## **UNITED STATES** **SECURITIES AND EXCHANGE COMMISSION**

**Washington, D.C. 20549**

## **FORM 10-K**


**(Mark One)**

x **ANNUAL REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934**


**For the fiscal year ended December 31, 2024**

**OR**


- **TRANSITION REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934**


**For the transition period from _________ to _________**


**Commission File Number: 001-34756**

# **Tesla, Inc.**

**(Exact name of registrant as specified in its charter)**


**Texas** **91-2197729**


**(State or other jurisdiction of**

**incorporation or organization)**


**1 Tesla Road**


**(I.R.S. Employer**

**Identification No.)**


**Austin, Texas** **78725**


**(Address of principal executive offices)** **(Zip Code)**


**(512) 516-8177**

**(Registrant’s telephone number, including area code)**


**Securities registered pursuant to Section 12(b) of the Act:**

|Title of each class|Trading Symbol(s)|Name of each exchange on which registered|
|---|---|---|
|Common stock|TSLA|The Nasdaq Global Select Market|


**Securities registered pursuant to Section 12(g) of the Act:**


**None**


Indicate by check mark whether the registrant is a well-known seasoned issuer, as defined in Rule 405 of the Securities Act. Yesx No o


Indicate by check mark if the registrant is not required to file reports pursuant to Section 13 or 15(d) of the Act. Yes o Nox


Indicate by check mark whether the registrant (1) has filed all reports required to be filed by Section 13 or 15(d) of the Securities Exchange Act of 1934 (“Exchange Act”)

during the preceding 12 months (or for such shorter period that the registrant was required to file such reports), and (2) has been subject to such filing requirements for the past 90

days. Yesx No o


Indicate by check mark whether the registrant has submitted electronically every Interactive Data File required to be submitted pursuant to Rule 405 of Regulation S-T

(§232.405 of this chapter) during the preceding 12 months (or for such shorter period that the registrant was required to submit such files). Yesx No o


Indicate by check mark whether the registrant is a large accelerated filer, an accelerated filer, a non-accelerated filer, a smaller reporting company, or an emerging growth

company. See the definitions of “large accelerated filer,” “accelerated filer,” “smaller reporting company” and “emerging growth company” in Rule 12b-2 of the Exchange Act:


Large accelerated filer x Accelerated filer

Non-accelerated filer - Smaller reporting company

Emerging growth company


---

If an emerging growth company, indicate by check mark if the registrant has elected not to use the extended transition period for complying with any new or revised financial

accounting standards provided pursuant to Section 13(a) of the Exchange Act. o


Indicate by check mark whether the Registrant has filed a report on and attestation to its management’s assessment of the effectiveness of its internal control over financial

reporting under Section 404(b) of the Sarbanes-Oxley Act (15 U.S.C. 7262(b)) by the registered public accounting firm that prepared or issued its audit report. x


If securities are registered pursuant to Section 12(b) of the Act, indicate by check mark whether the financial statements of the registrant included in the filing reflect the

correction of an error to previously issued financial statements. o


Indicate by check mark whether any of those error corrections are restatements that required a recovery analysis of incentive-based compensation received by any of the

registrant’s executive officers during the relevant recovery period pursuant to §240.10D-1(b). o


Indicate by check mark whether the registrant is a shell company (as defined in Rule 12b-2 of the Exchange Act). Yes o No x


The aggregate market value of voting stock held by non-affiliates of the registrant, as of June 28, 2024, the last business day of the registrant’s most recently completed

second fiscal quarter, was $550.17 billion (based on the closing price for shares of the registrant’s Common Stock as reported by the NASDAQ Global Select Market on June 28, 2024).

Shares of Common Stock held by each executive officer and director have been excluded in that such persons may be deemed to be affiliates. This determination of affiliate status is

not necessarily a conclusive determination for other purposes.


As of January 22, 2025, there were 3,216,517,037 shares of the registrant’s common stock outstanding.


**DOCUMENTS INCORPORATED BY REFERENCE**


Portions of the registrant’s Proxy Statement for the 2025 Annual Meeting of Stockholders are incorporated herein by reference in Part III of this Annual Report on Form 10-K to

the extent stated herein. Such proxy statement will be filed with the Securities and Exchange Commission within 120 days of the registrant’s fiscal year ended December 31, 2024.


---

**TESLA, INC.**


**ANNUAL REPORT ON FORM 10-K FOR THE YEAR ENDED DECEMBER 31, 2024**


**INDEX**


**Page**


**PART I.**


Item 1. Business 2


Item 1A. Risk Factors 13


Item 1B. Unresolved Staff Comments 27


Item 1C. Cybersecurity 28


Item 2. Properties 29


Item 3. Legal Proceedings 29


Item 4. Mine Safety Disclosures 29


**PART II.**


Item 5. Market for Registrant's Common Equity, Related Stockholder Matters and Issuer Purchases of Equity Securities 30


Item 6. [Reserved] 31


Item 7. Management's Discussion and Analysis of Financial Condition and Results of Operations 32


Item 7A. Quantitative and Qualitative Disclosures about Market Risk 44


Item 8. Financial Statements and Supplementary Data 45


Item 9. Changes in and Disagreements with Accountants on Accounting and Financial Disclosure 91


Item 9A. Controls and Procedures 91


Item 9B. Other Information 92


Item 9C. Disclosure Regarding Foreign Jurisdictions that Prevent Inspections 92


**PART III.**


Item 10. Directors, Executive Officers and Corporate Governance 93


Item 11. Executive Compensation 93


Item 12. Security Ownership of Certain Beneficial Owners and Management and Related Stockholder Matters 93


Item 13. Certain Relationships and Related Transactions, and Director Independence 93


Item 14. Principal Accountant Fees and Services 93


**PART IV.**


Item 15. Exhibits and Financial Statement Schedules 94


Item 16. Form 10-K Summary 107


Signatures


---

Table of Contents


**Forward-Looking Statements**


The discussions in this Annual Report on Form 10-K contain forward-looking statements within the meaning of the Private Securities Litigation Reform Act
of 1995. Forward-looking statements are based on assumptions with respect to the future and management’s current expectations, involve certain risks
and uncertainties and are not guarantees. These forward-looking statements include, but are not limited to, statements concerning supply chain
constraints, our strategy, competition, future operations and production capacity, future financial position, future revenues, projected costs, profitability,
expected cost reductions, capital adequacy, expectations regarding demand and acceptance for our technologies, growth opportunities and trends in the
markets in which we operate, prospects and plans and objectives of management. The words “anticipates,” “believes,” “could,” “estimates,” “expects,”
“intends,” “may,” “plans,” “projects,” “will,” “would,” “predicts” and similar expressions are intended to identify forward-looking statements, although not
all forward-looking statements contain these identifying words. We may not actually achieve the plans, intentions or expectations disclosed in our
forward-looking statements and you should not place undue reliance on our forward-looking statements. Future results may differ materially from the
plans, intentions and expectations disclosed in the forward-looking statements that we make. These forward-looking statements involve risks and
uncertainties that could cause our actual results to differ materially from those in the forward-looking statements, including, without limitation, the risks
set forth in Part I, Item 1A, “Risk Factors” of the Annual Report on Form 10-K for the fiscal year ended December 31, 2024 and that are otherwise
described or updated from time to time in our other filings with the Securities and Exchange Commission (the “SEC”). The discussion of such risks is not
an indication that any such risks have occurred at the time of this filing. We do not assume any obligation to update any forward-looking statements.


---

Table of Contents


**ITEM 1. BUSINESS**


**Overview**


**PART I**


We design, develop, manufacture, sell and lease high-performance fully electric vehicles and energy generation and storage systems, and offer
services related to our products. We generally sell our products directly to customers, and continue to grow our customer-facing infrastructure through a
global network of vehicle showrooms and service centers, Mobile Service, body shops, Supercharger stations and Destination Chargers to accelerate the
widespread adoption of our products. We emphasize performance, attractive styling and the safety of our users and workforce in the design and
manufacture of our products and are continuing to develop full self-driving technology for improved safety. We also strive to lower the cost of ownership
for our customers through continuous efforts to reduce manufacturing costs and by offering financial and other services tailored to our products.


Our mission is to accelerate the world’s transition to sustainable energy. We believe that this mission, along with our engineering expertise,
vertically integrated business model and focus on user experience differentiate us from other companies.


**Segment Information**


We operate as two reportable segments: (i) automotive and (ii) energy generation and storage.


The automotive segment includes the design, development, manufacturing, sales and leasing of high-performance fully electric vehicles as well as
sales of automotive regulatory credits. Additionally, the automotive segment also includes services and other, which includes sales of used vehicles, nonwarranty maintenance services and collision, part sales, paid Supercharging, insurance services revenue and retail merchandise sales. The energy
generation and storage segment includes the design, manufacture, installation, sales and leasing of solar energy generation and energy storage products
and related services and sales of solar energy systems incentives.


**Our Products and Services**


**Automotive**


We currently manufacture five different consumer vehicles – the Model 3, Y, S, X and Cybertruck. Model 3 is a four-door mid-size sedan that we
designed for manufacturability with a base price for mass-market appeal. Model Y is a compact sport utility vehicle (“SUV”) built on the Model 3 platform
with seating for up to seven adults. Model S is a four-door full-size sedan and Model X is a mid-size SUV with seating for up to seven adults. Model S and
Model X feature the highest performance characteristics and longest ranges that we offer in a sedan and SUV, respectively. In November 2023, we
entered the consumer pickup truck market with first deliveries of the Cybertruck, a full-size electric pickup truck with a stainless steel exterior that has
the utility and strength of a truck while featuring the speed of a sports car.


In 2022, we also began early production and deliveries of a commercial electric vehicle, the Tesla Semi. We have planned electric vehicles to
address additional vehicle markets, and continue leveraging developments in our proprietary Full Self-Driving (“FSD”) (Supervised) features, including
through our purpose-built Robotaxi product - Cybercab, and battery cell and other technologies. For purposes of this filing, use of the term “FSD
(Supervised)” includes the equivalent naming convention, “FSD (Capability)” that is used in the European, Middle East and Asia-Pacific regions.


**Energy Generation and Storage**


**Energy Storage Products**


Powerwall and Megapack are our lithium-ion battery energy storage products. Powerwall, which we sell directly to customers, as well as through
channel partners, is designed to store energy at a home or small commercial facility. Megapack is an energy storage solution for commercial, industrial,
utility and energy generation customers, multiple of which may be grouped together to form larger installations of gigawatt hours (“GWh”) or greater
capacity.


We also continue to develop software capabilities for remotely controlling and dispatching our energy storage systems across a wide range of
markets and applications, including through our real-time energy control and optimization platforms.


2


---

Table of Contents


**Solar Energy Offerings**


We sell retrofit solar energy systems to customers and channel partners. We purchase most of the components for our retrofit solar energy systems
from multiple sources to ensure competitive pricing and adequate supply. We also design and manufacture certain components for our solar energy
products.


We sell our Solar Roof, which combines premium glass roof tiles with energy generation, to consumers, including through channel customers. We
continue to improve our installation capability and efficiency, including through collaboration with real estate developers and builders on new homes.


**Technology**


**Automotive**


**Battery and Powertrain**


Our core vehicle technology competencies include powertrain engineering and manufacturing and our ability to design vehicles that utilize the
unique advantages of an electric powertrain. We have designed our proprietary powertrain systems to be adaptable, efficient, reliable and cost-effective
while withstanding the rigors of an automotive environment. We offer dual motor powertrain vehicles, which use two electric motors to maximize traction
and performance in an all-wheel drive configuration, as well as vehicle powertrain technology featuring three electric motors for further increased
performance in certain versions of Model S and Model X, Cybertruck and the Tesla Semi.


We maintain extensive testing and R&D capabilities for battery cells, packs and systems, and have built an expansive body of knowledge on lithiumion cell chemistry types and performance characteristics. In order to enable a greater supply of cells for our products with higher energy density at lower
costs, we have developed a new proprietary lithium-ion battery cell and improved manufacturing processes.


**Vehicle Control and Infotainment Software**


The performance and safety systems of our vehicles and their battery packs utilize sophisticated control software. Control systems in our vehicles
optimize performance, customize vehicle behavior, manage charging and control all infotainment functions. We develop almost all of this software,
including most of the user interfaces, internally and update our vehicles’ software regularly through over-the-air updates.


**Self-Driving Development and Artificial Intelligence**


We have expertise in developing technologies, systems and software to enable self-driving vehicles using primarily vision-based technologies. Our
FSD Computer runs our neural networks in our vehicles, and we are also developing additional computer hardware to better enable the massive amounts
of field data captured by our vehicles to continually train and improve these neural networks for real-world performance.


Currently, we offer in our vehicles certain advanced driver assist systems under our Autopilot and FSD (Supervised) options. Although at present,
same as in the past, the driver is responsible for remaining fully engaged in the driving operation, our systems provide safety and convenience
functionality that can relieve drivers of many tedious and potentially dangerous aspects of road travel much like the system that airplane pilots use, when
conditions permit. As with other vehicle systems, we improve these functions in our vehicles over time through over-the-air software updates.


In 2025, we intend to begin launching our Robotaxi business, a ride-hailing network that will eventually operate fully autonomous vehicles. We
expect this business will open access to a new customer base even as modes of transportation evolve. We believe our capabilities and advancements in
AI, including the deployment of Cortex, our training cluster at Gigafactory Texas, differentiates us from our competitors.


We are also applying our artificial intelligence learnings from self-driving technology to the field of robotics, such as through Optimus, a robotic
humanoid in development, which is controlled by the same AI system.


3


---

Table of Contents


**Energy Generation and Storage**


**Energy Storage Products**


We leverage many of the component-level technologies from our vehicles in our energy storage products. By taking a modular approach to the
design of battery systems, we can optimize manufacturing capacity of our energy storage products. Additionally, our expertise in power electronics
enables our battery systems to interconnect with electricity grids while providing fast-acting systems for power injection and absorption. We have also
developed software to remotely control and dispatch our energy storage systems.


**Solar Energy Systems**


We have engineered Solar Roof over numerous iterations to combine aesthetic appeal and durability with power generation. The efficiency of our
solar energy products is aided by our own solar inverter, which incorporates our power electronics technologies. We designed both products to integrate
with Powerwall.


**Design and Engineering**


**Automotive**


We have established significant in-house capabilities in the design and test engineering of electric vehicles and their components and systems. Our
team has significant experience in computer-aided design as well as durability, strength and crash test simulations, which reduces the product
development time of new models. We have also achieved complex engineering feats in stamping, casting and thermal systems, and developed a method
to integrate batteries directly with vehicle body structures without separate battery packs to optimize manufacturability, weight, range and cost
characteristics.


We are also expanding our manufacturing operations globally while taking action to localize our vehicle designs and production for particular
markets, including country-specific market demands and factory optimizations for local workforces. As we increase our capabilities, particularly in the
areas of automation, die-making and line-building, we are also making strides in the simulations modeling these capabilities prior to construction.


**Energy Generation and Storage**


Our expertise in electrical, mechanical, civil and software engineering allows us to design, engineer, manufacture and install energy generating and
storage products and components, including at the residential through utility scale. For example, the modular design of our Megapack utility-scale battery
line is intended to significantly reduce the amount of assembly required in the field. We also customize solutions including our energy storage products,
solar energy systems and/or Solar Roof for customers to meet their specific needs.


**Sales and Marketing**


Historically, we have been able to achieve sales without traditional advertising and at relatively low marketing costs. We continue to monitor our
public narrative and brand, and tailor our marketing efforts accordingly, including through investments in customer education and advertising as
necessary.


**Automotive**


**Direct Sales**


Our vehicle sales channels currently include our website and an international network of company-owned stores. In some jurisdictions, we also have
galleries to educate and inform customers about our products, but such locations do not transact in the sale of vehicles. We believe this infrastructure
enables us to better control costs of inventory, manage warranty service and pricing, educate consumers about electric vehicles, make our vehicles more
affordable, maintain and strengthen the Tesla brand and obtain rapid customer feedback.


We reevaluate our sales strategy both globally and at a location-by-location level from time to time to optimize our sales channels. However, sales
of vehicles in the automobile industry tend to be cyclical in many markets, which may expose us to volatility from time to time.


4


---

Table of Contents


**Used Vehicle Sales**


Our used vehicle business supports new vehicle sales by integrating the trade-in of a customer’s existing Tesla or non-Tesla vehicle with the sale of
a new Tesla vehicle. The Tesla and non-Tesla vehicles we acquire as trade-ins, along with vehicles returned upon lease-end are subsequently remarketed,
either directly by us or through third parties.


**Public Charging**


We have a growing global network of Tesla Superchargers, which are our industrial-grade, high-speed vehicle chargers. Where possible, we colocate Superchargers with our solar and energy storage systems to reduce costs and promote renewable power. Supercharger stations are typically
placed along well-traveled routes and in and around dense city centers to allow vehicle owners the ability to enjoy quick, reliable charging along an
extensive network with convenient stops. Use of the Supercharger network either requires payment of a fee or is free under certain sales programs. In
November 2021, we began to offer Supercharger access to non-Tesla vehicles in certain locations in support of our mission to accelerate the world’s
transition to sustainable energy, and in November 2022, we opened up our previously proprietary charging connector as the North American Charging
Standard (NACS). This enables electric vehicles and charging stations to interoperate — which makes charging easier and more efficient for everyone and
advances our mission to accelerate the world’s transition to sustainable energy. Following this, all major automotive companies announced their adoption
of NACS in certain markets, with their access to the Supercharger network beginning in phases in 2024 and their production of NACS vehicles beginning
no later than 2025. We also engaged SAE International to govern NACS as an industry standard, now named J3400. We continue to monitor and increase
our network of Tesla Superchargers in anticipation of future demand.


We also work with a wide variety of hospitality, retail and public destinations, as well as businesses with commuting employees, to offer additional
charging options for our customers, as well as single-family homeowners and multi-family residential entities, to deploy home charging solutions.


**In-App Upgrades**


As our vehicles are capable of being updated remotely over-the-air, our customers may purchase additional paid options and features through the
Tesla app or through the in-vehicle user interface. We expect that this functionality will also allow us to offer certain options and features on a
subscription basis in the future.


**Energy Generation and Storage**


We market and sell our solar and energy storage products to residential, commercial and industrial customers and utilities through a variety of
channels, including through our website, stores and galleries, as well as through our network of channel partners, and in the case of some commercial
customers, through PPA transactions. We emphasize simplicity, standardization and accessibility to make it easy and cost-effective for customers to adopt
clean energy, while reducing our customer acquisition costs.


**Service and Warranty**


**Automotive**


**Service**


We provide service for our electric vehicles at our company-owned service locations and through Tesla Mobile Service technicians who perform work
remotely at customers’ homes or other locations. Servicing the vehicles ourselves allows us to identify problems and implement solutions and
improvements faster than traditional automobile manufacturers and their dealer networks. The connectivity of our vehicles also allows us to diagnose and
remedy many problems remotely and proactively.


**Vehicle Limited Warranties and Extended Service Plans**


We provide a manufacturer’s limited warranty on all new and used Tesla vehicles we sell directly to consumers, which may include limited
warranties on certain components, specific types of damage or battery capacity retention. We also currently offer optional extended service plans that
provide coverage beyond the new vehicle limited warranties for certain models in specified regions.


5


---

Table of Contents


**Energy Generation and Storage**


We provide service and repairs to our energy product customers, including under warranty where applicable. We generally provide manufacturer’s
limited warranties with our energy storage products and offer certain extended limited warranties that are available at the time of purchase of the
system. If we install a system, we also provide certain limited warranties on our installation workmanship.


For retrofit solar energy systems, we provide separate limited warranties for workmanship and against roof leaks, and for Solar Roof, we also
provide limited warranties for defects and weatherization. For components not manufactured by us, we generally pass-through the applicable
manufacturers’ warranties.


As part of our historical solar energy system and energy storage contracts, we may provide the customer with performance guarantees that commit
that the underlying system will meet or exceed the minimum energy generation or performance requirements specified in the contract.


**Financial Services**


**Automotive**


**Purchase Financing and Leases**


We offer leasing and/or loan financing arrangements for our vehicles in certain jurisdictions in North America, Europe and/or Asia ourselves and
through various financial institutions. Under certain of such programs, we have provided resale value guarantees or buyback guarantees that may
obligate us to cover a resale loss up to a certain limit or repurchase the subject vehicles at pre-determined values.


**Insurance**


In 2021, we launched our insurance product using real-time driving behavior in select states, which offers rates that are often better than other
alternatives and promotes safer driving. Our insurance products are currently available in 12 states and we plan to expand the markets in which we offer
insurance products, as part of our ongoing effort to decrease the total cost of ownership for our customers.


**Energy Generation and Storage**


We offer certain financing options to our residential customers, which enable the customer to purchase and own energy systems comprised of solar,
Solar Roof and/or Powerwall batteries. Our solar PPAs, offered primarily to commercial customers, charge a fee per kilowatt-hour based on the amount of
electricity produced by our solar energy systems.


**Manufacturing**


We currently have manufacturing facilities in the U.S. in California, New York, Texas and Nevada. At these facilities, we manufacture and assemble,
among other things, vehicles, certain vehicle parts and components, such as our battery packs and battery cells, energy storage components and
systems and solar products and components.


Internationally, we also have manufacturing facilities in China and Germany, which allows us to increase the affordability of our vehicles for
customers in local markets by reducing transportation and manufacturing costs and eliminating the impact of unfavorable tariffs. In March 2023, we
announced the location of our next Gigafactory in Monterrey, Mexico. Generally, we continue to expand production capacity at our existing facilities. We
also intend to further increase cost-competitiveness in our significant markets by strategically adding local manufacturing.


**Supply Chain**


Our products use thousands of parts that are sourced from hundreds of suppliers across the world. We have developed close relationships with
vendors of key parts such as battery cells, electronics and complex vehicle assemblies. Certain components purchased from these suppliers are shared or
are similar across many product lines, allowing us to take advantage of pricing efficiencies from economies of scale.


6


---

Table of Contents


As is the case for some automotive companies, some of our procured components and systems are sourced from single suppliers. Where multiple
sources are available for certain key components, we work to qualify multiple suppliers for them where it is sensible to do so in order to minimize
potential production risks due to disruptions in their supply. We also mitigate risk by maintaining safety stock for key parts and assemblies and die banks
for components with lengthy procurement lead times.


Our products use various raw materials including aluminum, steel, cobalt, lithium, nickel and copper. Pricing for these materials is governed by
market conditions and may fluctuate due to various factors outside of our control, such as supply and demand and market speculation. We strive to
execute long-term supply contracts for such materials at competitive pricing when feasible, and we currently believe that we have adequate access to
raw materials supplies to meet the needs of our operations.


**Governmental Programs, Incentives and Regulations**


Globally, the ownership of our products by our customers is impacted by various government credits, incentives, and policies. Our business and
products are also subject to numerous governmental regulations that vary among jurisdictions.


The operation of our business is also impacted by various government programs, incentives, and other arrangements. See Note 2, Summary of
Significant Accounting Policies, to the consolidated financial statements included elsewhere in this Annual Report on Form 10-K for further details.


**Programs and Incentives**


**Inflation Reduction Act**


On August 16, 2022, the Inflation Reduction Act of 2022 (“IRA”) was enacted into law and is effective for taxable years beginning after December
31, 2022, and remains subject to future guidance releases. The IRA includes multiple incentives to promote clean energy, electric vehicles, battery and
energy storage manufacture or purchase, including through providing tax credits to consumers. For example, under current legislation, qualifying Tesla
customers may receive up to $7,500 in federal tax credits for the purchase of qualified electric vehicles in the U.S. through 2032.


**Automotive Regulatory Credits**


We earn tradable credits in the operation of our business under various regulations related to zero-emission vehicles (“ZEVs”), greenhouse gas, fuel
economy and clean fuel. We sell these credits to other regulated entities who can use the credits to comply with emission standards and other regulatory
requirements. Sales of these credits are recognized within automotive regulatory credits revenue in our consolidated statements of operations included
elsewhere in this Annual Report on Form 10-K.


**Energy Storage System Incentives and Policies**


While the regulatory regime for energy storage projects is still under development, there are various policies, incentives and financial mechanisms
at the federal, state and local levels that support the adoption of energy storage.


For example, energy storage systems that are charged using solar energy may be eligible for the solar energy-related U.S. federal tax credits
described below. The Federal Energy Regulatory Commission (“FERC”) has also taken steps to enable the participation of energy storage in wholesale
energy markets. In addition, California and a number of other states have adopted procurement targets for energy storage, and behind-the-meter energy
storage systems qualify for funding under the California Self Generation Incentive Program. Our customers primarily benefit directly under these
programs. In certain instances our customers may transfer such credits to us as contract consideration. In such transactions, they are included as a
component of energy generation and storage revenues in our consolidated statements of operations included elsewhere in this Annual Report on Form
10-K.


Pursuant to the IRA, under Sections 48, 48E and 25D of the Internal Revenue Code (”IRC”), standalone energy storage technology is eligible for a tax
credit between 6% and 50% of qualified expenditures, regardless of the source of energy, which may be claimed by our customers for storage systems
they purchase or by us for arrangements where we own the systems. These tax credits are primarily for the benefit of our customers and are currently
scheduled to phase-out starting in 2032 or later.


7


---

Table of Contents


**Solar Energy System Incentives and Policies**


U.S. federal, state and local governments have established various policies, incentives and financial mechanisms to reduce the cost of solar energy
and to accelerate the adoption of solar energy. These incentives include tax credits, cash grants, tax abatements and rebates.


In particular, pursuant to the IRA, Sections 48, 48E and 25D of the IRC provides a tax credit between 6% and 70% of qualified commercial or
residential expenditures for solar energy systems, which may be claimed by our customers for systems they purchase, or by us for arrangements where
we own the systems for properties that meet statutory requirements. These tax credits are primarily for the direct benefit of our customers and are
currently scheduled to phase-out starting in 2032 or later.


**Regulations**


**Vehicle Safety and Testing**


In the U.S., our vehicles are subject to regulation by the National Highway Traffic Safety Administration (“NHTSA”), including all applicable Federal
Motor Vehicle Safety Standards (“FMVSS”) and the NHTSA bumper standard. Numerous FMVSS apply to our vehicles, such as crash-worthiness and
occupant protection requirements. Our current vehicles fully comply and we expect that our vehicles in the future will fully comply with all applicable
FMVSS with limited or no exemptions; however, FMVSS are subject to change from time to time. As a manufacturer, we must self-certify that our vehicles
meet all applicable FMVSS and the NHTSA bumper standard, or otherwise are exempt, before the vehicles may be imported or sold in the U.S.


We are also required to comply with other federal laws administered by NHTSA, including the Corporate Average Fuel Economy standards, Theft
Prevention Act requirements, labeling requirements and other information provided to customers in writing, Early Warning Reporting requirements
regarding warranty claims, field reports, death and injury reports and foreign recalls, a Standing General Order requiring reports regarding certain crashes
involving vehicles equipped with advanced driver assistance systems, and additional requirements for cooperating with compliance and safety
investigations and recall reporting. The U.S. Automobile Information and Disclosure Act also requires manufacturers of motor vehicles to disclose certain
information regarding the manufacturer’s suggested retail price, optional equipment and pricing. In addition, federal law requires inclusion of fuel
economy ratings, as determined by the U.S. Department of Transportation and the Environmental Protection Agency (the “EPA”), and New Car
Assessment Program ratings as determined by NHTSA, if available.


Our vehicles sold outside of the U.S. are subject to similar foreign compliance, safety, environmental and other regulations. Many of those
regulations are different from those applicable in the U.S. and may require redesign and/or retesting. Some of those regulations impact or prevent the
rollout of new vehicle features.


**Self-Driving Vehicles**


Generally, laws pertaining to self-driving vehicles are evolving globally, and in some cases may create restrictions on features or vehicle designs
that we develop. While there are currently no federal U.S. regulations pertaining specifically to self-driving vehicles or self-driving equipment, NHTSA has
published recommended guidelines on self-driving vehicles, apart from the FMVSS and manufacturer reporting obligations, and retains the authority to
investigate and/or take action on the safety or compliance of any vehicle, equipment or features operating on public roads. Certain U.S. states also have
legal restrictions on the operation, registration or licensure of self-driving vehicles, and many other states are considering them. This regulatory
patchwork increases the legal complexity with respect to self-driving vehicles in the U.S.


In markets that follow the regulations of the United Nations Economic Commission for Europe (“ECE markets”), some requirements restrict the
design of advanced driver-assistance or self-driving features, which can compromise or prevent their use entirely. Other applicable laws, both current and
proposed, may hinder or complicate the path and timeline to introducing self-driving vehicles for sale and use in the markets where they apply.


Other key markets, including China, continue to consider self-driving regulation. Any implemented regulations may differ materially from the U.S.
and ECE markets, which may further increase the legal complexity of self-driving vehicles and limit or prevent certain features.


8


---

Table of Contents


**Automobile Manufacturer and Dealer Regulation**


In the U.S., state laws regulate the manufacture, distribution, sale and service of automobiles, and generally require motor vehicle manufacturers
and dealers to be licensed in order to sell vehicles directly to residents. Certain states have asserted that the laws in such states do not permit automobile
manufacturers to be licensed as dealers or to act in the capacity of a dealer, or that they otherwise restrict a manufacturer’s ability to deliver or perform
warranty repairs on vehicles. To sell vehicles to residents of states where we are not licensed as a dealer, we generally conduct the sale out of the state.
In certain such states, we have opened “galleries” that serve an educational purpose and where sales may not occur.


Some automobile dealer trade associations have both challenged the legality of our operations in court and used administrative and legislative
processes to attempt to prohibit or limit our ability to operate existing stores or expand to new locations. Certain dealer associations have also actively
lobbied state licensing agencies and legislators to interpret existing laws or enact new laws in ways not favorable to our ownership and operation of our
own retail and service locations. We expect such challenges to continue, and we intend to actively fight any such efforts.


**Battery Safety and Testing**


Our battery packs are subject to various U.S. and international regulations that govern transport of “dangerous goods,” defined to include lithiumion batteries, which may present a risk in transportation. We conduct testing to demonstrate our compliance with such regulations.


We use lithium-ion cells in our high voltage battery packs in our vehicles and energy storage products. The use, storage and disposal of our battery
packs are regulated under existing laws and are the subject of ongoing regulatory changes that may add additional requirements in the future. We have
agreements with third party battery recycling companies to recycle our battery packs, and we are also piloting our own recycling technology.


**Solar Energy—General**


We are subject to certain state and federal regulations applicable to solar and battery storage providers and sellers of electricity. To operate our
systems, we enter into standard interconnection agreements with applicable utilities. Sales of electricity and non-sale equipment leases by third parties,
such as our leases and PPAs, have faced regulatory challenges in some states and jurisdictions.


**Solar Energy—Net Metering**


Most states in the U.S. make net energy metering, or net metering, available to solar customers. Net metering typically allows solar customers to
interconnect their solar energy systems to the utility grid and offset their utility electricity purchases by receiving a bill credit for excess energy generated
by their solar energy system that is exported to the grid. In certain jurisdictions, regulators or utilities have reduced or eliminated the benefit available
under net metering or have proposed to do so.


**Competition**


**Automotive**


The worldwide automotive market is highly competitive and we expect it will become even more competitive in the future as a significant and
growing number of established and new automobile manufacturers, as well as other companies, have entered, or are reported to have plans to enter the
electric vehicle market.


We believe that our vehicles compete in the market based on both their traditional segment classification as well as their propulsion technology. For
example, Cybertruck competes with other pickup trucks, Model S and Model X compete primarily with premium sedans and premium SUVs and Model 3
and Model Y compete with small to medium-sized sedans and compact SUVs, all of which are extremely competitive markets. Competing products
typically include internal combustion vehicles from more established automobile manufacturers; however, many established and new automobile
manufacturers have entered or have announced plans to enter the market for electric and other alternative fuel vehicles. Overall, we believe these
announcements and vehicle introductions promote the development of the electric vehicle market by highlighting the attractiveness of electric vehicles
relative to internal combustion vehicles. Many major automobile manufacturers have electric vehicles available today in major markets including the U.S.,
China and Europe, and other current and prospective automobile manufacturers are also developing electric vehicles. In addition, several manufacturers
offer hybrid vehicles, including plug-in versions.


9


---

Table of Contents


We believe that there is also increasing competition for our vehicle offerings as a platform for delivering self-driving technologies, charging solutions
and other features and services, and we expect to compete in this developing market through continued progress on our Autopilot, FSD (Supervised) and
neural network capabilities, Supercharger network and our infotainment offerings.


**Energy Generation and Storage**


**Energy Storage Systems**


The market for energy storage products is also highly competitive, and both established and emerging companies have introduced products that are
similar to our product portfolio or that are alternatives to the elements of our systems. We compete with these companies based on price, energy density
and efficiency. We believe that the specifications and features of our products, our strong brand and the modular, scalable nature of our energy storage
products give us a competitive advantage in our markets.


**Solar Energy Systems**


The primary competitors to our solar energy business are the traditional local utility companies that supply energy to our potential customers. We
compete with these traditional utility companies primarily based on price and the ease by which customers can switch to electricity generated by our
solar energy systems. We also compete with solar energy companies that provide products and services similar to ours. Many solar energy companies
only install solar energy systems, while others only provide financing for these installations. We believe we have a significant expansion opportunity with
our offerings and that the regulatory environment is increasingly conducive to the adoption of renewable energy systems.


**Intellectual Property**


We place a strong emphasis on our innovative approach and proprietary designs which bring intrinsic value and uniqueness to our product portfolio.
As part of our business, we seek to protect the underlying intellectual property rights of these innovations and designs such as with respect to patents,
trademarks, copyrights, trade secrets, confidential information and other measures, including through employee and third-party nondisclosure
agreements and other contractual arrangements. For example, we place a high priority on obtaining patents to provide the broadest and strongest
possible protection to enable our freedom to operate our innovations and designs across all of our products and technologies as well as to protect and
defend our product portfolio. We have also adopted a patent policy in which we irrevocably pledged that we will not initiate a lawsuit against any party for
infringing our patents through activity relating to electric vehicles or related equipment for so long as such party is acting in good faith. We made this
pledge in order to encourage the advancement of a common, rapidly-evolving platform for electric vehicles, thereby benefiting ourselves, other
companies making electric vehicles and the world.


**Environmental, Social and Governance (ESG) and Human Capital Resources**


**ESG**


The very purpose of Tesla's existence is to accelerate the world's transition to sustainable energy. We believe the world cannot reduce carbon
emissions without addressing both energy generation and consumption, and we are designing and manufacturing a complete energy and transportation
ecosystem to achieve this goal. As we expand, we are building each new factory to be more efficient and sustainably designed than the previous one,
including with respect to per-unit waste reduction and resource consumption, including water and energy usage. We are focused on further enhancing
sustainability of operations outside of our direct control, including reducing the carbon footprint of our supply chain.


We are committed to sourcing only responsibly produced materials, and our suppliers are required to provide evidence of management systems that
ensure social, environmental and sustainability best practices in their own operations, as well as to demonstrate a commitment to responsible sourcing
into their supply chains. We have a zero-tolerance policy when it comes to child or forced labor and human trafficking by our suppliers and we look to the
Organization for Economic Co-operation and Development Due Diligence Guidelines to inform our process and use feedback from our internal and
external stakeholders to find ways to continually improve. We are also driving safety in our own factories by focusing on worker engagement. Our
incidents per vehicle continue to drop even as our production volumes increase. We also strive to be an employer of choice by offering compelling,
impactful jobs with best in-industry benefits.


10


---

Table of Contents


We believe that sound corporate governance is critical to helping us achieve our goals, including with respect to ESG. We continue to evolve a
governance framework that exercises appropriate oversight of responsibilities at all levels throughout the company and manages its affairs consistent
with high principles of business ethics. Our Sustainability and Impact team, in conjunction with leaders from across our Company, regularly presents to
our Board of Directors, which oversees our ESG impacts, initiatives and priorities.


**Human Capital Resources**


Tesla’s ability to attract, develop and retain a talented workforce is a competitive advantage. During the past year, Tesla provided its workforce with
opportunities to contribute to its mission and grow professionally, earning Tesla among the Top 100 Employers of Choice in the 2024 American
Opportunity Index. As of December 31, 2024, our employee headcount worldwide was 125,665.


Employees can participate in Tesla stock ownership programs (of which 92% have been given the opportunity to as part of their total rewards
package), while accessing industry-leading benefits, such as free counseling, paid parental leave, paid time off, company sponsored 401(k) plans, no cost
fertility and adoption programs and zero-premium medical plan options that are made available on the first day of employment.


We hire, evaluate and promote employees based on their skills and performance. In 2024, over 13,000 of our employees worldwide, 80% of whom
represent Tesla’s frontline workforce, took advantage of opportunities to advance their career within the Company. As of this report, more than two-thirds
(68%) of our managers have been promoted from internal, non-managerial positions, and 45% of our management team has been with Tesla for over five
years.


Tesla cultivates an environment that recognizes employee wins and impacts. We enhance everyday recognition by spotlighting employees and
empowering them to recognize each other’s successes. We inform and engage employees to help foster a connected Tesla experience that supports the
business. To enable employee performance, we provide opportunities for them to learn and grow, including:


**Internships & Fellowships**


  - **Professional Internships –** Every year, Tesla hires approximately 4,000 university and community college students globally for internships
across all business groups. We partner with campuses and student organizations to build a high-quality pipeline of talent, particularly individuals
passionate about sustainable energy and autonomy. From day one, our interns contribute to meaningful projects, often times leading to full-time
positions upon completion of their internships.


  - **Military Fellowship Program –** Tesla's Fellowship program, in partnership with the U.S. Chamber of Commerce Foundation’s Hire Our Heroes,
offers exiting military service members corporate industry experience during their transition in service. The program aims to convert highperforming individuals to full-time roles and create a veteran talent pipeline for opportunities across Tesla North America.


**Development Programs**


  - **Manufacturing Development Program –** Tesla's global manufacturing pathway programs are designed to provide graduating high school
seniors and early career individuals with the financial resources, coursework and experience they need to start a successful manufacturing career
at Tesla. Through 2024, Tesla expanded the program to new campuses and hired over 800 graduates with a goal for continued growth. In 2025,
Tesla plans to hire over 1,000 participants across our factories.


  - **Supervisor Professional Program**  - The Supervisor program is designed for industrial foremen that provides employees the opportunity to
develop expertise in their field. Across a 16-month period, employees take comprehensive coursework in the fields of technology, law, organization
and personnel management. In 2024, our employees became people leaders in the fields of metal production and electrical technology.


11


---

Table of Contents


  - **Engineering Development Program**  - Launched 2024, the program focuses on developing recent college and university graduates for
specialized engineering fields. In partnership with local education partners, the program educates early-career engineers in controls engineering,
enhancing their knowledge of high-demand technologies for manufacturing.


**Educational Programs**


  - **Education Assistance Program**  - Tesla's Education Assistance Program offers employees access to tuition-free and partially funded learning
opportunities, including degrees for in-demand careers, short-form certificates and programs for high-school completion or English-language
learning. Launched in February 2024, the program has provided funding to 5,436 actively enrolled learners and 1,338 graduates acquiring
valuable skills in manufacturing, engineering, artificial intelligence, supply chain management and leadership. The program partners with topranked online institutions and local colleges offering both flexible self-paced learning options and in-person applied training.


  - **FlexLearn and Dual Study Program**  - The FlexLearn and Dual Study Program provides employees opportunities to pursue their educational
goals across Europe. FlexLearn allows our employees to further develop with tailored training that aligns with the needs of our factories. The Dual
Study Program combines theoretical knowledge with practical experience. Graduates of the program receive industry related degrees.


**Technical Programs**


  - **Apprenticeships –** The Tesla Apprenticeships are multi-year global programs combining academic and on-the-job training, that prepares
specialists in skilled trades. Apprentices complete 2,000 - 8,000 hours of on-the-job training alongside courses at local education partners
throughout our manufacturing and service locations. The program ensures that graduates are well-qualified technicians, ready to support our
teams.


  - **Technician Trainee (Service and Collision) –** The Tesla Technician Trainee Program provides on-the-job automotive maintenance and collision
training at Tesla’s Service Centers. The program is targeted at individuals currently enrolled in a school automotive or collision program and recent
graduates with limited industry experience. In 2024, Tesla hired trainees across North America, EMEA and APAC.


  - **Future Talent Traineeship –** The Flagship entry-level rotational program was piloted in the United Kingdom and Ireland. Trainees have the
unique opportunity to experience all key aspects of service, sales and delivery within a single 12-month program, before making an informed
decision on which career path they'd like to specialize in full-time upon completion. The program is ideal for exploring careers within Tesla’s
service team.


  - **START (Manufacturing and Service) –** Tesla START is an intensive training program that equips individuals with the skills needed for a
successful technician role at Tesla. We partner with colleges to integrate Tesla START into automotive and manufacturing classroom locations. In
2024, Tesla START expanded to 14 campuses and hired over 400 technicians.


Tesla is committed to providing a workplace where employees feel respected, satisfied and appreciated. Our policies are designed to promote
fairness and respect for everyone. We actively support the hiring, retention and advancement of exceptional talent, including but not limited to veterans,
disabled veterans and individuals with disabilities. As of December 31, 2024, in the US, 2.3% of our employees are veterans or active-duty military
personnel, 3.3% of our employees are identify as individuals with disabilities and 1.2% of our employees identify as veterans or active-duty military
personnel with disabilities. Our military partnerships and development programs noted above help to directly and indirectly support these employees.


At Tesla, our employees’ passion is what powers our mission. Everyone is expected to be trustworthy, demonstrate excellence in their performance
and collaborate with others. Our factories, offices, stores and service centers are places where our employees have opportunities to enhance their skills
and gain experience, which is essential for Tesla’s growth.


12


---

Table of Contents


With this in mind, we will not tolerate certain behaviors. These include harassment, retaliation, violence, intimidation and discrimination of any kind
based on any protected category or action. Anti-harassment training is provided to all new hires on their first day of orientation, ensuring that all
employees are equipped with the knowledge and tools to maintain a respectful environment. For leaders, anti-harassment training is reinforced on an
ongoing basis to promote consistent leadership standards and reinforce organizational values.


In addition to anti-harassment training, we offer a range of leadership development programs throughout the year to further enhance leaders' skills.
These programs are designed to help leaders manage teams, communicate effectively, drive a culture of accountability and resolve disputes.


At Tesla, we listen to our employees. Our engagement strategy is to listen, act and report back to employees on progress. Pulse, Tesla's semiannual
employee survey, aims to capture the employee experience and generated 86% global participation. The crucial feedback garnered from these efforts
helps shape Tesla’s future goals, plans and projects.


The safety and health of our employees is a core value. Everyone across Tesla works to ensure a healthy and safe workplace. Employees are
encouraged to speak up regarding misconduct or safety concerns and can do so by contacting the integrity line, submitting concerns through our Take
Charge process, or notifying their Human Resource Partner or any member of management. Concerns are reviewed in accordance with established
protocols by investigators with expertise, who also review for trends and outcomes for remediation and appropriate controls. Responding to questions
timely is key so Human Resource Partners for each functional area are visible throughout facilities and engaging employees.


Our Compensation Committee generally oversees our human capital management strategy, and regularly receives updates and reviews certain
management practices related to Tesla’s talent, including how Tesla recruits, develops and retains excellent talent. The Committee directly interacts and
engages with members of Tesla’s management, including members from the human resources, compliance and legal teams to review and evaluate
people-related initiatives, employee feedback, risks and opportunities. The Committee also monitors developments in human capital management
practices and recommends revisions to Company policies and practices as appropriate.


Tesla aspires to do the right thing, and we are constantly looking for ways to do better.


**Available Information**


We file or furnish periodic reports and amendments thereto, including our Annual Reports on Form 10-K, our Quarterly Reports on Form 10-Q and
Current Reports on Form 8-K, proxy statements and other information with the SEC. In addition, the SEC maintains a website (www.sec.gov) that contains
reports, proxy and information statements, and other information regarding issuers that file electronically. Our website is located at www.tesla.com, and
our reports, amendments thereto, proxy statements and other information are also made available, free of charge, on our investor relations website at
ir.tesla.com as soon as reasonably practicable after we electronically file or furnish such information with the SEC. The information posted on our website
is not incorporated by reference into this Annual Report on Form 10-K.


**ITEM 1A. RISK FACTORS**


You should carefully consider the risks described below together with the other information set forth in this report, which could materially affect our
business, financial condition and future results. The risks described below are not the only risks facing our company. Risks and uncertainties not currently
known to us or that we currently deem to be immaterial also may materially adversely affect our business, financial condition and operating results.


**Risks Related to Our Ability to Grow Our Business**


**We may experience delays in launching and ramping the production of our products and features, or we may be unable to control**
**our manufacturing costs.**


We have previously experienced and may in the future experience launch and production ramp delays for new products and features. For example,
we encountered unanticipated supplier issues that led to delays during the initial ramp of our first Model X and experienced challenges with a supplier and
with ramping full automation for certain of our initial Model 3 manufacturing processes. In addition, we may introduce in the future new or unique
manufacturing processes and design features for our products. As we expand our vehicle offerings and global footprint, there is no guarantee that we will
be able to successfully and timely introduce and scale such processes or features.


13


---

Table of Contents


In particular, our future business depends in large part on increasing the production of mass-market vehicles. In order to be successful, we will need
to implement, maintain and ramp efficient and cost-effective manufacturing capabilities, processes and supply chains and achieve the design tolerances,
high quality and output rates we have planned at our manufacturing facilities in California, Nevada, Texas, China, Germany and any future sites such as
Mexico. We will also need to hire, train and compensate skilled employees to operate these facilities. Bottlenecks and other unexpected challenges such
as those we experienced in the past may arise during our production ramps, and we must address them promptly while continuing to improve
manufacturing processes and reducing costs. If we are not successful in achieving these goals, we could face delays in establishing and/or sustaining our
product ramps or be unable to meet our related cost and profitability targets.


We have experienced, and may also experience similar future delays in launching and/or ramping production of our energy storage products and
Solar Roof; new product versions or variants; new vehicles; and future products, features and services based on artificial intelligence. Likewise, we may
encounter delays with the design, construction and regulatory or other approvals necessary to build and bring online future manufacturing facilities and
products. In addition, as we continue to develop our artificial intelligence services and products, we may face many additional challenges, including the
availability and cost of energy, processing power limitations and the substantial power requirements for our data centers.


Any delay or other complication in ramping the production of our current products or the development, manufacture, launch and production ramp of
our future products, features and services, or in doing so cost-effectively and with high quality, may harm our brand, business, prospects, financial
condition and operating results.


**Our suppliers may fail to deliver components according to schedules, prices, quality and volumes that are acceptable to us, or we**
**may be unable to manage these components effectively.**


Our products contain thousands of parts purchased globally from hundreds of suppliers, including single-source direct suppliers, which exposes us to
multiple potential sources of component shortages. Unexpected changes in business conditions, materials pricing, including inflation of raw material
costs, labor issues, wars, trade policies, natural disasters, health epidemics, trade and shipping disruptions, port congestions, cyberattacks and other
factors beyond our or our suppliers’ control could also affect these suppliers’ ability to deliver technologies or components to us or to remain solvent and
operational. Additionally, if our suppliers do not accurately forecast and effectively allocate production or if they are not willing to allocate sufficient
production to us, or face other challenges such as insolvency, it may reduce our access to components and require us to search for new suppliers. The
unavailability of any component or supplier could result in production delays, idle manufacturing facilities, product design changes and loss of access to
important technology and tools for producing and supporting our products, as well as impact our capacity expansion and our ability to fulfill our
obligations under customer contracts. Moreover, significant increases in our production or product design changes by us have required and may in the
future require us to procure additional components in a short amount of time. We have faced in the past, and may face suppliers who are unwilling or
unable to sustainably meet our timelines or our cost, quality and volume needs, which may increase our costs or require us to replace them with other
sources. Finally, as we construct new manufacturing facilities and add production lines to existing facilities, we may experience issues in correspondingly
increasing the level of localized procurement at those facilities. While we believe that we will be able to secure additional or alternate sources or develop
our own replacements for most of our components, there is no assurance that we will be able to do so quickly or at all. Additionally, we may be
unsuccessful in our continuous efforts to negotiate with existing suppliers to obtain cost reductions and avoid unfavorable changes to terms, source less
expensive suppliers for certain parts and redesign certain parts to make them less expensive to produce, especially in the case of increases in materials
pricing. Any of these occurrences may harm our business, prospects, financial condition and operating results.


As the scale of our vehicle production increases, we will also need to accurately forecast, purchase, warehouse and transport components at high
volumes to our manufacturing facilities and servicing locations internationally. If we are unable to accurately match the timing and quantities of
component purchases to our actual needs or successfully implement automation, inventory management and other systems to accommodate the
increased complexity in our supply chain and parts management, we may incur unexpected production disruption, storage, transportation and write-off
costs, which may harm our business and operating results.


**We may be unable to meet our projected construction timelines, costs and production ramps at new factories, or we may**
**experience difficulties in generating and maintaining demand for products manufactured there.**


Our ability to increase production of our vehicles on a sustained basis, make them affordable globally by accessing local supply chains and
workforces and streamline delivery logistics is dependent on the construction and ramp of our current and future factories. The construction of and
commencement and ramp of production at these factories are subject


14


---

Table of Contents


to a number of uncertainties inherent in all new manufacturing operations, including ongoing compliance with regulatory requirements, procurement and
maintenance of construction, environmental and operational licenses and approvals for additional expansion, supply chain constraints, hiring, training and
retention of qualified employees and the pace of bringing production equipment and processes online with the capability to manufacture high-quality
units at scale. Moreover, we will have to establish and ramp production of our proprietary battery cells and packs at our new factories, and we additionally
intend to incorporate sequential design and manufacturing changes into vehicles manufactured at each new factory. If we experience any issues or delays
in meeting our projected timelines, costs, capital efficiency and production capacity for our new factories, expanding and managing teams to implement
iterative design and production changes there, maintaining and complying with the terms of any debt financing that we obtain to fund them or generating
and maintaining demand for the vehicles we manufacture there, our business, prospects, operating results and financial condition may be harmed.


**We may be unable to grow our global product sales, delivery and installation capabilities and our servicing and vehicle charging**
**networks, or we may be unable to accurately project and effectively manage our growth.**


Our success will depend on our ability to continue to expand our sales capabilities. We are targeting a global mass demographic with a broad range
of potential customers, in which we have relatively limited experience projecting demand and pricing our products. We currently produce numerous
international variants at a limited number of factories, and if our specific demand expectations for these variants prove inaccurate, we may not be able to
timely generate deliveries matched to the vehicles that we produce in the same timeframe or that are commensurate with the size of our operations in a
given region. Likewise, as we develop and grow our energy products and services worldwide, our success will depend on our ability to correctly forecast
demand in various markets.


Because we do not have independent dealer networks, we are responsible for delivering all of our vehicles to our customers. As our production
volumes continue to grow, we have faced in the past, and may face challenges with deliveries at increasing volumes, particularly in international markets
requiring significant transit times. We have also deployed a number of delivery models, such as deliveries to customers’ homes and workplaces and
touchless deliveries, but there is no guarantee that such models will be scalable or be accepted globally. Likewise, as we ramp our energy products, we
are working to substantially increase our production and installation capabilities. If we experience production delays or inaccurately forecast demand, our
business, financial condition and operating results may be harmed.


Moreover, because of our unique expertise with our vehicles, we recommend that our vehicles be serviced by us or by certain authorized
professionals. If we experience delays in adding servicing capacity or servicing our vehicles efficiently, or experience unforeseen issues with the reliability
of our vehicles, particularly higher-volume additions to our fleet such as Model 3 and Model Y, it could overburden our servicing capabilities and parts
inventory. Similarly, the increasing number of Tesla vehicles also requires us to continue to rapidly increase the number of our Supercharger stations and
connectors throughout the world.


There is no assurance that we will be able to ramp our business to meet our sales, delivery, installation, servicing and vehicle charging targets
globally, that our projections on which such targets are based will prove accurate or that the pace of growth or coverage of our customer infrastructure
network will meet customer expectations. These plans require significant cash investments and management resources and there is no guarantee that
they will generate additional sales or installations of our products, or that we will be able to avoid cost overruns or be able to hire additional personnel to
support them. As we expand, we will also need to ensure our compliance with regulatory requirements in various jurisdictions applicable to the sale,
installation and servicing of our products, the sale or dispatch of electricity related to our energy products and the operation of Superchargers. If we fail to
manage our growth effectively, it may harm our brand, business, prospects, financial condition and operating results.


**We will need to maintain and significantly grow our access to battery cells, including through the development and manufacture of**
**our own cells, and control our related costs.**


We are dependent on the continued supply of lithium-ion battery cells for our vehicles and energy storage products, and we will require substantially
more cells to grow our business according to our plans. Currently, we rely on suppliers such as Panasonic and Contemporary Amperex Technology Co.
Limited (CATL) for these cells. We have to date fully qualified only a very limited number of such suppliers and have limited flexibility in changing
suppliers. Any disruption in the supply of battery cells from our suppliers could limit production of our vehicles and energy storage products. In the long
term, we intend to supplement cells from our suppliers with cells manufactured by us, which we believe will be more efficient, manufacturable at greater
volumes and more cost-effective than currently available cells. However, our efforts to develop and manufacture such battery cells have required, and
may continue to require, significant investments, and there can be no assurance that we will be able to achieve these targets in the timeframes that we
have planned or at all. If we are


15


---

Table of Contents


unable to do so, we may have to curtail our planned vehicle and energy storage product production or procure additional cells from suppliers at
potentially greater costs, either of which may harm our business and operating results.


In addition, the cost and mass production of battery cells, whether manufactured by our suppliers or by us, depends in part upon the prices and
availability of raw materials such as lithium, nickel, cobalt and/or other metals. The prices for these materials fluctuate and their available supply may be
unstable, depending on market conditions and global demand for these materials. For example, as a result of increased global production of electric
vehicles and energy storage products, suppliers of these raw materials may be unable to meet our volume needs. Additionally, our suppliers may not be
willing or able to reliably meet our timelines or our cost and quality needs, which may require us to replace them with other sources. Any reduced
availability of these materials may impact our access to cells and our growth, and any increases in their prices may reduce our profitability if we cannot
recoup such costs through increased prices. Moreover, our inability to meet demand and any product price increases may harm our brand, growth,
prospects and operating results.


**Our future growth and success are dependent upon consumers’ demand for electric vehicles and specifically our vehicles in an**
**automotive industry that is generally competitive, cyclical and volatile.**


Though we continue to see increased interest and adoption of electric vehicles, if the market for electric vehicles in general and Tesla vehicles in
particular does not develop as we expect, develops more slowly than we expect, or if demand for our vehicles decreases in our markets or our vehicles
compete with each other, our business, prospects, financial condition and operating results may be harmed.


In addition, electric vehicles still constitute a small percentage of overall vehicle sales. As a result, the market for our vehicles could be negatively
affected by numerous factors, such as:


   - perceptions about electric vehicle features, quality, safety, performance and cost;


   - perceptions about the limited range over which electric vehicles may be driven on a single battery charge, and access to charging facilities;


   - competition, including from other types of alternative fuel vehicles, plug-in hybrid electric vehicles and high fuel-economy internal combustion
engine vehicles;


   - volatility in the cost of oil, gasoline and energy;


   - government regulations and economic incentives and conditions; and


   - concerns about our future viability.


The target demographics for our vehicles are highly competitive. Sales of vehicles in the automotive industry tend to be cyclical in many markets,
which may expose us to further volatility. We also cannot predict the duration or direction of current global trends or their sustained impact on consumer
demand. Ultimately, we continue to monitor macroeconomic conditions to remain flexible and to optimize and evolve our business as appropriate, and
attempt to accurately project demand and infrastructure requirements globally and deploy our production, workforce and other resources accordingly.
Rising interest rates may lead to consumers to increasingly pull back spending, including on our products, which may harm our demand, business and
operating results. If we experience unfavorable global market conditions, or if we cannot or do not maintain operations at a scope that is commensurate
with such conditions or are later required to or choose to suspend such operations again, our business, prospects, financial condition and operating results
may be harmed.


**We face strong competition for our products and services from a growing list of established and new competitors.**


The worldwide automotive market is highly competitive today and we expect it will become even more so in the future. A significant and growing
number of established and new automobile manufacturers, as well as other companies, have entered, or are reported to have plans to enter, the market
for electric and other alternative fuel vehicles, including hybrid, plug-in hybrid and fully electric vehicles, as well as the market for self-driving technology
and other vehicle applications and software platforms. In some cases, our competitors offer or will offer electric vehicles in important markets such as
China and Europe, and/or have announced an intention to produce electric vehicles exclusively at some point in the future. In addition, certain
government and economic incentives which provide benefits to manufacturers who assemble domestically or have local suppliers, may provide a greater
benefit to our competitors, which could negatively impact our profitability. Many of our competitors have significantly more or better-established
resources than we do to devote to the design, development, manufacturing, distribution, promotion, sale and support of their products. Increased
competition could result in our lower vehicle unit sales, price reductions, revenue shortfalls, loss of customers and loss of market share, which may harm
our business, financial condition and operating results.


16


---

Table of Contents


We also face competition in our energy generation and storage business from other manufacturers, developers, installers and service providers of
competing energy technologies, as well as from large utilities. In addition, decreases in the retail or wholesale prices of electricity from utilities or other
renewable energy sources could make our products less attractive to customers and lead to an increased rate of customer defaults.


**Risks Related to Our Operations**


**We may experience issues with lithium-ion cells or other components manufactured at our Gigafactories, which may harm the**
**production and profitability of our vehicle and energy storage products.**


Our plan to grow the volume and profitability of our vehicles and energy storage products depends on significant lithium-ion battery cell production,
including by our partner Panasonic at Gigafactory Nevada. We also produce several vehicle components at our Gigafactories, such as battery modules and
packs and drive units, and manufacture energy storage products. If we are unable to or otherwise do not maintain and grow our respective operations, or
if we are unable to do so cost-effectively or hire and retain highly-skilled personnel there, our ability to manufacture our products profitably would be
limited, which may harm our business and operating results.


Finally, the high volumes of lithium-ion cells and battery modules and packs manufactured by us and by our suppliers are stored and recycled at our
various facilities. Any mishandling of these products may cause disruption to the operation of such facilities. While we have implemented safety
procedures related to the handling of the cells, there can be no assurance that a safety issue or fire related to the cells would not disrupt our operations.
Any such disruptions or issues may harm our brand and business.


**We face risks associated with maintaining and expanding our international operations, including unfavorable and uncertain**
**regulatory, political, economic, tax and labor conditions.**


We are subject to legal and regulatory requirements, political uncertainty and social, environmental and economic conditions in numerous
jurisdictions, including markets in which we generate significant sales, over which we have little control and which are inherently unpredictable. Our
operations in such jurisdictions, particularly as a company based in the U.S., with additional manufacturing operations in China and Europe, create risks
relating to conforming our products to regulatory and safety requirements and charging and other electric infrastructures; organizing local operating
entities; establishing, staffing and managing foreign business locations; attracting local customers; navigating foreign government taxes, regulations and
permit requirements; enforceability of our contractual rights; trade restrictions, customs regulations, tariffs and price or exchange controls; and
preferences in foreign nations for domestically manufactured products. For example, we monitor tax legislation changes on a global basis, including
changes arising as a result of the Organization for Economic Cooperation and Development’s multi-jurisdictional plan of action to address base erosion
and profit shifting. Such conditions may increase our costs, impact our ability to sell our products and require significant management attention, and may
harm our business if we are unable to manage them effectively.


**Our business may suffer if our products or features contain defects, fail to perform as expected or take longer than expected to**
**become fully functional.**


If our products contain design or manufacturing defects, whether relating to our software or hardware, that cause them not to perform as designed
or intended or that require repair, or certain features of our vehicles such as new Autopilot or FSD (Supervised) features take longer than expected to
become enabled, are legally restricted or become subject to onerous regulation, our ability to develop, market and sell our products and services may be
harmed, and we may experience delivery delays, product recalls, allegations of product liability, breach of warranty and related consumer protection
claims and significant warranty and other expenses. While we are continuously working to develop and improve our products’ capability and performance,
there is no guarantee that any incremental changes in the specific software or equipment we deploy in our vehicles over time will not result in initial
functional disparities from prior iterations or will perform as forecast in the timeframe we anticipate, or at all. Although we attempt to remedy any issues
we observe in our products as effectively and rapidly as possible, such efforts may not be timely, may hamper production or may not completely satisfy
our customers. We have performed, and continue to perform, extensive internal testing on our products and features, though, like the rest of the industry,
we currently have a limited frame of reference by which to evaluate certain aspects of their long-term quality, reliability, durability and performance
characteristics, including exposure to or consequence of external attacks. While we attempt to identify and address or remedy defects we identify preproduction and sale, there may be latent defects that we may be unable to detect or control for in our products, and thereby address, prior to their sale to
or installation for customers.


17


---

Table of Contents


**We may be required to defend or insure against product liability claims.**


The automobile industry generally experiences significant product liability claims, and as such we face the risk of such claims in the event our
vehicles do not perform or are claimed to not have performed as expected. As is true for other automakers, our vehicles have been involved and we
expect in the future will be involved in accidents resulting in death or personal injury, and such accidents where Autopilot, Enhanced Autopilot or FSD
(Supervised) features are engaged are the subject of significant public attention, especially in light of NHTSA’s Standing General Order requiring reports
regarding certain crashes involving vehicles with advanced driver assistance systems. We have experienced, and we expect to continue to face, claims
and regulatory scrutiny arising from or related to misuse or claimed failures or alleged misrepresentations of such new technologies that we are
pioneering. In addition, the battery packs that we produce make use of lithium-ion cells. On rare occasions, lithium-ion cells can rapidly release the energy
they contain by venting smoke and flames in a manner that can ignite nearby materials as well as other lithium-ion cells. While we have designed our
battery packs to passively contain any single cell’s release of energy without spreading to neighboring cells, there can be no assurance that a field or
testing failure of our vehicles or other battery packs that we produce will not occur, in particular due to a high-speed crash. Likewise, as our solar energy
systems and energy storage products generate and store electricity, they have the potential to fail or cause injury to people or property. Any product
liability claim may subject us to lawsuits and substantial monetary damages, product recalls or redesign efforts, and even a meritless claim may require
us to defend it, all of which may generate negative publicity and be expensive and time-consuming. In most jurisdictions, we generally self-insure against
the risk of product liability claims for vehicle exposure, meaning that any product liability claims will likely have to be paid from company funds and not by
insurance.


**We will need to maintain public credibility and confidence in our long-term business prospects in order to succeed.**


In order to maintain and grow our business, we must maintain credibility and confidence among customers, suppliers, analysts, investors, ratings
agencies and other parties in our long-term financial viability and business prospects. Maintaining such confidence may be challenging due to our limited
operating history relative to established competitors; customer unfamiliarity with our products; any delays we may experience in scaling manufacturing,
delivery and service operations to meet demand; competition and uncertainty regarding the future of electric vehicles or our other products and services;
our quarterly production and sales performance compared with market expectations; and other factors including those over which we have no control. In
particular, Tesla’s products, business, results of operations, and statements and actions of Tesla and its management are subject to significant amounts of
commentary by a range of third parties. Such attention can include criticism, which may be exaggerated or unfounded, such as speculation regarding the
sufficiency or stability of our management team. Any such negative perceptions, whether caused by us or not, may harm our business and make it more
difficult to raise additional funds if needed.


**We may be unable to effectively grow, or manage the compliance, residual value, financing and credit risks related to, our various**
**financing programs.**


We offer financing arrangements for our vehicles in North America, Europe and Asia primarily ourselves and through various financial institutions.
We also currently offer vehicle financing arrangements directly through our local subsidiaries in certain markets. Depending on the country, such
arrangements are available for specified models and may include operating leases directly with us under which we typically receive only a very small
portion of the total vehicle purchase price at the time of lease, followed by a stream of payments over the term of the lease. We have also offered various
arrangements for customers of our solar energy systems whereby they pay us a fixed payment to lease or finance the purchase of such systems or
purchase electricity generated by them. If we do not successfully monitor and comply with applicable national, state and/or local financial regulations and
consumer protection laws governing these transactions, we may become subject to enforcement actions or penalties.


The profitability of any directly-leased vehicles returned to us at the end of their leases depends on our ability to accurately project our vehicles’
residual values at the outset of the leases, and such values may fluctuate prior to the end of their terms depending on various factors such as supply and
demand of our used vehicles, economic cycles, legislative changes and the pricing of new vehicles. We have made in the past and may make in the future
certain adjustments to our prices from time to time in the ordinary course of business, which may impact the residual values of our vehicles and reduce
the profitability of our vehicle leasing program. The funding and growth of this program also rely on our ability to secure adequate financing and/or
business partners. If we are unable to adequately fund our leasing program through internal funds, partners or other financing sources, and compelling
alternative financing programs are not available for our customers who may expect or need such options, we may be unable to grow our vehicle
deliveries. Furthermore, if our vehicle leasing business grows substantially, our business may suffer if we cannot effectively manage the resulting greater
levels of residual risk.


18


---

Table of Contents


Similarly, we have provided residual value guarantees to vehicle customers and partners for certain financing programs, under which such
counterparties may sell their vehicles through various remarketing channels. However, actual resale values are subject to fluctuations over the term of
the financing arrangements, such as from one or more of the factors discussed above. If the actual resale values of any vehicles resold by our vehicle
customers and partners are lower than the residual values we have agreed to with them, the residual value guarantees may be triggered and, as a result,
our financial condition and operating results may be harmed.


Finally, our vehicle and solar energy system financing programs and our energy storage sales programs also expose us to customer credit risk. In
the event of a widespread economic downturn or other catastrophic event, our customers may be unable or unwilling to satisfy their payment obligations
to us on a timely basis or at all. If a significant number of our customers default, we may incur substantial credit losses and/or impairment charges with
respect to the underlying assets.


**We must manage ongoing obligations under our agreement with the Research Foundation for the State University of New York**
**relating to our Gigafactory New York.**


We are party to an operating lease and a research and development agreement through the State University of New York (the “SUNY Foundation”).
These agreements provide for the construction and use of our Gigafactory New York, which we have primarily used for the development and production of
our Solar Roof and other solar products and components, energy storage components and Supercharger components, and for other lessor-approved
functions. Under this agreement, we are obligated to, among other things, meet employment targets as well as specified minimum numbers of personnel
in the State of New York and in Buffalo, New York and spend or incur $5.00 billion in combined capital, operational expenses, costs of goods sold and
other costs in the State of New York during a period that was initially 10 years beginning April 30, 2018. As of December 31, 2024, we have met and
expect to meet the requirements under this arrangement, as may be modified and discussed from time to time, based on our current and anticipated
level of operations. While we expect to have and grow significant operations at Gigafactory New York and the surrounding Buffalo area, any failure by us
in any year over the course of the term of the agreement to meet all applicable future obligations may result in our incurring financial liabilities in the
form of “program payments” which would not be expected to have a material adverse effect to our financial operations, the termination of our lease at
Gigafactory New York, and/or the need to adjust certain of our operations. Any of the foregoing events may harm our business, financial condition and
operating results.


**If we are unable to attract, hire and retain key employees and qualified personnel, our ability to compete may be harmed.**


The loss of the services of any of our key employees or any significant portion of our workforce could disrupt our operations or delay the
development, introduction and ramp of our products and services. In particular, we are highly dependent on the services of Elon Musk, Technoking of
Tesla and our Chief Executive Officer. None of our key employees is bound by an employment agreement for any specific term and we may not be able to
successfully attract and retain senior leadership necessary to grow our business. Our future success also depends upon our ability to attract, hire and
retain a large number of engineering, manufacturing, marketing, sales and delivery, service, installation, technology and support personnel, especially to
support our planned high-volume product sales, market and geographical expansion and technological innovations. If we are not successful in managing
these risks, our business, financial condition and operating results may be harmed.


Employees may leave Tesla or choose other employers over Tesla due to various factors, such as a very competitive labor market for talented
individuals with automotive or technology experience, or any negative publicity related to us. In regions where we have or will have operations,
particularly significant engineering and manufacturing centers, there is strong competition for individuals with skillsets needed for our business, including
specialized knowledge of electric vehicles, engineering and electrical and building construction expertise. We also compete with both mature and
prosperous companies that have far greater financial resources than we do and start-ups and emerging companies that promise short-term growth
opportunities.


Finally, our compensation philosophy for all of our personnel reflects our startup origins, with an emphasis on equity-based awards and benefits in
order to closely align their incentives with the long-term interests of our stockholders. We periodically seek and obtain approval from our stockholders for
future increases to the number of awards available under our equity incentive and employee stock purchase plans. If we are unable to obtain the requisite
stockholder approvals for such future increases, we may have to expend additional cash to compensate our employees and our ability to retain and hire
qualified personnel may be harmed.


19


---

Table of Contents


**We are highly dependent on the services of Elon Musk, Technoking of Tesla and our Chief Executive Officer.**


We are highly dependent on the services of Elon Musk, Technoking of Tesla and our Chief Executive Officer. Although Mr. Musk spends significant
time with Tesla and is highly active in our management, he does not devote his full time and attention to Tesla. For example: Mr. Musk also currently
holds management positions at Space Exploration Technologies Corp., X Corp., X.AI Corp., Neuralink Corp. and The Boring Company, and is involved in
other ventures and with the Department of Government Efficiency.


**Our information technology systems or data, or those of our service providers or customers or users could be subject to cyber-**
**attacks or other security incidents, which could result in data breaches, intellectual property theft, claims, litigation, regulatory**
**investigations, significant liability, reputational damage and other adverse consequences.**


We continue to expand our information technology systems as our operations grow, such as product data management, procurement, inventory
management, production planning and execution, sales, service and logistics, dealer management, financial, tax and regulatory compliance systems. This
includes the implementation of new internally developed systems and the deployment of such systems in the U.S. and abroad. While, we maintain
information technology measures designed to protect us against intellectual property theft, data breaches, sabotage and other external or internal cyberattacks or misappropriation, our systems and those of our service providers are potentially vulnerable to malware, ransomware, viruses, denial-of-service
attacks, phishing attacks, social engineering, computer hacking, unauthorized access, exploitation of bugs, defects and vulnerabilities, breakdowns,
damage, interruptions, system malfunctions, power outages, terrorism, acts of vandalism, security breaches, security incidents, inadvertent or intentional
actions by employees or other third parties, and other cyber-attacks.


To the extent any security incident results in unauthorized access or damage to or acquisition, use, corruption, loss, destruction, alteration or
dissemination of our data, including intellectual property and personal information, or our products or vehicles, or for it to be believed or reported that any
of these occurred, it could disrupt our business, harm our reputation, compel us to comply with applicable data breach notification laws, subject us to time
consuming, distracting and expensive litigation, regulatory investigation and oversight, mandatory corrective action, require us to verify the correctness
of database contents, or otherwise subject us to liability under laws, regulations and contractual obligations, including those that protect the privacy and
security of personal information. This could result in increased costs to us and result in significant legal and financial exposure and/or reputational harm.


We also rely on service providers, and similar incidents relating to their information technology systems could also have a material adverse effect on
our business. There have been and may continue to be significant supply chain attacks. Our service providers, including our workforce management
software provider, have been subject to ransomware and other security incidents, and we cannot guarantee that our or our service providers’ systems
have not been breached or that they do not contain exploitable defects, bugs, or vulnerabilities that could result in a security incident, or other disruption
to, our or our service providers’ systems. Our ability to monitor our service providers’ security measures is limited, and, in any event, malicious third
parties may be able to circumvent those security measures.


Further, the implementation, maintenance, segregation and improvement of these systems require significant management time, support and cost,
and there are inherent risks associated with developing, improving and expanding our core systems as well as implementing new systems and updating
current systems, including disruptions to the related areas of business operation. These risks may affect our ability to manage our data and inventory,
procure parts or supplies or manufacture, sell, deliver and service products, adequately protect our intellectual property or achieve and maintain
compliance with, or realize available benefits under, tax laws and other applicable regulations.


Moreover, if we do not successfully implement, maintain or expand these systems as planned, our operations may be disrupted, our ability to
accurately and/or timely report our financial results could be impaired and deficiencies may arise in our internal control over financial reporting, which
may impact our ability to certify our financial results. Moreover, our proprietary information, including intellectual property and personal information,
could be compromised or misappropriated and our reputation may be adversely affected. If these systems or their functionality do not operate as we
expect them to, we may be required to expend significant resources to make corrections or find alternative sources for performing these functions.


20


---

Table of Contents


**Any unauthorized control or manipulation of our products’ systems could result in loss of confidence in us and our products.**


Our products contain complex information technology systems. For example, our vehicles and energy storage products are designed with built-in
data connectivity to accept and install periodic remote updates from us to improve or update their functionality. While we have implemented security
measures intended to prevent unauthorized access to our information technology networks, our products and their systems, malicious entities have
reportedly attempted, and may attempt in the future, to gain unauthorized access to modify, alter and use such networks, products and systems to gain
control of, or to change, our products’ functionality, user interface and performance characteristics or to gain access to data stored in or generated by our
products. We encourage reporting of potential vulnerabilities in the security of our products through our security vulnerability reporting policy, and we
aim to remedy any reported and verified vulnerability. However, there can be no assurance that any vulnerabilities will not be exploited before they can
be identified, or that our remediation efforts are or will be successful.


Any unauthorized access to or control of our products or their systems or any loss of data could result in legal claims or government investigations.
In addition, regardless of their veracity, reports of unauthorized access to our products, their systems or data, as well as other factors that may result in
the perception that our products, their systems or data are capable of being hacked, may harm our brand, prospects and operating results. We have been
the subject of such reports in the past.


**Our business may be adversely affected by any disruptions caused by union activities.**


It is not uncommon for employees of certain trades at companies such as ours to belong to a union, which can result in higher employee costs and
increased risk of work stoppages. Moreover, regulations in some jurisdictions outside of the U.S. mandate employee participation in industrial collective
bargaining agreements and work councils with certain consultation rights with respect to the relevant companies’ operations. Although we work diligently
to provide the best possible work environment for our employees, they may still decide to join or seek recognition to form a labor union, or we may be
required to become a union signatory. From time to time, labor unions have engaged in campaigns to organize certain of our operations, as part of which
such unions have filed unfair labor practice charges against us with the National Labor Relations Board (the “NLRB”), and they may do so in the future.
Any unfavorable ultimate outcome for Tesla may have a negative impact on the perception of Tesla’s treatment of our employees. Furthermore, we are
directly or indirectly dependent upon companies with unionized work forces, such as suppliers and trucking and freight companies. Any work stoppages or
strikes organized by such unions could delay the manufacture and sale of our products and may harm our business and operating results.


**We may choose to or be compelled to undertake product recalls or take other similar actions.**


As a manufacturing company, we must manage the risk of product recalls with respect to our products. Recalls for our vehicles have resulted from
various hardware and software-related safety or non-compliance determinations. In addition to recalls initiated by us for various causes, testing of or
investigations into our products by government regulators or industry groups may compel us to initiate product recalls or may result in negative public
perceptions about the safety of our products, even if we disagree with the defect determination or have data that contradicts it. In the future, we may
voluntarily or involuntarily initiate recalls or field actions if any of our products are determined by us or a regulator to contain a safety defect or be
noncompliant with applicable laws and regulations, such as U.S. Federal Motor Vehicle Safety Standards, or provide certain functionalities. Such recalls or
field actions, whether voluntary or involuntary or caused by systems or components engineered or manufactured by us or our suppliers, could result in
significant expense, supply chain complications and service burdens, and may harm our brand, business, prospects, financial condition and operating
results.


**Our current and future warranty reserves may be insufficient to cover future warranty claims.**


We provide a manufacturer’s warranty on all new and used Tesla vehicles we sell directly to customers. We also provide certain warranties with
respect to the energy generation and storage systems we sell, including on their installation and maintenance. For components not manufactured by us,
we generally pass through to our customers the applicable manufacturers’ warranties, but may retain some warranty responsibilities for some or all of the
life of such components. As part of our energy generation and storage system contracts, we may provide the customer with performance guarantees that
guarantee that the underlying system will meet or exceed the minimum energy generation or other energy performance requirements specified in the
contract. Under these performance guarantees, we generally bear the risk of electricity production or other performance shortfalls, including in some
cases shortfalls caused by failures in components from third party manufacturers. These risks are exacerbated in the event such manufacturers cease
operations or fail to honor their warranties.


21


---

Table of Contents


If our warranty reserves are inadequate to cover future warranty claims on our products, our financial condition and operating results may be
harmed. Warranty reserves include our management’s best estimates of the projected costs to repair or to replace items under warranty, which are based
on actual claims incurred to date and an estimate of the nature, frequency and costs of future claims. Such estimates are inherently uncertain and
changes to our historical or projected experience, especially with respect to products that we have introduced relatively recently and/or that we expect to
produce at significantly greater volumes than our past products, may cause material changes to our warranty reserves in the future.


**Our insurance coverage strategy may not be adequate to protect us from all business risks.**


We may be subject, in the ordinary course of business, to losses resulting from products liability, accidents, acts of God and other claims against us,
for which we may have no insurance coverage. As a general matter, we do not maintain as much insurance coverage as many other companies do, and in
some cases, we do not maintain any at all. Additionally, the policies that we do have may include significant deductibles or self-insured retentions, policy
limitations and exclusions, and we cannot be certain that our insurance coverage will be sufficient to cover all future losses or claims against us. A loss
that is uninsured or which exceeds policy limits may require us to pay substantial amounts, which may harm our financial condition and operating results.


**Our debt agreements contain covenant restrictions that may limit our ability to operate our business.**


The terms of certain of our debt facilities contain, and any of our other future debt agreements may contain, covenant restrictions that may limit our
ability to operate our business, including restrictions on our and/or our subsidiaries’ ability to, among other things, incur additional debt or create liens. In
addition, under certain circumstances we are required to maintain a certain amount of liquidity. As a result of these covenants, our ability to respond to
changes in business and economic conditions and engage in beneficial transactions, including to obtain additional financing as needed, may be restricted.
Furthermore, our failure to comply with our debt covenants could result in a default under our debt agreements, which could permit the holders to
accelerate our obligation to repay the debt. If any of our debt is accelerated, we may not have sufficient funds available to repay it.


**Additional funds may not be available to us when we need or want them.**


Our business and our future plans for expansion are capital-intensive, and the specific timing of cash inflows and outflows may fluctuate
substantially from period to period. We may need or want to raise additional funds through the issuance of equity, equity-related or debt securities or
through obtaining credit from financial institutions to fund, together with our principal sources of liquidity, the costs of developing and manufacturing our
current or future products, to pay any significant unplanned or accelerated expenses or for new significant strategic investments, or to refinance our
significant consolidated indebtedness, even if not required to do so by the terms of such indebtedness. We cannot be certain that additional funds will be
available to us on favorable terms when required, or at all. If we cannot raise additional funds when we need them, our financial condition, results of
operations, business and prospects could be materially and adversely affected.


**We may be negatively impacted by any early obsolescence of our manufacturing equipment.**


We depreciate the cost of our manufacturing equipment over their expected useful lives. However, product cycles or manufacturing technology may
change periodically, and we may decide to update our products or manufacturing processes more quickly than expected. Moreover, improvements in
engineering and manufacturing expertise and efficiency may result in our ability to manufacture our products using less of our currently installed
equipment. Alternatively, as we ramp and mature the production of our products to higher levels, we may discontinue the use of already installed
equipment in favor of different or additional equipment. The useful life of any equipment that would be retired early as a result would be shortened,
causing the depreciation on such equipment to be accelerated, and our results of operations may be harmed.


**There is no guarantee that we will have sufficient cash flow from our business to pay our indebtedness or that we will not incur**
**additional indebtedness.**


As of December 31, 2024, we and our subsidiaries had outstanding $7.91 billion in aggregate principal amount of indebtedness (see Note 10, Debt,
to the consolidated financial statements included elsewhere in this Annual Report on Form 10-K). Our consolidated indebtedness may increase our
vulnerability to any generally adverse economic and industry conditions. We and our subsidiaries may, subject to the limitations in the terms of our
existing and future indebtedness, incur additional debt, secure existing or future debt or recapitalize our debt.


22


---

Table of Contents


Our ability to make scheduled payments of the principal and interest on our indebtedness when due, or to refinance our indebtedness as we may
need or desire, depends on our future performance, which is subject to economic, financial, competitive and other factors beyond our control. Our
business may not continue to generate cash flow from operations in the future sufficient to satisfy our obligations under our existing indebtedness and
any future indebtedness we may incur, and to make necessary capital expenditures. If we are unable to generate such cash flow, we may be required to
adopt one or more alternatives, such as reducing or delaying investments or capital expenditures, selling assets, refinancing or obtaining additional equity
capital on terms that may be onerous or highly dilutive. Our ability to refinance existing or future indebtedness will depend on the capital markets and our
financial condition at such time. In addition, our ability to make payments may be limited by law, by regulatory authority or by agreements governing our
future indebtedness. We may not be able to engage in these activities on desirable terms or at all, which may result in a default on our existing or future
indebtedness and harm our financial condition and operating results.


**We are exposed to fluctuations in currency exchange rates.**


We transact business globally in multiple currencies and have foreign currency risks related to our revenue, costs of revenue, operating expenses
and localized subsidiary debt denominated in currencies other than the U.S. dollar. To the extent we have significant revenues denominated in such
foreign currencies, any strengthening of the U.S. dollar would tend to reduce our revenues as measured in U.S. dollars, as we have historically
experienced, and are currently experiencing. We have also experienced, and will continue to experience, fluctuations in our net income as a result of
gains (losses) on the settlement and the re-measurement of monetary assets and liabilities denominated in currencies that are not the local currency
(primarily consisting of our intercompany and cash and cash equivalents balances). In addition, a portion of our costs and expenses have been, and we
anticipate will continue to be, denominated in foreign currencies. If we do not have fully offsetting revenues in these currencies and if the value of the U.S.
dollar depreciates significantly against these currencies, our costs as measured in U.S. dollars as a percent of our revenues will correspondingly increase
and our margins will suffer. As a result, our operating results may be harmed.


**We may not be able to adequately protect or defend ourselves against intellectual property infringement claims, which may be**
**time-consuming and expensive, or affect the freedom to operate our business.**


Our competitors or other third parties may hold or obtain patents, copyrights, trademarks or other proprietary rights that could prevent, limit or
interfere with our ability to make, use, develop, sell or market our products and services, which could make it more difficult for us to operate our business.
From time to time, the holders of such intellectual property rights may assert their rights and urge us to take licenses and/or may bring suits alleging
infringement or misappropriation of such rights, which could result in substantial costs, negative publicity and management attention, regardless of merit.


In addition, the effective protection for our brands, technologies, and proprietary information may be limited or unavailable in certain countries,
making it difficult to protect our intellectual property from misappropriation or infringement. Although we make reasonable efforts to maintain the
confidentiality of our proprietary information, we cannot guarantee that these actions will deter or prevent misappropriation of our intellectual property.
The theft or unauthorized use or publication of our trade secrets and confidential information could affect our competitive position.


While we endeavor to obtain and protect the intellectual property rights that we expect will allow us to retain or advance our strategic initiatives in
these circumstances, there can be no assurance that we will be able to adequately identify and protect the portions of intellectual property that are
strategic to our business, or mitigate the risk of potential suits or other legal demands by third parties. Accordingly, we may consider the entering into
licensing agreements with respect to such rights, although no assurance can be given that such licenses can be obtained on acceptable terms or that
litigation will not occur, and such licenses and associated litigation could significantly increase our operating expenses. Further, if we are determined to
have or believe there is a high likelihood that we have infringed upon a third party’s intellectual property rights, we may be required to cease making,
selling or incorporating certain components or intellectual property into the goods and services we offer, to pay substantial damages and/or license
royalties, to redesign our products and services and/or to establish and maintain alternative branding for our products and services. In the event that we
are required to take one or more such actions, our brand, business, financial condition and operating results may be harmed.


**Increased scrutiny and changing expectations from stakeholders with respect to the Company’s ESG practices may result in**
**additional costs or risks.**


Companies across many industries are facing increasing scrutiny related to their environmental, social and governance (ESG) practices. Investor
advocacy groups, certain institutional investors, investment funds and other influential investors are also increasingly focused on ESG practices and in
recent years have placed increasing importance on the non-financial impacts of their investments. While our mission is to accelerate the world’s transition
to sustainable


23


---

Table of Contents


energy, if our ESG practices do not meet investor or other industry stakeholder expectations, which continue to evolve, we may incur additional costs and
our brand, ability to attract and retain qualified employees and business may be harmed. Compliance with any current or future legal requirements on
these topics may result in additional costs or risks to us, including harm to our reputation, reduction in customer demand, and increased legal and
operational risks.


**Our operations could be adversely affected by events outside of our control, such as natural disasters, wars or health epidemics.**


We may be impacted by natural disasters, wars, health epidemics, weather conditions, the long-term effects of climate change, power outages or
other events outside of our control. For example, our Fremont Factory and Gigafactory Nevada are located in seismically active regions in Northern
California and Nevada, and our Gigafactory Shanghai is located in a flood-prone area. Moreover, the area in which our Gigafactory Texas is located
experienced severe winter storms in the first quarter of 2021 that had a widespread impact on utilities and transportation. If major disasters such as
earthquakes, floods or other climate-related events occur, or our information system or communication breaks down or operates improperly, our
headquarters and production facilities may be seriously damaged, or we may have to stop or delay production and shipment of our products. Also, the
broader consequences in the current conflict between Russia and Ukraine, which may include further embargoes, regional instability and geopolitical
shifts; airspace bans relating to certain routes, or strategic decisions to alter certain routes; and potential retaliatory action by the Russian government
against companies, and the extent of the conflict on our business and operating results cannot be predicted. We may incur expenses or delays relating to
such events outside of our control, which could have a material adverse impact on our business, operating results and financial condition.


**Risks Related to Government Laws and Regulations**


**Demand for our products and services may be impacted by the status of government and economic incentives supporting the**
**development and adoption of such products.**


Government and economic incentives that support the development and adoption of electric vehicles in the U.S. and abroad, including certain tax
exemptions, tax credits and rebates, may be reduced, eliminated, amended or exhausted from time to time. For example, previously available incentives
favoring electric vehicles in certain areas have expired or were cancelled or temporarily unavailable, and in some cases were not eventually replaced or
reinstituted, which may have negatively impacted sales. In addition, certain government and economic incentives may also be implemented or amended
to provide benefits to manufacturers who assemble domestically, have local suppliers or have other characteristics that may not apply to Tesla. Such
developments could negatively impact demand for our vehicles, and we and our customers may have to adjust to them, including through pricing
modifications.


In addition, certain governmental rebates, tax credits and other financial incentives that are currently available with respect to our solar and energy
storage product businesses allow us to lower our costs and encourage customers to buy our products and investors to invest in our solar financing funds.
However, these incentives may expire when the allocated funding is exhausted, reduced or terminated as renewable energy adoption rates increase,
sometimes without warning. Likewise, in jurisdictions where net metering is currently available, our customers receive bill credits from utilities for energy
that their solar energy systems generate and export to the grid in excess of the electric load they use. The benefit available under net metering has been
or has been proposed to be reduced, altered or eliminated in several jurisdictions, and has also been contested and may continue to be contested before
the Federal Energy Regulatory Commission. Any reductions or terminations of such incentives may harm our business, prospects, financial condition and
operating results by making our products less competitive for customers, increasing our cost of capital and adversely impacting our ability to attract
investment partners and to form new financing funds for our solar and energy storage assets.


Finally, we and our fund investors claim these U.S. federal tax credits and certain state incentives in amounts based on independently appraised fair
market values of our solar and energy storage systems. Some governmental authorities have audited such values and in certain cases have determined
that these values should be lower, and they may do so again in the future. Such determinations may result in adverse tax consequences and/or our
obligation to make indemnification or other payments to our funds or fund investors.


**We are subject to evolving laws and regulations that could impose substantial costs, legal prohibitions or unfavorable changes**
**upon our operations or products.**


Our business operations are and will continue to be subject to complex environmental, occupational, health and safety laws and regulations at
numerous jurisdictional levels in the U.S., China, Germany and other locations abroad, including laws relating to the use, handling, storage, recycling,
disposal and/or human exposure to hazardous materials,


24


---

Table of Contents


product material inputs and post-consumer products and with respect to constructing, expanding and maintaining our facilities. New, or changes in,
environmental and climate change laws, regulations or rules could also lead to increased costs of compliance, including remediations of any discovered
issues, and changes to our operations, which may be significant, and any failures to comply could result in significant expenses, delays or fines. In
addition, as we have increased our operations, we are and may continue to be subject to increased scrutiny, including litigation and government
investigations, that we will need to defend against. If we are unable to successfully defend ourselves in such litigation or government investigations, it
may harm our brand, ability to attract and retain qualified employees, business and financial condition. We are also subject to laws and regulations
applicable to the supply, manufacture, import, sale, service and performance of our products both domestically and abroad. For example, in countries
outside of the U.S., we are required to meet standards relating to vehicle safety, fuel economy and emissions that are often materially different from
equivalent requirements in the U.S., thus resulting in additional investment into the vehicles and systems to ensure regulatory compliance in all countries.
This process may include official review and certification of our vehicles by foreign regulatory agencies prior to market entry, as well as compliance with
foreign reporting and recall management systems requirements.


In particular, we offer in our vehicles in certain markets Autopilot and FSD (Supervised) features that today assist drivers with certain tedious and
potentially dangerous aspects of road travel, but which currently require drivers to remain fully engaged in the driving operation. We are continuing to
develop our Autopilot and FSD (Supervised) technology. There are a variety of international, federal and state regulations that may apply to, and may
adversely affect, the design and performance, sale, marketing, registration and operation of Autopilot and FSD (Supervised), and future capability,
including autonomous vehicles that may not be operated by a human driver. This includes many existing vehicle standards that were not originally
intended to apply to vehicles that may not be operated by a human driver. Such regulations, including their enforcement or the enforcement policy
associated with the regulations, continue to rapidly change, which increases the likelihood of a patchwork of complex or conflicting regulations, or may
delay, restrict or prohibit the availability of certain functionalities and vehicle designs, which could adversely affect our business.


Finally, as a manufacturer, installer and service provider with respect to solar generation and energy storage systems, a supplier of electricity
generated and stored by certain of the solar energy and energy storage systems we install for customers, and a provider of grid services through virtual
power plant models, we are impacted by federal, state and local regulations and policies concerning the import or export of components, electricity
pricing, the interconnection of electricity generation and storage equipment with the electrical grid and the sale of electricity generated by third partyowned systems. If regulations and policies are introduced that adversely impact the import or export of components, or the interconnection, maintenance
or use of our solar and energy storage systems, they could deter potential customers from purchasing our solar and energy storage products and
services, threaten the economics of our existing contracts and cause us to cease solar and energy storage system sales and services in the relevant
jurisdictions, which may harm our business, financial condition and operating results.


**Any failure by us to comply with a variety of U.S. and international privacy and consumer protection laws may harm us.**


Any failure by us or our vendors or other business partners to comply with our public privacy notice or with federal, state or international privacy,
data protection, artificial intelligence or security laws or regulations relating to the processing, collection, use, retention, security and transfer of
personally identifiable information could result in regulatory or litigation-related actions against us, legal liability, fines, damages, ongoing audit
requirements and other significant costs. Substantial expenses and operational changes may be required in connection with maintaining compliance with
such laws, and even an unsuccessful challenge by customers or regulatory authorities of our activities could result in adverse publicity and could require a
costly response from and defense by us. In addition, certain privacy laws are still subject to a high degree of uncertainty as to their interpretation,
application and impact, and may require extensive system and operational changes, be difficult to implement, increase our operating costs, adversely
impact the cost or attractiveness of the products or services we offer, or result in adverse publicity and harm our reputation. For example, the General
Data Protection Regulation applies to the processing of personal information collected from individuals located in the European Union requiring certain
data protection measures when handling, with a significant risk of fines for noncompliance. Similarly, our North American operations are subject to
complex and changing federal and US state-specific data privacy laws and regulations, such as the California Consumer Privacy Act which imposes certain
legal obligations on our use and processing of personal information related to California residents. Finally, additional privacy and cybersecurity laws have
come into effect in China, and other jurisdictions where Tesla has a market presence.


These laws continue to develop and may be inconsistent from jurisdiction to jurisdiction. Complying with emerging and changing requirements may
cause us to incur substantial costs and make enhancements to relevant data practices. Noncompliance could result in significant penalties or legal
liability.


25


---

Table of Contents


In addition to the risks related to general privacy regulation, we may also be subject to specific vehicle manufacturer obligations relating to
cybersecurity, data privacy and data localization requirements which place additional risks to our international operations. Risks and penalties could
include ongoing audit requirements, data protection authority investigations, legal proceedings by international governmental entities or others resulting
in mandated disclosure of sensitive data or other commercially unfavorable terms. Notwithstanding our efforts to protect the security and integrity of our
customers’ personal information, we may be required to expend significant resources to comply with data breach requirements if, for example, third
parties improperly obtain and use the personal information of our customers or we otherwise experience a data loss with respect to the personal
information we process and handle. A major breach of our network security and systems may occur despite defensive measures, and may result in fines,
penalties and damages and harm our brand, prospects and operating results.


**We could be subject to liability, penalties and other restrictive sanctions and adverse consequences arising out of certain**
**governmental investigations and proceedings.**


We are cooperating with certain government investigations as discussed in Note 14, Commitments and Contingencies, to the consolidated financial
statements included elsewhere in this Annual Report on Form 10-K. To our knowledge, no government agency in any such ongoing investigation has
concluded that any wrongdoing occurred. However, we cannot predict the outcome or impact of any such ongoing matters, and there exists the possibility
that we could be subject to liability, penalties and other restrictive sanctions and adverse consequences if the SEC, the U.S. Department of Justice or any
other government agency were to pursue legal action in the future. Moreover, we expect to incur costs in responding to related requests for information
and subpoenas, and if instituted, in defending against any governmental proceedings.


**We may face regulatory challenges to or limitations on our ability to sell vehicles directly.**


While we intend to continue to leverage our most effective sales strategies, including sales through our website, we may not be able to sell our
vehicles through our own stores in certain states in the U.S. with laws that may be interpreted to impose limitations on this direct-to-consumer sales
model. It has also been asserted that the laws in some states limit our ability to obtain dealer licenses from state motor vehicle regulators, and such
assertions persist. In certain locations, decisions by regulators permitting us to sell vehicles have been, and may be, challenged by dealer associations
and others as to whether such decisions comply with applicable state motor vehicle industry laws. We have prevailed in many of these lawsuits and such
results have reinforced our continuing belief that state franchise laws were not intended to apply to a manufacturer that does not have franchise dealers
anywhere in the world. In some states, there have also been regulatory and legislative efforts by dealer associations to propose laws that, if enacted,
would prevent us from obtaining dealer licenses in their states given our current sales model. A few states have passed legislation that clarifies our ability
to operate, but at the same time limits the number of dealer licenses we can obtain or stores that we can operate. The application of state laws applicable
to our operations continues to be difficult to predict.


Internationally, there may be laws in jurisdictions we have not yet entered or laws we are unaware of in jurisdictions we have entered that may
restrict our sales or other business practices. Even for those jurisdictions we have analyzed, the laws in this area can be complex, difficult to interpret and
may change over time. Continued regulatory limitations and other obstacles interfering with our ability to sell vehicles directly to consumers may harm
our financial condition and operating results.


**Risks Related to the Ownership of Our Common Stock**


**The trading price of our common stock is likely to continue to be volatile.**


The trading price of our common stock has been highly volatile and could continue to be subject to wide fluctuations in response to various factors,
some of which are beyond our control. Our common stock has experienced over the last 52 weeks an intra-day trading high of $488.54 per share and a
low of $138.80 per share. The stock market in general, and the market for technology companies in particular, has experienced extreme price and volume
fluctuations that have often been unrelated or disproportionate to the operating performance of those companies. In particular, a large proportion of our
common stock has been historically and may in the future be traded by short sellers which may put pressure on the supply and demand for our common
stock, further influencing volatility in its market price. Public perception of our company or management and other factors outside of our control may
additionally impact the stock price of companies like us that garner a disproportionate degree of public attention, regardless of actual operating
performance. In addition, in the past, following periods of volatility in the overall market or the market price of our shares, securities


26


---

Table of Contents


class action litigation has been filed against us. While we defend such actions vigorously, any judgment against us or any future stockholder litigation
could result in substantial costs and a diversion of our management’s attention and resources.


**Our financial results may vary significantly from period to period due to fluctuations in our operating costs and other factors.**


We expect our period-to-period financial results to vary based on our operating costs, which we anticipate will fluctuate as the pace at which we
continue to design, develop and manufacture new products and increase production capacity by expanding our current manufacturing facilities and
adding future facilities, may not be consistent or linear between periods. Additionally, our revenues from period to period may fluctuate as we introduce
existing products to new markets for the first time and as we develop and introduce new products. As a result of these factors, we believe that quarter-toquarter comparisons of our financial results, especially in the short term, are not necessarily meaningful and that these comparisons cannot be relied
upon as indicators of future performance. Moreover, our financial results may not meet expectations of equity research analysts, ratings agencies or
investors, who may be focused only on short-term quarterly financial results. If any of this occurs, the trading price of our stock could fall substantially,
either suddenly or over time.


**We may fail to meet our publicly announced guidance or other expectations about our business, which could cause our stock price**
**to decline.**


We provide from time to time guidance regarding our expected financial and business performance. Correctly identifying key factors affecting
business conditions and predicting future events is inherently an uncertain process, and our guidance may not ultimately be accurate and has in the past
been inaccurate in certain respects, such as the timing of new product manufacturing ramps. Our guidance is based on certain assumptions such as those
relating to anticipated production and sales volumes (which generally are not linear throughout a given period), average sales prices, supplier and
commodity costs and planned cost reductions. If our guidance varies from actual results, such as due to our assumptions not being met or the impact on
our financial performance that could occur as a result of various risks and uncertainties, the market value of our common stock could decline significantly.


**If Elon Musk were forced to sell shares of our common stock, either that he has pledged to secure certain personal loan obligations,**
**or in satisfaction of other obligations, such sales could cause our stock price to decline.**


Certain banking institutions have made extensions of credit to Elon Musk, our Chief Executive Officer, a portion of which was used to purchase
shares of common stock in certain of our public offerings and private placements at the same prices offered to third-party participants in such offerings
and placements. We are not a party to these loans, which are partially secured by pledges of a portion of the Tesla common stock currently owned by Mr.
Musk. If the price of our common stock were to decline substantially, Mr. Musk may be forced by one or more of the banking institutions to sell shares of
Tesla common stock to satisfy his loan obligations if he could not do so through other means. Any such sales could cause the price of our common stock
to decline further. Further, Mr. Musk from time to time may commit to investing in significant business or other ventures, and as a result, be required to
sell shares of our common stock in satisfaction of such commitments.


**Anti-takeover provisions contained in our governing documents, applicable laws and certain of our debt facilities could impair a**
**takeover attempt.**


Our certificate of formation and bylaws afford certain rights and powers to our board of directors that may facilitate the delay or prevention of an
acquisition that it deems undesirable. We are also subject to Section 21.606 of the Texas Business Organizations Code and other provisions of Texas law
that limit the ability of stockholders in certain situations to effect certain business combinations. In addition, a change in control may cause the
acceleration of certain of our debt facilities. Any of the foregoing provisions and terms that has the effect of delaying or deterring a change in control
could limit the opportunity for our stockholders to receive a premium for their shares of our common stock, and could also affect the price that some
investors are willing to pay for our common stock.


**ITEM 1B. UNRESOLVED STAFF COMMENTS**


None.


27


---

**ITEM 1C. CYBERSECURITY**


**Cybersecurity Risk Management and Strategy**


We recognize the importance of assessing, identifying, and managing material risks associated with cybersecurity threats, as such term is defined in
Item 106(a) of Regulation S-K. These risks include, among other things: operational risks, intellectual property theft, fraud, extortion, harm to employees
or customers and violation of data privacy or security laws.


Identifying and assessing cybersecurity risk is integrated into our overall risk management systems and processes. Cybersecurity risks related to our
business, technical operations, privacy and compliance issues are identified and addressed through a multi-faceted approach including third party
assessments, internal IT Audit, IT security, governance, risk and compliance reviews. To defend, detect and respond to cybersecurity incidents, we,
among other things: conduct proactive privacy and cybersecurity reviews of systems and applications, audit applicable data policies, perform penetration
testing using external third-party tools and techniques to test security controls, operate a bug bounty program to encourage proactive vulnerability
reporting, conduct employee training, monitor emerging laws and regulations related to data protection and information security (including our consumer
products) and implement appropriate changes.


We have implemented incident response and breach management processes which have four overarching and interconnected stages: 1)
preparation for a cybersecurity incident, 2) detection and analysis of a security incident, 3) containment, eradication and recovery, and 4) post-incident
analysis. Such incident responses are overseen by leaders from our Information Security, Product Security, Compliance and Legal teams regarding
matters of cybersecurity.


Security events and data incidents are evaluated, ranked by severity and prioritized for response and remediation. Incidents are evaluated to
determine materiality as well as operational and business impact, and reviewed for privacy impact.


We also conduct tabletop exercises to simulate responses to cybersecurity incidents. Our team of cybersecurity professionals then collaborate with
technical and business stakeholders across our business units to further analyze the risk to the company, and form detection, mitigation and remediation
strategies.


As part of the above processes, we regularly engage external auditors and consultants to assess our internal cybersecurity programs and
compliance with applicable practices and standards. As of 2024, our Information Security Management System has been certified to conform to the
requirements of ISO/IEC 27001:2013.


Our risk management program also assesses third party risks, and we perform third-party risk management to identify and mitigate risks from third
parties such as vendors, suppliers, and other business partners associated with our use of third-party service providers. Cybersecurity risks are evaluated
when determining the selection and oversight of applicable third-party service providers and potential fourth-party risks when handling and/or processing
our employee, business or customer data. In addition to new vendor onboarding, we perform risk management during third-party cybersecurity
compromise incidents to identify and mitigate risks to us from third-party incidents.


We describe whether and how risks from identified cybersecurity threats, including as a result of any previous cybersecurity incidents, have
materially affected or are reasonably likely to materially affect us, including our business strategy, results of operations, or financial condition, under the
heading “Our information technology systems or data, or those of our service providers or customers or users could be subject to cyber-attacks or other
security incidents, which could result in data breaches, intellectual property theft, claims, litigation, regulatory investigations, significant liability,
reputational damage and other adverse consequences” included as part of our risk factor disclosures at Item 1A of this Annual Report on Form 10-K.


**Cybersecurity Governance**


Cybersecurity is an important part of our risk management processes and an area of focus for our Board and management. Our Audit Committee is
responsible for the oversight of risks from cybersecurity threats.Members of the Audit Committee receive updates on a quarterly basis from senior
management, including leaders from our Information Security, Product Security, Compliance and Legal teams regarding matters of cybersecurity. This
includes existing and new cybersecurity risks, status on how management is addressing and/or mitigating those risks, cybersecurity and data privacy
incidents (if any) and status on key information security initiatives. Our Board members also engage in ad hoc conversations with management on
cybersecurity-related news events and discuss any updates to our cybersecurity risk management and strategy programs.


28


---

Our cybersecurity risk management and strategy processes are overseen by leaders from our Information Security, Product Security, Compliance
and Legal teams. Such individuals have an average of over 15 years of prior work experience in various roles involving information technology, including
security, auditing, compliance, systems and programming. These individuals are informed about, and monitor the prevention, mitigation, detection and
remediation of cybersecurity incidents through their management of, and participation in, the cybersecurity risk management and strategy processes
described above, including the operation of our incident response plan, and report to the Audit Committee on any appropriate items.


**ITEM 2. PROPERTIES**


We are headquartered in Austin, Texas. Our principal facilities include a large number of properties in North America, Europe and Asia utilized for
manufacturing and assembly, warehousing, engineering, retail and service locations, Supercharger sites and administrative and sales offices. Our facilities
are used to support both of our reporting segments, and are suitable and adequate for the conduct of our business. We generally lease such facilities with
the primary exception of some manufacturing facilities. The following table sets forth the location of our primary owned and leased manufacturing
facilities.


**Primary Manufacturing Facilities** **Location** **Owned or Leased**


Gigafactory Texas Austin, Texas Owned


Fremont Factory Fremont, California Owned


Gigafactory Nevada Sparks, Nevada Owned


Gigafactory Berlin-Brandenburg Grunheide, Germany Owned


Gigafactory Shanghai Shanghai, China

Megafactory Shanghai Shanghai, China

Gigafactory New York Buffalo, New York Leased


Megafactory Lathrop Lathrop, California Leased


- We own the building and the land use rights with an initial term of 50 years. The land use rights are treated as operating lease right-of-use assets.


**ITEM 3. LEGAL PROCEEDINGS**


For a description of our material pending legal proceedings, please see Note 14, Commitments and Contingencies, to the consolidated financial
statements included elsewhere in this Annual Report on Form 10-K.


**ITEM 4. MINE SAFETY DISCLOSURES**


Not applicable.


29


---

**PART II**


**ITEM 5. MARKET FOR REGISTRANT’S COMMON EQUITY, RELATED STOCKHOLDER MATTERS AND ISSUER PURCHASES OF EQUITY**
**SECURITIES**


**Market Information**


Our common stock has traded on The NASDAQ Global Select Market under the symbol “TSLA” since it began trading on June 29, 2010. Our initial
public offering was priced at approximately $1.13 per share on June 28, 2010 as adjusted to give effect to the three-for-one stock split effected in the
form of a stock dividend in August 2022 and the five-for-one stock split effected in the form of a stock dividend in August 2020.


**Holders**


As of January 22, 2025, there were 9,512 holders of record of our common stock. A substantially greater number of holders of our common stock are
“street name” or beneficial holders, whose shares are held by banks, brokers and other financial institutions.


**Dividend Policy**


We have never declared or paid cash dividends on our common stock. We currently do not anticipate paying any cash dividends in the foreseeable
future. Any future determination to declare cash dividends will be made at the discretion of our board of directors, subject to applicable laws, and will
depend on our financial condition, results of operations, capital requirements, general business conditions and other factors that our board of directors
may deem relevant.


**Stock Performance Graph**


This performance graph shall not be deemed “filed” for purposes of Section 18 of the Securities Exchange Act of 1934, as amended (the “Exchange
Act”), or incorporated by reference into any filing of Tesla, Inc. under the Securities Act of 1933, as amended (the “Securities Act”), or the Exchange Act,
except as shall be expressly set forth by specific reference in such filing.


The following graph shows a comparison, from January 1, 2020 through December 31, 2024, of the cumulative total return on our common stock,
The NASDAQ Composite Index and a group of all public companies sharing the same SIC code as us, which is SIC code 3711, “Motor Vehicles and
Passenger Car Bodies” (Motor Vehicles and Passenger Car Bodies Public Company Group). Such returns are based on historical results and are not
intended to suggest future performance. Data for The NASDAQ Composite Index and the Motor Vehicles and Passenger Car Bodies Public Company Group
assumes an investment of $100 on January 1, 2020 and reinvestment of dividends. We have never declared or paid cash dividends on our common stock
nor do we anticipate paying any such cash dividends in the foreseeable future.


30


---

**Unregistered Sales of Equity Securities and Use of Proceeds**


In connection with the offering of 2.00% Convertible Senior Notes due 2024 in May 2019, we sold warrants to each of Société Générale, Wells Fargo
Bank, National Association, Credit Suisse Capital LLC (later assigned to UBS AG, London Branch) and Goldman, Sachs & Co. LLC (together, the “2019
Warrantholders”). Between October 1, 2024 and October 15, 2024, we issued an aggregate of 2,894,424 shares of our common stock to the 2019
Warrantholders pursuant to their exercise of such warrants, which were net of the applicable exercise prices. Such shares were issued pursuant to an
exemption from registration provided by Rule 3(a)(9) of the Securities Act of 1933.


**Purchases of Equity Securities by the Issuer and Affiliated Purchasers**


None.


**ITEM 6. [RESERVED]**


31


---

**ITEM 7. MANAGEMENT’S DISCUSSION AND ANALYSIS OF FINANCIAL CONDITION AND RESULTS OF OPERATIONS**


The following discussion and analysis should be read in conjunction with the consolidated financial statements and the related notes included
elsewhere in this Annual Report on Form 10-K. For further discussion of our products and services, technology and competitive strengths, refer to Item 1Business. For discussion related to changes in financial condition and the results of operations for fiscal year 2023-related items, refer to Part II, Item 7.
Management’s Discussion and Analysis of Financial Condition and Results of Operations in our Annual Report on Form 10-K for fiscal year 2023, which was
filed with the Securities and Exchange Commission on January 29, 2024.


**Overview and 2024 Highlights**


Our mission is to accelerate the world’s transition to sustainable energy. We design, develop, manufacture, lease and sell high-performance fully
electric vehicles, solar energy generation systems and energy storage products. We also offer maintenance, installation, operation, charging, insurance,
financial and other services related to our products. Additionally, we are increasingly focused on products and services based on AI, robotics and
automation.


In 2024, we produced approximately 1,773,000 consumer vehicles and delivered approximately 1,789,000 consumer vehicles. We are focused on
profitable growth, including by leveraging existing factories and production lines to introduce new and more affordable products, further improving and
deploying our FSD (Supervised) capabilities, including future autonomous capabilities through our purpose-built Robotaxi product, Cybercab, reducing
costs, increasing vehicle production, utilized capacity and delivery capabilities, improving and developing our vehicles and battery technologies, vertically
integrating and localizing our supply chain, and expanding our global infrastructure, including our service and charging infrastructure.


In 2024, we deployed 31.4 GWh of energy storage products. We are focused on ramping the production and increasing the market penetration of
our energy storage products.


In 2024, we recognized total revenues of $97.69 billion, representing an increase of $917 million compared to the prior year. In 2024, our net
income attributable to common stockholders was $7.09 billion, representing a decrease of $7.91 billion compared to the prior year, primarily due to the
impact of releasing $6.54 billion of our valuation allowance associated with U.S. federal and state deferred tax assets in the fourth quarter of 2023.We
continue to ramp production and build and optimize our manufacturing capacity, expand our operations while focusing on further cost reductions and
operational efficiencies to enable increased deliveries and deployments of our products, and invest in research and development to accelerate our AI,
software, and fleet-based profits for further revenue growth.


We ended 2024 with $36.56 billion in cash and cash equivalents and investments, representing an increase of $7.47 billion from the end of 2023.
Our cash flows provided by operating activities were $14.92 billion in 2024 compared to $13.26 billion in 2023, representing an increase of $1.67 billion.
Capital expenditures amounted to $11.34 billion in 2024 compared to $8.90 billion in 2023, representing an increase of $2.44 billion. Overall growth has
allowed our business to generally fund itself, and we will continue investing in a number of capital-intensive projects and research and development in
upcoming periods.


32


---

**Management Opportunities, Challenges and Uncertainties and 2025 Outlook**


Automotive—Production


The following is a summary of the status of production of each of our announced vehicle models in production and under development, as of the
date of this Annual Report on Form 10-K:


**Region** **Vehicle Model(s)** **Production Status**


Shanghai Model 3 / Model Y Active


Berlin Model Y Active


Texas Model Y Active


Cybertruck Active


Cybercab In development


Nevada Tesla Semi Pilot production


TBD Roadster In development


We are focused on growing our manufacturing capacity, which includes capacity for manufacturing newer vehicle models such as our Cybertruck,
Tesla Semi and future vehicles utilizing aspects of our next generation platform, and ramping the production at our Gigafactories to their installed
production capacities as well as increasing production rate and efficiency at our current factories. The next phase of production growth will depend on the
continued ramp at our factories and be initiated by advances in autonomy and the introduction of new products, including those built on our next
generation vehicle platform, as well as our ability to add to our available sources of battery cell supply by manufacturing our own cells that we are
developing to have high-volume output, lower capital and production costs and longer range. Our goals are to improve vehicle performance, decrease
production costs and increase affordability and customer awareness.


These plans are subject to uncertainties inherent in establishing and ramping manufacturing operations, which may be exacerbated by new product
and manufacturing technologies we introduce, the number of concurrent international projects, any industry-wide component constraints, labor shortages
and any future impact from events outside of our control. For example, during the first quarter of 2024, we experienced a sequential decline in production
volumes partially caused by the early phase of the production ramp of the updated Model 3 at our Fremont factory, and factory shutdowns at Gigafactory
Berlin-Brandenburg resulting from shipping diversions caused by the Red Sea conflict and an arson attack. In the first quarter of 2025, as we launch our
New Model Y worldwide, we may similarly experience delays or declines in production volumes due to simultaneous manufacturing ramps in facilities on
three continents. Moreover, we have set ambitious technological targets with our plans for battery cells as well as for iterative manufacturing and design
improvements for our vehicles with each new factory.


Automotive—Demand, Sales, Deliveries and Infrastructure


Our cost reduction efforts, cost innovation strategies, and additional localized procurement and manufacturing are key to our vehicles’ affordability
and have allowed us to competitively price our vehicles. We will also continue to generate demand by improving our vehicles’ performance and
functionality, including through product offerings and features based on artificial intelligence such as Autopilot, FSD (Supervised), and other software, and
delivering new vehicles and vehicle options, such as our launch of the updated Model 3 in 2024, and the New Model Y in the first quarter of 2025. In
addition, we have been increasing awareness, and expanding our vehicle financing programs, including attractive leasing terms for our customers.


33


---

However, we operate in a cyclical industry that is sensitive to shifting consumer trends, political and regulatory uncertainty, including with respect to
trade and the environment, all of which can be compounded by inflationary pressures, rising energy prices, interest rate fluctuations and the liquidity of
enterprise customers. For example, as inflationary pressures increased across the markets in which we operate, central banks in developed countries
raised interest rates rapidly and substantially, which impacted the affordability of vehicle lease and finance arrangements. Further, sales of vehicles in the
automotive industry also tend to be cyclical in many markets, which may expose us to increased volatility as we expand and adjust our operations.
Moreover, as additional competitors enter the marketplace and help bring the world closer to sustainable transportation, we will have to adjust and
continue to execute well to maintain our momentum. Additionally, our suppliers’ liquidity and allocation plans may be affected by current challenges in
the North American automotive industry, which could reduce our access to components or result in unfavorable changes to cost. These macroeconomic
and industry trends have had, and will likely continue to have, an impact on the pricing of, and order rate for our vehicles, and in turn our operating
margin. Changes in government and economic policies, incentives or tariffs may also impact our production, sales, cost structure and the competitive
landscape. We will continue to adjust accordingly to such developments, and we believe our ongoing cost reduction, including improved production
innovation and efficiency at our newest factories and lower logistics costs, and focus on operating leverage will continue to benefit us in relation to our
competitors, while our new products will help enable future growth.


As our production increases, we must work constantly to similarly increase vehicle delivery capability so that it does not become a bottleneck on our
total deliveries. We are also committed to reducing the percentage of vehicles delivered in the third month of each quarter, which will help to reduce the
cost per vehicle. As we expand our manufacturing operations globally, we will also have to continue to increase and staff our delivery, servicing and
charging infrastructure accordingly, maintain our vehicle reliability and optimize our Supercharger locations to ensure cost effectiveness and customer
satisfaction. In particular, as other automotive manufacturers have announced their adoption of the North American Charging Standard (“NACS”) and
agreements with us to utilize our Superchargers, we must correspondingly expand our network in order to ensure adequate availability to meet customer
demands. We also remain focused on continued enhancements of the capability and efficiency of our servicing operations.


Energy Generation and Storage Demand, Production and Deployment


The long-term success of this business is dependent upon incremental volume growth. We continue to increase the production and capabilities of
our energy storage products to meet high levels of demand, including the introduction of Powerwall 3 in 2024, and the ramps of our Megafactories in
Shanghai and Lathrop, California. For Megapack, energy storage deployments can vary meaningfully quarter to quarter depending on the timing of
specific project milestones and logistics. As these product lines grow, we will have to maintain adequate battery cell supply for our energy storage
products. At the same time, changes in government and economic incentives or tariffs may also impact our sales, cost structure and the competitive
landscape.


Cash Flow and Capital Expenditure Trends


Our capital expenditures are typically difficult to project beyond the short-term given the number and breadth of our core projects at any given time,
and may further be impacted by uncertainties in future global market conditions. We are simultaneously developing and ramping new products, building
or ramping manufacturing facilities on three continents, piloting the development and manufacture of new battery cell technologies, expanding our
Supercharger network and investing in autonomy and other artificial intelligence enabled training and products, and the pace of our capital spend may
vary depending on overall priority among projects, the pace at which we meet milestones, production adjustments to and among our various products,
increased capital efficiencies and the addition of new projects. Owing and subject to the foregoing as well as the pipeline of announced projects under
development, all other continuing infrastructure growth and varying levels of inflation, we currently expect our capital expenditures to exceed $11.00
billion in 2025 and in each of the following two fiscal years.


Our business has generally been consistently generating cash flow from operations in excess of our level of capital spend, and with better working
capital management resulting in shorter days sales outstanding than days payable outstanding, our sales growth is also generally facilitating positive
cash generation. We have and will continue to utilize such cash flows, among other things, to invest in autonomy, do more vertical integration, expand
our product roadmap and provide financing options to our customers. At the same time, we are likely to see heightened levels of capital expenditures
during certain periods depending on the specific pace of our capital-intensive projects and other potential variables such as rising material prices and
increases in supply chain and labor expenses resulting from changes in global trade conditions and labor availability. Overall, we expect our ability to be
self-funding to continue as long as macroeconomic factors support current trends in our sales.


34


---

**Critical Accounting Policies and Estimates**


The consolidated financial statements are prepared in accordance with accounting principles generally accepted in the U.S. (“GAAP”). The
preparation of the consolidated financial statements requires us to make estimates and assumptions that affect the reported amounts of assets, liabilities,
revenues, costs and expenses and related disclosures. We base our estimates on historical experience, as appropriate, and on various other assumptions
that we believe to be reasonable under the circumstances. Changes in the accounting estimates are reasonably likely to occur from period to period.
Accordingly, actual results could differ significantly from the estimates made by our management. We evaluate our estimates and assumptions on an
ongoing basis. To the extent that there are material differences between these estimates and actual results, our future financial statement presentation,
financial condition, results of operations and cash flows may be affected.


The estimates used for, but not limited to, determining significant economic incentive for resale value guarantee arrangements, sales return
reserves, resale value guarantee liabilities, income tax, the collectability of accounts and finance receivables, inventory valuation, warranties, fair value of
long-lived assets, goodwill, fair value of financial instruments, fair value and residual value of operating lease vehicles and solar energy systems subject
to leases could be impacted. We have assessed the impact and are not aware of any specific events or circumstances that required an update to our
estimates and assumptions or materially affected the carrying value of our assets or liabilities as of the date of issuance of this Annual Report on Form 10K. These estimates may change as new events occur and additional information is obtained. Actual results could differ materially from these estimates
under different assumptions or conditions.


Revenue Recognition


Automotive Sales


Automotive sales revenue includes revenues related to cash and financing deliveries of new vehicles, and specific other features and services that
meet the definition of a performance obligation under Accounting Standards Codification 606, Revenue from Contracts with Customers (“ASC 606”),
including access to our FSD (Supervised) features and their ongoing maintenance, internet connectivity, free Supercharging programs and over-the-air
software updates. We recognize revenue on automotive sales upon delivery to the customer, which is when the control of a vehicle transfers. Payments
are typically received at the point control transfers or in accordance with payment terms customary to the business, except sales we finance for which
payments are collected over the contractual loan term. We also recognize a sales return reserve based on historical experience plus consideration for
expected future market values, when we offer resale value guarantees or similar buyback terms. Other features and services such as access to our
internet connectivity, unlimited free Supercharging and over-the-air software updates are provisioned upon control transfer of a vehicle and recognized
over time on a straight-line basis as we have a stand-ready obligation to deliver such services to the customer. Other limited free Supercharging
incentives are recognized based on actual usage or expiration, whichever is earlier. We recognize revenue related to these other features and services
over the performance period, which is generally the expected ownership life of the vehicle. Revenue related to FSD (Supervised) features is recognized
when functionality is delivered to the customer and their ongoing maintenance is recognized over time. For our obligations related to automotive sales,
we estimate standalone selling price by considering costs used to develop and deliver the service, third-party pricing of similar options and other
information that may be available.


Inventory Valuation


Inventories are stated at the lower of cost or net realizable value. Cost is computed using standard cost for vehicles and energy products, which
approximates actual cost on a first-in, first-out basis. We record inventory write-downs for excess or obsolete inventories based upon assumptions about
current and future demand forecasts. If our inventory on-hand is in excess of our future demand forecast, the excess amounts are written-off.


We also review our inventory to determine whether its carrying value exceeds the net amount realizable upon the ultimate sale of the inventory.
This requires us to determine the estimated selling price of our vehicles less the estimated cost to convert the inventory on-hand into a finished product.
Once inventory is written-down, a new, lower cost basis for that inventory is established and subsequent changes in facts and circumstances do not result
in the restoration or increase in that newly established cost basis.


Should our estimates of future selling prices or production costs change, additional and potentially material write-downs may be required. A small
change in our estimates may result in a material charge to our reported financial results.


35


---

Warranties


We provide a manufacturer’s warranty on all new and used vehicles and a warranty on the installation and components of the energy generation
and storage systems we sell for periods typically between 10 to 25 years. We accrue a warranty reserve for the products sold by us, which includes our
best estimate of the projected costs to repair or replace items under warranties and recalls if identified. These estimates are based on actual claims
incurred to date and an estimate of the nature, frequency and costs of future claims. These estimates are inherently uncertain and changes to our
historical or projected warranty experience may cause material changes to the warranty reserve in the future. The warranty reserve does not include
projected warranty costs associated with our vehicles subject to operating lease accounting and our solar energy systems under lease contracts or PPAs,
as the costs to repair these warranty claims are expensed as incurred. The portion of the warranty reserve expected to be incurred within the next 12
months is included within Accrued liabilities and other, while the remaining balance is included within Other long-term liabilities on the consolidated
balance sheets. For liabilities that we are entitled to receive indemnification from our suppliers, we record receivables for the contractually obligated
amounts on the consolidated balance sheets as a component of Prepaid expenses and other current assets for the current portion and as Other noncurrent assets for the long-term portion. Warranty expense is recorded as a component of Cost of revenues in the consolidated statements of operations.
Due to the magnitude of our automotive business, our accrued warranty balance is primarily related to our automotive segment.


Stock-Based Compensation


We use the fair value method of accounting for our stock options and restricted stock units (“RSUs”) granted to employees and for our employee
stock purchase plan (the “ESPP”) to measure the cost of employee services received in exchange for the stock-based awards. The fair value of stock
option awards with only service and/or performance conditions is estimated on the grant or offering date using the Black-Scholes option-pricing model.
The Black-Scholes option-pricing model requires inputs such as the risk-free interest rate, expected term and expected volatility. These inputs are
subjective and generally require significant judgment. The fair value of RSUs is measured on the grant date based on the closing fair market value of our
common stock. The resulting cost is recognized over the period during which an employee is required to provide service in exchange for the awards,
usually the vesting period, which is generally four years for stock options and RSUs and six months for the ESPP. Stock-based compensation expense is
recognized on a straight-line basis, net of actual forfeitures in the period.


For performance-based awards, stock-based compensation expense is recognized over the expected performance achievement period of individual
performance milestones when the achievement of each individual performance milestone becomes probable.


As we accumulate additional employee stock-based awards data over time and as we incorporate market data related to our common stock, we may
calculate significantly different volatilities and expected lives, which could materially impact the valuation of our stock-based awards and the stock-based
compensation expense that we will recognize in future periods. Stock-based compensation expense is recorded in Cost of revenues, Research and
development expense and Selling, general and administrative expense in the consolidated statements of operations.


Income Taxes


We are subject to income taxes in the U.S. and in many foreign jurisdictions. Significant judgment is required in determining our provision for
income taxes, our deferred tax assets and liabilities and any valuation allowance recorded against our net deferred tax assets that are not more likely
than not to be realized. We monitor the realizability of our deferred tax assets taking into account all relevant factors at each reporting period. In
completing our assessment of realizability of our deferred tax assets, we consider our history of income (loss) measured at pre-tax income (loss) adjusted
for permanent book-tax differences on a jurisdictional basis, volatility in actual earnings, excess tax benefits related to stock-based compensation in
recent prior years, and impacts of the timing of reversal of existing temporary differences. We also rely on our assessment of the Company’s projected
future results of business operations, including uncertainty in future operating results relative to historical results, volatility in the market price of our
common stock and its performance over time, variable macroeconomic conditions impacting our ability to forecast future taxable income, and changes in
business that may affect the existence and magnitude of future taxable income. Our valuation allowance assessment is based on our best estimate of
future results considering all available information.


36


---

Furthermore, significant judgment is required in evaluating our tax positions. In the ordinary course of business, there are many transactions and
calculations for which the ultimate tax settlement is uncertain. As a result, we recognize the effect of this uncertainty on our tax attributes or taxes
payable based on our estimates of the eventual outcome. These effects are recognized when, despite our belief that our tax return positions are
supportable, we believe that it is more likely than not that some of those positions may not be fully sustained upon review by tax authorities. We are
required to file income tax returns in the U.S. and various foreign jurisdictions, which requires us to interpret the applicable tax laws and regulations in
effect in such jurisdictions. Such returns are subject to audit by the various federal, state and foreign taxing authorities, who may disagree with respect to
our tax positions. We believe that our consideration is adequate for all open audit years based on our assessment of many factors, including past
experience and interpretations of tax law. We review and update our estimates in light of changing facts and circumstances, such as the closing of a tax
audit, the lapse of a statute of limitations or a change in estimate. To the extent that the final tax outcome of these matters differs from our expectations,
such differences may impact income tax expense in the period in which such determination is made.


**Results of Operations**


**Revenues**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Automotive sales $ 72,480 $ 78,509 $ 67,210 $ (6,029) (8)% $ 11,299 17 %


Automotive regulatory credits 2,763 1,790 1,776 973 54 % 14 1 %


Automotive leasing 1,827 2,120 2,476 (293) (14)% (356) (14)%


Total automotive revenues 77,070 82,419 71,462 (5,349) (6)% 10,957 15 %


Services and other 10,534 8,319 6,091 2,215 27 % 2,228 37 %


Total automotive & services and other segment

revenue 87,604 90,738 77,553 (3,134) (3)% 13,185 17 %


Energy generation and storage segment revenue 10,086 6,035 3,909 4,051 67 % 2,126 54 %


Total revenues $ 97,690 $ 96,773 $ 81,462 $ 917 1 % $ 15,311 19 %


Automotive & Services and Other Segment


Automotive sales revenue includes revenues related to cash and financing deliveries of new vehicles, including access to our FSD (Supervised)
features and their ongoing maintenance, internet connectivity, free Supercharging programs and over-the-air software updates. These deliveries are
vehicles that are not subject to lease accounting.


Automotive regulatory credits includes sales of regulatory credits to other automotive manufacturers. Our revenue from automotive regulatory
credits is directly related to our new vehicle production, sales and pricing negotiated with our customers. We monetize them proactively as new vehicles
are sold based on standing arrangements with buyers of such credits, typically as close as possible to the production and delivery of the vehicle or
changes in regulation impacting the credits.


Automotive leasing revenue includes the amortization of revenue for vehicles under direct operating lease agreements. Additionally, automotive
leasing revenue includes direct sales-type leasing programs where we recognize all revenue associated with the sales-type lease upon delivery to the
customer.


Services and other revenue consists of sales of used vehicles, non-warranty maintenance services and collision, part sales, paid Supercharging,
insurance services revenue and retail merchandise sales.


2024 compared to 2023


Automotive sales revenue decreased $6.03 billion, or 8%, in the year ended December 31, 2024 as compared to the year ended December 31,
2023, primarily due to lower average selling price on our vehicles driven by overall price reductions and attractive financing options provided in 2024 as
well as mix. Additionally, there was a decrease of approximately 22,000 combined Model 3 and Model Y cash deliveries. The decreases were partially
offset by an increase of approximately 19,000 deliveries of other models primarily due to our production ramp of Cybertruck. Additionally, we recognized
$596 million of FSD (Supervised) revenue due to release of certain features in 2024.


37


---

Automotive regulatory credits revenue increased $973 million, or 54%, in the year ended December 31, 2024 as compared to the year ended
December 31, 2023, driven by demand for credits in North America as other automobile manufacturers scale back on their battery electric vehicle plans.


Automotive leasing revenue decreased $293 million, or 14%, in the year ended December 31, 2024 as compared to the year ended December 31,
2023, primarily due to lower direct sales-type leasing deliveries as we have shifted towards providing leasing options through commercial banking partner
programs that allow for us to recognize upfront revenue in automotive sales and a decrease in lease buyouts.


Services and other revenue increased $2.22 billion, or 27%, in the year ended December 31, 2024 as compared to the year ended December 31,
2023, primarily due to increases in sales of used vehicles, non-warranty maintenance services and collision revenue, paid Supercharging revenue,
insurance services revenue and part sales revenue.


Energy Generation and Storage Segment


Energy generation and storage revenue includes sales and leasing of solar energy generation and energy storage products, financing of solar energy
generation products, services related to such products and sales of solar energy systems incentives.


2024 compared to 2023


Energy generation and storage revenue increased $4.05 billion, or 67%, in the year ended December 31, 2024 as compared to the year ended
December 31, 2023, primarily due to a 16.7 GWh increase in Megapack and Powerwall deployments compared to the prior year.


**Cost of Revenues and Gross Margin**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Cost of revenues


Automotive sales $ 61,870 $ 65,121 $ 49,599 $ (3,251) (5)% $ 15,522 31 %


Automotive leasing 1,003 1,268 1,509 (265) (21)% (241) (16)%


Total automotive cost of revenues 62,873 66,389 51,108 (3,516) (5)% 15,281 30 %


Services and other 9,921 7,830 5,880 2,091 27 % 1,950 33 %


Total automotive & services and other segment

cost of revenues 72,794 74,219 56,988 (1,425) (2)% 17,231 30 %


Energy generation and storage segment 7,446 4,894 3,621 2,552 52 % 1,273 35 %


Total cost of revenues $ 80,240 $ 79,113 $ 60,609 $ 1,127 1 % $ 18,504 31 %


Gross profit total automotive $ 14,197 $ 16,030 $ 20,354


Gross margin total automotive 18.4 % 19.4 % 28.5 %


Gross profit total automotive & services and other

segment $ 14,810 $ 16,519 $ 20,565


Gross margin total automotive & services and other

segment 16.9 % 18.2 % 26.5 %


Gross profit energy generation and storage segment $ 2,640 $ 1,141 $ 288


Gross margin energy generation and storage segment 26.2 % 18.9 % 7.4 %


Total gross profit $ 17,450 $ 17,660 $ 20,853


Total gross margin 17.9 % 18.2 % 25.6 %


38


---

Automotive & Services and Other Segment


Cost of automotive sales revenue includes direct and indirect materials, labor costs, manufacturing overhead, including depreciation costs of tooling
and machinery, shipping and logistic costs, vehicle connectivity costs, FSD (Supervised) ongoing maintenance costs, allocations of electricity and
infrastructure costs related to our Supercharger network and reserves for estimated warranty expenses. Cost of automotive sales revenues also includes
adjustments to warranty expense and charges to write down the carrying value of our inventory when it exceeds its estimated net realizable value and to
provide for obsolete and on-hand inventory in excess of forecasted demand. Additionally, cost of automotive sales revenue benefits from manufacturing
credits earned.


Cost of automotive leasing revenue includes the depreciation of operating lease vehicles, cost of goods sold associated with direct sales-type leases
and warranty expense related to leased vehicles.


Costs of services and other revenue includes cost of used vehicles including refurbishment costs, costs associated with providing non-warranty
after-sales services, costs associated with our body shops and part sales, costs of paid Supercharging, costs to provide vehicle insurance and costs of
retail merchandise sales.


2024 compared to 2023


Cost of automotive sales revenue decreased $3.25 billion, or 5%, in the year ended December 31, 2024 as compared to the year ended
December 31, 2023 due to a decrease in the average combined cost per unit of our vehicles primarily from lower raw material costs, freight and duties as
well as mix, in addition to the volume changes in deliveries year over year as discussed above. The decreases were partially offset by higher costs for
Cybertruck.


Cost of automotive leasing revenue decreased $265 million, or 21%, in the year ended December 31, 2024 as compared to the year ended
December 31, 2023, primarily due to a decrease in direct sales-type leasing cost of revenue driven by lower deliveries and a decrease in our direct
operating lease cost of revenue driven by lower lease buyouts compared to the prior periods.


Cost of services and other revenue increased $2.09 billion, or 27%, in the year ended December 31, 2024 as compared to the year ended
December 31, 2023, primarily due to volume increases in used vehicle sales at lower average vehicle acquisition cost, insurance services, paid
Supercharging, part sales and non-warranty maintenance services and collision.


Gross margin for total automotive decreased from 19.4% to 18.4% in the year ended December 31, 2024 as compared to the year ended
December 31, 2023 due to lower average selling price on our vehicles and Cybertruck ramp, partially offset by lower average combined cost per unit of
our vehicles and increases in regulatory credit and FSD (Supervised) revenue, as discussed above.


Gross margin for total automotive & services and other segment decreased from 18.2% to 16.9% in the year ended December 31, 2024 as
compared to the year ended December 31, 2023. The changes in gross margin are primarily due to the automotive gross margin factors discussed above.


Energy Generation and Storage Segment


Cost of energy generation and storage revenue includes direct and indirect material and labor costs, manufacturing overhead, including
depreciation costs of tooling and machinery, freight, warranty expense, and cost of servicing. Cost of energy generation and storage revenue also
includes charges to write down the carrying value of our inventory when it exceeds its estimated net realizable value and to provide for obsolete and onhand inventory in excess of forecasted demand. Additionally, cost of energy generation and storage revenue benefits from manufacturing credits earned.
In agreements for solar energy systems and PPAs where we are the lessor, the cost of revenue is primarily comprised of depreciation of the cost of leased
solar energy systems, maintenance costs associated with those systems and amortization of any initial direct costs.


2024 compared to 2023


Cost of energy generation and storage revenue increased $2.55 billion, or 52%, in the year ended December 31, 2024 as compared to the year
ended December 31, 2023, primarily due to increases in Megapack and Powerwall deployments, partially offset by increases in IRA manufacturing credits
recognized as compared to the prior year.


39


---

Gross margin for energy generation and storage increased from 18.9% to 26.2% in the year ended December 31, 2024 as compared to the year
ended December 31, 2023, primarily due to margin improvements for our energy storage products driven by cost reductions, including benefits from IRA
manufacturing credits, and a higher proportion of our storage business, which operated at a higher gross margin, within the segment as compared to the
prior periods.


**Research and Development Expense**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Research and development $ 4,540 $ 3,969 $ 3,075 $ 571 14 % $ 894 29 %


As a percentage of revenues 5 % 4 % 4 %


Research and development (“R&D”) expenses consist primarily of personnel costs for our teams in engineering and research, manufacturing
engineering and manufacturing test organizations, prototyping expense, contract and professional services and amortized equipment expense.


R&D expenses increased $571 million, or 14%, in the year ended December 31, 2024 as compared to the year ended December 31, 2023. The
overall increases were primarily driven by additional costs year over year related to AI programs. R&D expenses as a percentage of revenue increased
from 4% to 5% in the year ended December 31, 2024 as compared to the year ended December 31, 2023 as we continue to expand our product roadmap
and technologies.


**Selling, General and Administrative Expense**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Selling, general and administrative $ 5,150 $ 4,800 $ 3,946 $ 350 7 % $ 854 22 %


As a percentage of revenues 5 % 5 % 5 %


Selling, general and administrative (“SG&A”) expenses generally consist of personnel and facilities costs related to our stores, marketing, sales,
executive, finance, human resources, information technology and legal organizations, as well as fees for professional and contract services and litigation
settlements.


SG&A expenses increased $350 million, or 7%, in the year ended December 31, 2024 as compared to the year ended December 31, 2023 driven by
a $171 million increase in facilities related expenses, a $115 million increase in employee and labor costs, including professional services and a $57
million increase in marketing expenses.


**Restructuring and Other**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Restructuring and other $ 684 $ - $ 176 $ 684 Not meaningful $ (176) (100)%


In the second quarter of 2024, we initiated and substantially completed certain restructuring actions to reduce costs and improve efficiency. As a
result, we recognized $583 million of employee termination expenses in Restructuring and other in our consolidated income statement. These expenses
were substantially paid with an immaterial accrual remaining in Accrued liabilities and other in our consolidated balance sheet as of December 31, 2024.


**Interest Income**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Interest income $ 1,569 $ 1,066 $ 297 $ 503 47 % $ 769 259 %


Interest income increased $503 million, or 47%, in the year ended December 31, 2024 as compared to the year ended December 31, 2023,
primarily due to higher interest earned on our cash and cash equivalents and short-term investments compared to the prior year due to an increase in our
portfolio balance and a higher weighted average interest rate.


40


---

**Other Income (Expense), Net**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Other income (expense), net $ 695 $ 172 $ (43) $ 523 304% $ 215 Not meaningful


Other income (expense), net, consists of foreign exchange gains and losses related to our foreign currency-denominated monetary assets and
liabilities and fair value remeasurements of our digital assets following the adoption of ASU 2023-08 effective January 1, 2024. See Note 2, Summary of
Significant Accounting Policies, to the consolidated financial statements included elsewhere in this Annual Report on Form 10-K for further details.


Other income (expense), net, changed favorably by $523 million in the year ended December 31, 2024 as compared to the year ended
December 31, 2023 primarily due to remeasurement of our bitcoin digital assets to fair value in 2024 (see above), partially offset by unfavorable
fluctuations in foreign currency exchange rates on our intercompany balances. As our intercompany balances are significant in nature and we do not
typically hedge foreign currency risk, we can experience significant fluctuations in foreign currency exchange rate gains and losses from period to period.


**Provision for (Benefit from) Income Taxes**


**Year Ended December 31,** **2024 vs. 2023 Change** **2023 vs. 2022 Change**


(Dollars in millions) **2024** **2023** **2022** **$** **%** **$** **%**


Provision for (benefit from) income taxes $ 1,837 $ (5,001) $ 1,132 $ 6,838 Not meaningful $ (6,133) Not meaningful


Effective tax rate 20 % (50)% 8 %


Our provision for (benefit from) income taxes changed by $6.84 billion in the year ended December 31, 2024 as compared to the year ended
December 31, 2023. Our effective tax rate changed to an expense of 20% in the year ended December 31, 2024 from a benefit of 50% in the year ended
December 31, 2023. These changes are primarily due to the impact of releasing the valuation allowance on our U.S. deferred tax assets in the fourth
quarter of 2023.


We monitor the realizability of our deferred tax assets taking into account all relevant factors at each reporting period. In the fourth quarter of 2023,
based on the relevant weight of positive and negative evidence, including the amount of our taxable income in recent years which was objective and
verifiable, and consideration of our expected future taxable earnings, we concluded that it is more likely than not that most of our U.S. federal and certain
state deferred tax assets are realizable and released $6.54 billion of our valuation allowance. As of December 31, 2024, we continue to conclude that it is
more likely than not that our deferred tax assets are realizable, except for our California deferred tax assets, U.S. foreign tax credits and certain foreign
operating losses.


See Note 13, Income Taxes, to the consolidated financial statements included elsewhere in this Annual Report on Form 10-K for further details.


**Liquidity and Capital Resources**


We expect to continue to generate net positive operating cash flow. The cash we generate from our core operations enables us to fund ongoing
operations and production, our research and development projects for new products and technologies including our proprietary battery cells, additional
manufacturing ramps at existing manufacturing facilities, the construction of future factories, and the continued expansion of our retail and service
locations, body shops, Mobile Service fleet, Supercharger, including to support NACS, energy product installation capabilities and autonomy and other
artificial intelligence enabled products.


In addition, because a large portion of our future expenditures will be to fund our growth, we expect that if needed we will be able to adjust our
capital and operating expenditures by operating segment. For example, if our near-term manufacturing operations decrease in scale or ramp more slowly
than expected, including due to global economic or business conditions, we may choose to correspondingly slow the pace of our capital expenditures.
Finally, we continually evaluate our cash needs and may decide it is best to raise additional capital or seek alternative financing sources to fund the rapid
growth of our business, including through drawdowns on existing or new debt facilities or financing funds. Conversely, we may also from time to time
determine that it is in our best interests to voluntarily repay certain indebtedness early.


41


---

Accordingly, we believe that our current sources of funds will provide us with adequate liquidity during the 12-month period following December 31,
2024, as well as in the long-term.


See the sections below for more details regarding the material requirements for cash in our business and our sources of liquidity to meet such
needs.


Material Cash Requirements


From time to time in the ordinary course of business, we enter into agreements with vendors for the purchase of components and raw materials to
be used in the manufacture of our products. However, due to contractual terms, variability in the precise growth curves of our development and
production ramps, and opportunities to renegotiate pricing, we generally do not have binding and enforceable purchase orders under such contracts
beyond the short-term, and the timing and magnitude of purchase orders beyond such period is difficult to accurately project.


As discussed in and subject to the considerations referenced in Part II, Item 7, Management's Discussion and Analysis of Financial Condition and
Results of Operations—Management Opportunities, Challenges and Uncertainties and 2025 Outlook—Cash Flow and Capital Expenditure Trends in this
Annual Report on Form 10-K, we currently expect our capital expenditures to support our projects globally to exceed $11.00 billion in 2025 and in each of
the following two fiscal years.


As of December 31, 2024, we and our subsidiaries had outstanding $7.91 billion in aggregate principal amount of indebtedness, of which $2.35
billion is current. As of December 31, 2024, our total minimum lease payments was $7.05 billion, of which $1.19 billion is due in the succeeding 12
months. For details regarding our indebtedness and lease obligations, refer to Note 10, Debt, and Note 11, Leases, to the consolidated financial
statements included elsewhere in this Annual Report on Form 10-K.


Sources and Conditions of Liquidity


Our sources to fund our material cash requirements are predominantly from our deliveries and servicing of new and used vehicles, sales and
installations of our energy storage products, interest income, and proceeds from debt facilities and equity offerings, when applicable.


As of December 31, 2024, we had $16.14 billion and $20.42 billion of cash and cash equivalents and short-term investments, respectively. Balances
held in foreign currencies had a U.S. dollar equivalent of $2.90 billion and consisted primarily of euros and Chinese yuan. We had $5.00 billion of unused
committed credit amounts as of December 31, 2024. For details regarding our indebtedness, refer to Note 10, Debt, to the consolidated financial
statements included elsewhere in this Annual Report on Form 10-K.


We continue adapting our strategy to meet our liquidity and risk objectives, such as investing in U.S. government securities and other investments,
invest in autonomy, do more vertical integration, expand our product roadmap and provide financing options to our customers.


**Summary of Cash Flows**


**Year Ended December 31,**


(Dollars in millions) **2024** **2023** **2022**


Net cash provided by operating activities $ 14,923 $ 13,256 $ 14,724


Net cash used in investing activities $ (18,787) $ (15,584) $ (11,973)


Net cash provided by (used in) financing activities $ 3,853 $ 2,589 $ (3,527)


Cash Flows from Operating Activities


Our cash flows from operating activities are significantly affected by our cash investments to support the growth of our business in areas such as
research and development and selling, general and administrative and working capital. Our operating cash inflows include cash from vehicle sales and
related servicing, customer lease and financing payments, customer deposits, cash from sales of regulatory credits and energy generation and storage
products, and interest income on our cash and investments portfolio. These cash inflows are offset by our payments to suppliers for production materials
and parts used in our manufacturing process, operating expenses, operating lease payments and interest payments on our financings.


42


---

Net cash provided by operating activities increased by $1.67 billion to $14.92 billion during the year ended December 31, 2024 from $13.26 billion
during the year ended December 31, 2023. This increase was primarily due to favorable changes in net operating assets and liabilities of $2.29 billion,
partially offset by a decrease in net income excluding non-cash expenses, gains and losses of $623 million.


Cash Flows from Investing Activities


Net cash flows from investing activities and their variability across each period related primarily to capital expenditures, which were $11.34 billion
and $8.90 billion for the years ended December 31, 2024 and 2023, respectively, mainly for AI-related capital expenditures, global factory expansion and
machinery and equipment as we expand and enhance our product roadmap. We also purchased $7.45 billion and $6.62 billion of investments, net of
proceeds from maturities and sales, for the years ended December 31, 2024 and 2023, respectively.


Cash Flows from Financing Activities


Net cash flows from financing activities increased by $1.26 billion to $3.85 billion during the year ended December 31, 2024 from $2.59 billion
during the year ended December 31, 2023. The increase was primarily due to a $1.81 billion increase in proceeds from issuances of debt, partially offset
by a $1.15 billion increase in repayments of debt. See Note 10, Debt, to the consolidated financial statements included elsewhere in this Annual Report on
Form 10-K for further details regarding our debt obligations. Additionally, there was an increase of $541 million in proceeds from exercises of stock
options and other stock issuances compared to the prior year.


**Recent Accounting Pronouncements**


See Note 2, Summary of Significant Accounting Policies, to the consolidated financial statements included elsewhere in this Annual Report on Form
10-K.


43


---

**ITEM 7A. QUANTITATIVE AND QUALITATIVE DISCLOSURES ABOUT MARKET RISK**


**Foreign Currency Risk**


We transact business globally in multiple currencies and hence have foreign currency risks related to our revenue, costs of revenue and operating
expenses denominated in currencies other than the U.S. dollar (primarily the Chinese yuan and euro in relation to our current year operations). In general,
we are a net receiver of currencies other than the U.S. dollar for our foreign subsidiaries. Accordingly, changes in exchange rates affect our operating
results as expressed in U.S. dollars as we do not typically hedge foreign currency risk.


We have also experienced, and will continue to experience, fluctuations in our net income as a result of gains (losses) on the settlement and the remeasurement of monetary assets and liabilities denominated in currencies that are not the local currency (primarily consisting of our intercompany and
cash and cash equivalents balances).


We considered the historical trends in foreign currency exchange rates and determined that it is reasonably possible that adverse changes in foreign
currency exchange rates of 10% for all currencies could be experienced in the near-term. These changes were applied to our total monetary assets and
liabilities denominated in currencies other than our local currencies at the balance sheet date to compute the impact these changes would have had on
our net income before income taxes. These changes would have resulted in a gain or loss of $1.15 billion at December 31, 2024 and $1.01 billion at
December 31, 2023, assuming no foreign currency hedging.


44


---

**ITEM 8. FINANCIAL STATEMENTS AND SUPPLEMENTARY DATA**


**Index to Consolidated Financial Statements**


Page


Report of Independent Registered Public Accounting Firm (PCAOB ID: 238) 46


Consolidated Balance Sheets 48


Consolidated Statements of Operations 49


Consolidated Statements of Comprehensive Income 50


Consolidated Statements of Redeemable Noncontrolling Interests and Equity 51


Consolidated Statements of Cash Flows 52


Notes to Consolidated Financial Statements 53


45


---

**Report of Independent Registered Public Accounting Firm**


To the Board of Directors and Stockholders of Tesla, Inc.


**Opinions on the Financial Statements and Internal Control over Financial Reporting**


We have audited the accompanying consolidated balance sheets of Tesla, Inc. and its subsidiaries (the "Company") as of December 31, 2024 and 2023,
and the related consolidated statements of operations, of comprehensive income, of redeemable noncontrolling interests and equity and of cash flows for
each of the three years in the period ended December 31, 2024, including the related notes (collectively referred to as the "consolidated financial
statements"). We also have audited the Company's internal control over financial reporting as of December 31, 2024, based on criteria established in
Internal Control - Integrated Framework (2013) issued by the Committee of Sponsoring Organizations of the Treadway Commission (COSO).


In our opinion, the consolidated financial statements referred to above present fairly, in all material respects, the financial position of the Company as of
December 31, 2024 and 2023, and the results of its operations and its cash flows for each of the three years in the period ended December 31, 2024 in
conformity with accounting principles generally accepted in the United States of America. Also in our opinion, the Company maintained, in all material
respects, effective internal control over financial reporting as of December 31, 2024, based on criteria established in Internal Control - Integrated
Framework (2013) issued by the COSO.


Change in Accounting Principle


As discussed in Note 2 to the consolidated financial statements, the Company changed the manner in which it accounts for digital assets in 2024.


**Basis for Opinions**


The Company's management is responsible for these consolidated financial statements, for maintaining effective internal control over financial reporting,
and for its assessment of the effectiveness of internal control over financial reporting, included in Management’s Report on Internal Control over Financial
Reporting appearing under Item 9A. Our responsibility is to express opinions on the Company’s consolidated financial statements and on the Company's
internal control over financial reporting based on our audits. We are a public accounting firm registered with the Public Company Accounting Oversight
Board (United States) (PCAOB) and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and
the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.


We conducted our audits in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audits to obtain
reasonable assurance about whether the consolidated financial statements are free of material misstatement, whether due to error or fraud, and whether
effective internal control over financial reporting was maintained in all material respects.


Our audits of the consolidated financial statements included performing procedures to assess the risks of material misstatement of the consolidated
financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a
test basis, evidence regarding the amounts and disclosures in the consolidated financial statements. Our audits also included evaluating the accounting
principles used and significant estimates made by management, as well as evaluating the overall presentation of the consolidated financial statements.
Our audit of internal control over financial reporting included obtaining an understanding of internal control over financial reporting, assessing the risk
that a material weakness exists, and testing and evaluating the design and operating effectiveness of internal control based on the assessed risk. Our
audits also included performing such other procedures as we considered necessary in the circumstances. We believe that our audits provide a reasonable
basis for our opinions.


46


---

**Definition and Limitations of Internal Control over Financial Reporting**


A company’s internal control over financial reporting is a process designed to provide reasonable assurance regarding the reliability of financial reporting
and the preparation of financial statements for external purposes in accordance with generally accepted accounting principles. A company’s internal
control over financial reporting includes those policies and procedures that (i) pertain to the maintenance of records that, in reasonable detail, accurately
and fairly reflect the transactions and dispositions of the assets of the company; (ii) provide reasonable assurance that transactions are recorded as
necessary to permit preparation of financial statements in accordance with generally accepted accounting principles, and that receipts and expenditures
of the company are being made only in accordance with authorizations of management and directors of the company; and (iii) provide reasonable
assurance regarding prevention or timely detection of unauthorized acquisition, use, or disposition of the company’s assets that could have a material
effect on the financial statements.


Because of its inherent limitations, internal control over financial reporting may not prevent or detect misstatements. Also, projections of any evaluation
of effectiveness to future periods are subject to the risk that controls may become inadequate because of changes in conditions, or that the degree of
compliance with the policies or procedures may deteriorate.


**Critical Audit Matters**


The critical audit matter communicated below is a matter arising from the current period audit of the consolidated financial statements that was
communicated or required to be communicated to the audit committee and that (i) relates to accounts or disclosures that are material to the consolidated
financial statements and (ii) involved our especially challenging, subjective, or complex judgments. The communication of critical audit matters does not
alter in any way our opinion on the consolidated financial statements, taken as a whole, and we are not, by communicating the critical audit matter below,
providing a separate opinion on the critical audit matter or on the accounts or disclosures to which it relates.


Automotive Warranty Reserve


As described in Note 2 to the consolidated financial statements, total accrued warranty, which primarily relates to the automotive segment, was $6,716
million as of December 31, 2024. The Company provides a manufacturer’s warranty on all new and used Tesla vehicles. A warranty reserve is accrued for
these products sold, which includes management’s best estimate of the projected costs to repair or replace items under warranty and recalls if identified.
These estimates are based on actual claims incurred to date and an estimate of the nature, frequency and costs of future claims.


The principal considerations for our determination that performing procedures relating to the automotive warranty reserve is a critical audit matter are (i)
the significant judgment by management in determining the automotive warranty reserve for certain Tesla vehicle models; (ii) a high degree of auditor
judgment, subjectivity, and effort in performing procedures and evaluating management’s significant assumptions related to the nature, frequency and
costs of future claims for certain Tesla vehicle models; and, (iii) the audit effort involved the use of professionals with specialized skill and knowledge.


Addressing the matter involved performing procedures and evaluating audit evidence in connection with forming our overall opinion on the consolidated
financial statements. These procedures included testing the effectiveness of controls relating to management’s estimate of the automotive warranty
reserve for certain Tesla vehicle models, including controls over management’s significant assumptions related to the nature, frequency and costs of
future claims as well as the completeness and accuracy of actual claims incurred to date. These procedures also included, among others, (i) testing the
completeness and accuracy of historical vehicle claims processed and testing that such claims were appropriately used by management in the estimation
of future claims and (ii) the involvement of professionals with specialized skill and knowledge to assist in evaluating the reasonableness of management’s
estimate by (a) developing an independent estimate of the automotive warranty reserve for certain Tesla vehicle models and (b) comparing the
independent estimate to management’s estimate. Developing the independent estimate involved evaluating the appropriateness of certain aspects of
management’s significant assumptions related to the nature and frequency of future claims.


/s/ PricewaterhouseCoopers LLP


San Jose, California
January 29, 2025


We have served as the Company’s auditor since 2005.


47


---

**Tesla, Inc.**


**Consolidated Balance Sheets**
**(in millions, except per share data)**


**December 31,**

**2024**


**December 31,**

**2023**


**Assets**


Current assets


Cash and cash equivalents $ 16,139 $ 16,398


Short-term investments 20,424 12,696


Accounts receivable, net 4,418 3,508


Inventory 12,017 13,626


Prepaid expenses and other current assets 5,362 3,388


Total current assets 58,360 49,616


Operating lease vehicles, net 5,581 5,989


Solar energy systems, net 4,924 5,229


Property, plant and equipment, net 35,836 29,725


Operating lease right-of-use assets 5,160 4,180


Digital assets, net 1,076 184


Intangible assets, net 150 178


Goodwill 244 253


Deferred tax assets 6,524 6,733


Other non-current assets 4,215 4,531


**Total assets** $ 122,070 $ 106,618


**Liabilities**


Current liabilities


Accounts payable $ 12,474 $ 14,431


Accrued liabilities and other 10,723 9,080


Deferred revenue 3,168 2,864


Current portion of debt and finance leases 2,456 2,373


Total current liabilities 28,821 28,748


Debt and finance leases, net of current portion 5,757 2,857


Deferred revenue, net of current portion 3,317 3,251


Other long-term liabilities 10,495 8,153


**Total liabilities** 48,390 43,009


Commitments and contingencies (Note 14)


Redeemable noncontrolling interests in subsidiaries 63 242


**Equity**


Stockholders’ equity


Preferred stock; $0.001 par value; 100 shares authorized; no shares issued and outstanding  -

Common stock; $0.001 par value; 6,000 shares authorized; 3,216 and 3,185 shares issued and outstanding as of

December 31, 2024 and December 31, 2023, respectively 3 3


Additional paid-in capital 38,371 34,892


Accumulated other comprehensive loss (670) (143)


Retained earnings 35,209 27,882


Total stockholders’ equity 72,913 62,634


Noncontrolling interests in subsidiaries 704 733


**Total liabilities and equity** $ 122,070 $ 106,618


The accompanying notes are an integral part of these consolidated financial statements.


48


---

**Tesla, Inc.**


**Consolidated Statements of Operations**

**(in millions, except per share data)**


**Year Ended December 31,**


**2024** **2023** **2022**


**Revenues**


Automotive sales $ 72,480 $ 78,509 $ 67,210


Automotive regulatory credits 2,763 1,790 1,776


Automotive leasing 1,827 2,120 2,476


Total automotive revenues 77,070 82,419 71,462


Energy generation and storage 10,086 6,035 3,909


Services and other 10,534 8,319 6,091


Total revenues 97,690 96,773 81,462


**Cost of revenues**


Automotive sales 61,870 65,121 49,599


Automotive leasing 1,003 1,268 1,509


Total automotive cost of revenues 62,873 66,389 51,108


Energy generation and storage 7,446 4,894 3,621


Services and other 9,921 7,830 5,880


Total cost of revenues 80,240 79,113 60,609


**Gross profit** 17,450 17,660 20,853


**Operating expenses**


Research and development 4,540 3,969 3,075


Selling, general and administrative 5,150 4,800 3,946


Restructuring and other 684  - 176


Total operating expenses 10,374 8,769 7,197


**Income from operations** 7,076 8,891 13,656


Interest income 1,569 1,066 297


Interest expense (350) (156) (191)


Other income (expense), net 695 172 (43)


**Income before income taxes** 8,990 9,973 13,719


Provision for (benefit from) income taxes 1,837 (5,001) 1,132


**Net income** 7,153 14,974 12,587


Net income (loss) attributable to noncontrolling interests and redeemable noncontrolling interests

in subsidiaries 62 (23) 31


**Net income attributable to common stockholders** $ 7,091 $ 14,997 $ 12,556


Net income per share of common stock attributable to common stockholders


Basic $ 2.23 $ 4.73 $ 4.02


Diluted $ 2.04 $ 4.30 $ 3.62


Weighted average shares used in computing net income per share of common stock


Basic 3,197 3,174 3,130


Diluted 3,498 3,485 3,475


The accompanying notes are an integral part of these consolidated financial statements.


49


---

**Tesla, Inc.**


**Consolidated Statements of Comprehensive Income**

**(in millions)**


**Year Ended December 31,**


**2024** **2023** **2022**


Net income $ 7,153 $ 14,974 $ 12,587


Other comprehensive income (loss):


Foreign currency translation adjustment (539) 198 (392)


Unrealized net gain (loss) on investments, net of tax 12 16 (23)


Net loss realized and included in net income  - 4

Comprehensive income 6,626 15,192 12,172


Less: Comprehensive income (loss) attributable to noncontrolling interests and

redeemable noncontrolling interests in subsidiaries 62 (23) 31

Comprehensive income attributable to common stockholders $ 6,564 $ 15,215 $ 12,141


The accompanying notes are an integral part of these consolidated financial statements.


50


---

**Tesla, Inc.**


**Consolidated Statements of Redeemable Noncontrolling Interests and Equity**

**(in millions)**


The accompanying notes are an integral part of these consolidated financial statements.


51


---

**Tesla, Inc.**


**Consolidated Statements of Cash Flows**

**(in millions)**


**Year Ended December 31,**


**2024** **2023** **2022**


**Cash Flows from Operating Activities**


Net income $ 7,153 $ 14,974 $ 12,587


Adjustments to reconcile net income to net cash provided by operating activities:


Depreciation, amortization and impairment 5,368 4,667 3,747


Stock-based compensation 1,999 1,812 1,560


Inventory and purchase commitments write-downs 335 463 177


Foreign currency transaction net unrealized (gain) loss (73) (144) 81


Deferred income taxes 477 (6,349) (196)


Non-cash interest and other operating activities 172 81 340


Digital assets (gain) loss, net (589)  - 140


Changes in operating assets and liabilities:


Accounts receivable (1,083) (586) (1,124)


Inventory 937 (1,195) (6,465)


Operating lease vehicles (590) (1,952) (1,570)


Prepaid expenses and other assets (3,273) (2,652) (3,713)


Accounts payable, accrued and other liabilities 3,588 2,605 8,029


Deferred revenue 502 1,532 1,131


Net cash provided by operating activities 14,923 13,256 14,724


**Cash Flows from Investing Activities**


Purchases of property and equipment excluding finance leases, net of sales (11,339) (8,898) (7,158)


Purchases of solar energy systems, net of sales (3) (1) (5)


Proceeds from sales of digital assets - - 936


Purchase of intangible assets - - (9)


Purchases of investments (35,955) (19,112) (5,835)


Proceeds from maturities of investments 28,310 12,353 22


Proceeds from sales of investments 200 138

Receipt of government grants - - 76


Business combinations, net of cash acquired - (64)

Net cash used in investing activities (18,787) (15,584) (11,973)


**Cash Flows from Financing Activities**


Proceeds from issuances of debt 5,744 3,931

Repayments of debt (2,500) (1,351) (3,364)


Proceeds from exercises of stock options and other stock issuances 1,241 700 541


Principal payments on finance leases (381) (464) (502)


Debt issuance costs (14) (29)

Distributions paid to noncontrolling interests in subsidiaries (104) (144) (157)


Payments for buy-outs of noncontrolling interests in subsidiaries (133) (54) (45)


Net cash provided by (used in) financing activities 3,853 2,589 (3,527)


Effect of exchange rate changes on cash and cash equivalents and restricted cash (141) 4 (444)


Net (decrease) increase in cash and cash equivalents and restricted cash (152) 265 (1,220)


Cash and cash equivalents and restricted cash, beginning of period 17,189 16,924 18,144


Cash and cash equivalents and restricted cash, end of period $ 17,037 $ 17,189 $ 16,924


**Supplemental Non-Cash Investing and Financing Activities**


Acquisitions of property and equipment included in liabilities $ 1,410 $ 2,272 $ 2,148


**Supplemental Disclosures**


Cash paid during the period for interest $ 277 $ 126 $ 152


Cash paid during the period for income taxes, net of refunds $ 1,331 $ 1,119 $ 1,203


The accompanying notes are an integral part of these consolidated financial statements.


52


---

**Tesla, Inc.**


**Notes to Consolidated Financial Statements**


**Note 1 – Overview**


Tesla, Inc. (“Tesla”, the “Company”, “we”, “us” or “our”) was incorporated in the State of Delaware on July 1, 2003 and converted to a Texas
corporation on June 13, 2024. We design, develop, manufacture, sell and lease high-performance fully electric vehicles and energy generation and
storage systems, and offer services related to our products.


**Note 2 – Summary of Significant Accounting Policies**


Principles of Consolidation


The accompanying consolidated financial statements have been prepared in conformity with GAAP and reflect our accounts and operations and
those of our subsidiaries in which we have a controlling financial interest. In accordance with the provisions of ASC 810, Consolidation (“ASC 810”), we
consolidate any variable interest entity (“VIE”) of which we are the primary beneficiary. We have formed VIEs with financing fund investors in the ordinary
course of business in order to facilitate the funding and monetization of certain attributes associated with solar energy systems and leases under our
direct vehicle leasing programs. The typical condition for a controlling financial interest ownership is holding a majority of the voting interests of an entity;
however, a controlling financial interest may also exist in entities, such as VIEs, through arrangements that do not involve controlling voting interests. ASC
810 requires a variable interest holder to consolidate a VIE if that party has the power to direct the activities of the VIE that most significantly impact the
VIE’s economic performance and the obligation to absorb losses of the VIE that could potentially be significant to the VIE or the right to receive benefits
from the VIE that could potentially be significant to the VIE. We do not consolidate a VIE in which we have a majority ownership interest when we are not
considered the primary beneficiary. We have determined that we are the primary beneficiary of all the VIEs (see Note 15, Variable Interest Entity
Arrangements). We evaluate our relationships with all the VIEs on an ongoing basis to ensure that we continue to be the primary beneficiary. All
intercompany transactions and balances have been eliminated upon consolidation.


Use of Estimates


The preparation of financial statements in conformity with GAAP requires management to make estimates and assumptions that affect the reported
amounts of assets, liabilities, revenues, costs and expenses and related disclosures in the accompanying notes. The estimates used for, but not limited to,
determining significant economic incentive for resale value guarantee arrangements, sales return reserves, resale value guarantee liabilities, income
taxes, the collectability of accounts and finance receivables, inventory valuation, warranties, fair value of long-lived assets, goodwill, fair value of financial
instruments, fair value and residual value of operating lease vehicles and solar energy systems subject to leases could be impacted. We have assessed
the impact and are not aware of any specific events or circumstances that required an update to our estimates and assumptions or materially affected the
carrying value of our assets or liabilities as of the date of issuance of this Annual Report on Form 10-K. These estimates may change as new events occur
and additional information is obtained. Actual results could differ materially from these estimates under different assumptions or conditions.


Reclassifications


Certain prior period balances have been reclassified to conform to the current period presentation in the consolidated financial statements and the
accompanying notes.


53


---

Revenue Recognition


Revenue by source


The following table disaggregates our revenue by major source (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Automotive sales $ 72,480 $ 78,509 $ 67,210


Automotive regulatory credits 2,763 1,790 1,776


Energy generation and storage sales 9,564 5,515 3,376


Services and other 10,534 8,319 6,091

Total revenues from sales and services 95,341 94,133 78,453


Automotive leasing 1,827 2,120 2,476


Energy generation and storage leasing 522 520 533

Total revenues $ 97,690 $ 96,773 $ 81,462


Automotive Segment


Automotive Sales


Automotive sales revenue includes revenues related to cash and financing deliveries of new vehicles, and specific other features and services that
meet the definition of a performance obligation under ASC 606, including access to our FSD(Supervised) features and their ongoing maintenance, internet
connectivity, free Supercharging programs and over-the-air software updates. We recognize revenue on automotive sales upon delivery to the customer,
which is when the control of a vehicle transfers. Payments are typically received at the point control transfers or in accordance with payment terms
customary to the business, except sales we finance for which payments are collected over the contractual loan term. We also recognize a sales return
reserve based on historical experience plus consideration for expected future market values, when we offer resale value guarantees or similar buyback
terms. Other features and services such as access to our internet connectivity, unlimited free Supercharging and over-the-air software updates are
provisioned upon control transfer of a vehicle and recognized over time on a straight-line basis as we have a stand-ready obligation to deliver such
services to the customer. Other limited free Supercharging incentives are recognized based on actual usage or expiration, whichever is earlier. We
recognize revenue related to these other features and services over the performance period, which is generally the expected ownership life of the vehicle.
Revenue related to FSD (Supervised) features is recognized when functionality is delivered to the customer and their ongoing maintenance is recognized
over time. For our obligations related to automotive sales, we estimate standalone selling price by considering costs used to develop and deliver the
service, third-party pricing of similar options and other information that may be available.


Any fees that are paid or payable by us to a customer’s lender when we arrange the financing are recognized upfront as an offset against
automotive sales revenue. Costs to obtain a contract mainly relate to commissions for the sale of vehicles. As our contract costs related to automotive
sales are typically fulfilled within one year, the costs to obtain a contract are expensed as incurred. Amounts billed to customers related to shipping and
handling are classified as automotive sales revenue, and we have elected to recognize the cost for freight and shipping when control over vehicles, parts
or accessories have transferred to the customer as an expense in cost of automotive sales revenue. Our policy is to exclude taxes collected from a
customer from the transaction price of automotive contracts.


We offer resale value guarantees to our commercial banking partners in connection with certain vehicle leasing programs. Under these programs,
we originate the lease with our end customer and immediately transfer the lease and the underlying vehicle to our commercial banking partner, with the
transaction being accounted for as a sale under ASC 606.


54


---

We receive upfront payment for the vehicle, do not bear casualty and credit risks during the lease term, and we provide a guarantee capped to a
limit if they are unable to sell the vehicle at or above the vehicle’s contractual or determined residual value at the end of the lease term. We estimate a
guarantee liability in accordance with ASC 460, Guarantees and record it within other liabilities on our consolidated balance sheet. On a quarterly basis,
we assess the estimated market value of vehicles sold under these programs to determine whether there have been changes to the amount of expected
resale value guarantee liabilities. As we accumulate more data related to the resale values of our vehicles or as market conditions change, there may be
material changes to their estimated values. The total recorded guarantee liabilities on vehicles sold under these programs were immaterial as of
December 31, 2024 and 2023. Our maximum exposure on the guarantees we provide if they are unable to sell the vehicle at or above the vehicle’s
contractual residual value at the end of the lease term was $1.45 billion and $166 million as of December 31, 2024 and 2023, respectively.


Deferred revenue related to the access to our FSD (Supervised) features and their ongoing maintenance, internet connectivity, free Supercharging
programs and over-the-air software updates primarily on automotive sales consisted of the following (in millions):


**Year Ended December 31,**


**2024** **2023**


Deferred revenue — beginning of period $ 3,536 $ 2,913


Additions 1,343 1,201


Net changes in liability for pre-existing contracts,
including foreign exchange impact (92) 17


Revenue recognized (1,188) (595)

Deferred revenue — end of period $ 3,599 $ 3,536


Deferred revenue is equivalent to the total transaction price allocated to the performance obligations that are unsatisfied, or partially unsatisfied, as
of the balance sheet date. Revenue recognized from the deferred revenue balance as of December 31, 2023 and 2022 was $872 million and $469 million
for the years ended December 31, 2024 and 2023, respectively. Of the total deferred revenue balance as of December 31, 2024, we expect to recognize
$840 million of revenue in the next 12 months. The remaining balance will be recognized at the time of transfer of control of the product or over the
performance period as discussed above in Automotive Sales.


We have financing receivables on our consolidated balance sheets related to loans we provide for financing our automotive deliveries. As of
December 31, 2024 and 2023, we had current net financing receivables of $247 million and $242 million, respectively, in Accounts receivable, net, and
$821 million and $1.04 billion, respectively, in Other non-current assets for the long-term portion.


Automotive Regulatory Credits


We earn tradable credits in the operation of our automotive business under various regulations related to ZEVs, greenhouse gas, fuel economy and
clean fuel. We sell these credits to other regulated entities who can use the credits to comply with emission standards and other regulatory requirements.


Payments for automotive regulatory credits are typically received at the point control transfers to the customer, or in accordance with payment
terms customary to the business. We recognize revenue on the sale of automotive regulatory credits, which have negligible incremental costs associated
with them, at the time control of the regulatory credits is transferred to the purchasing party. Deferred revenue related to sales of automotive regulatory
credits was immaterial as of December 31, 2024 and 2023. Revenue recognized from the deferred revenue balance as of December 31, 2023 and 2022
was immaterial for the years ended December 31, 2024 and 2023. During the year ended December 31, 2022, we had also recognized $288 million in
revenue due to changes in regulation which entitled us to additional consideration for credits sold previously. We have elected the practical expedient to
omit disclosure of the amount of the transaction price allocated to remaining performance obligations for contracts with an original expected contract
length of one year or less. As of December 31, 2024, total transaction price allocated to performance obligations that were unsatisfied or partially
unsatisfied for contracts with an original expected length of more than one year was $4.68 billion. Of this amount, we expect to recognize $863 million in
the next 12 months and the rest over the remaining performance obligation period. Additionally, changes in regulations on automotive regulatory credits
may significantly impact our remaining performance obligations and revenue to be recognized under these contracts.


55


---

Automotive Leasing Revenue


Direct Vehicle Operating Leasing Program


We have outstanding leases under our direct vehicle operating leasing programs in the U.S., Canada and in certain countries in Europe. Qualifying
customers are permitted to lease a vehicle directly from Tesla for up to 48 months. At the end of the lease term, customers may opt to return the vehicles
to us or purchase the vehicles when contractually permitted. We account for these leasing transactions as operating leases. We record leasing revenues
to automotive leasing revenue on a straight-line basis over the contractual term, and we record the depreciation of these vehicles to cost of automotive
leasing revenue. For the years ended December 31, 2024, 2023 and 2022, we recognized $1.78 billion, $1.86 billion and $1.75 billion of direct vehicle
leasing revenue, respectively. As of December 31, 2024 and 2023, we had deferred $394 million and $458 million, respectively, of lease-related upfront
payments, which will be recognized on a straight-line basis over the contractual terms of the individual leases.


Our policy is to exclude taxes collected from a customer from the transaction price of automotive contracts.


Direct Sales-Type Leasing Program


We have outstanding direct leases and vehicles financed by us under loan arrangements accounted for as sales-type leases under ASC 842, Leases
(“ASC 842”), in certain countries in Asia and Europe. Our arrangements under these programs can have terms for up to 72 months. We recognize all
revenue and costs associated with the sales-type lease as automotive leasing revenue and automotive leasing cost of revenue, respectively, upon
delivery of the vehicle to the customer. Interest income based on the implicit rate in the lease is recorded to automotive leasing revenue over time as
customers are invoiced on a monthly basis. For the years ended December 31, 2024, 2023 and 2022, we recognized $12 million, $215 million and $683
million, respectively, of sales-type leasing revenue and $7 million, $164 million and $427 million, respectively, of sales-type leasing cost of revenue.


Services and Other Revenue


Services and other revenue consists of sales of used vehicles, non-warranty maintenance services and collision, part sales, paid Supercharging,
insurance services revenue and retail merchandise sales.


Revenues related to repair, maintenance and vehicle insurance services are recognized over time as services are provided and extended service
plans are recognized over the performance period of the service contract as the obligation represents a stand-ready obligation to the customer. We sell
used vehicles, services, service plans, vehicle components and merchandise separately and thus use standalone selling prices as the basis for revenue
allocation to the extent that these items are sold in transactions with other performance obligations. Payment for used vehicles, services, vehicle
components, and merchandise are typically received at the point when control transfers to the customer or in accordance with payment terms customary
to the business. Payments received for prepaid plans are refundable upon customer cancellation of the related contracts and are included within Accrued
liabilities and other on the consolidated balance sheets. We record in Deferred revenue any non-refundable prepayment amounts that are collected from
customers and unearned insurance premiums, which is recognized as revenue ratably over the respective customer contract term. Deferred revenue
excluding unearned insurance premiums was not material as of December 31, 2024 and 2023.


Energy Generation and Storage Segment


Energy Generation and Storage Sales


Energy generation and storage sales revenue consists of the sale of solar energy systems and energy storage systems to residential, small
commercial, large commercial and utility grade customers. Sales of solar energy systems to residential and small-scale commercial customers consist of
the engineering, design and installation of the system. Residential and small-scale commercial customers pay the full purchase price of the solar energy
system upfront. Revenue for the design and installation obligation is recognized when control transfers, which is when we install a solar energy system
and the system passes inspection by the utility or the authority having jurisdiction. Sales of energy storage systems to residential and small-scale
commercial customers consist of the installation of the energy storage system and revenue is recognized when control transfers, which is when the
product has been delivered or, if we are performing installation, when installed and commissioned. Payment for such storage systems is made upon
invoice or in accordance with payment terms customary to the business.


56


---

For certain large commercial and utility grade energy storage system sales which consist of the engineering, design and installation of the system,
customers make milestone payments that are consistent with contract-specific phases of a project. Revenue from such contracts is recognized over time
using the percentage of completion method based on cost incurred as a percentage of total estimated contract costs for energy storage system sales.


In instances where there are multiple performance obligations in a single contract, we allocate the consideration to the various obligations in the
contract based on the relative standalone selling price method. Standalone selling prices are estimated based on estimated costs plus margin or by using
market data for comparable products. Costs to obtain a contract relate mainly to commissions paid to our sales personnel related to the sale of energy
storage systems. As our contract costs related to energy storage system sales are typically fulfilled within one year, the costs to obtain a contract are
expensed as incurred.


As part of certain energy storage system contracts, we may provide the customer with performance guarantees that warrant that the underlying
system will meet or exceed the minimum energy performance requirements specified in the contract. If an energy storage system does not meet the
performance guarantee requirements, we may be required to pay liquidated damages. Other forms of variable consideration related to our large
commercial and utility grade energy storage system contracts include variable customer payments that will be made based on our energy market
participation activities. Such guarantees and variable customer payments represent a form of variable consideration and are estimated at contract
inception at their most likely amount and updated at the end of each reporting period as additional performance data becomes available. Such estimates
are included in the transaction price only to the extent that it is probable a significant reversal of revenue will not occur.


We record as deferred revenue any non-refundable amounts that are primarily related to prepayments from customers, which is recognized as
revenue as or when the performance obligations are satisfied. As of December 31, 2024 and 2023, deferred revenue related to such customer payments
amounted to $1.77 billion and $1.60 billion, respectively, mainly due to contractual payment terms. Revenue recognized from the deferred revenue
balance as of December 31, 2023 and 2022 was $1.27 billion and $571 million for the years ended December 31, 2024 and 2023, respectively. We have
elected the practical expedient to omit disclosure of the amount of the transaction price allocated to remaining performance obligations for energy
generation and storage sales with an original expected contract length of one year or less and the amount that we have the right to invoice when that
amount corresponds directly with the value of the performance to date. As of December 31, 2024, total transaction price allocated to performance
obligations that were unsatisfied or partially unsatisfied for contracts with an original expected length of more than one year was $7.18 billion. Of this
amount, we expect to recognize $4.51 billion in the next 12 months and the rest over the remaining performance obligation period.


We have financing receivables on our consolidated balance sheets related to loans we provide for financing our energy products. As of
December 31, 2024 and 2023, we had current net financing receivables of $34 million and $31 million, respectively, in Accounts receivable, net, and
$658 million and $578 million, respectively, in Other non-current assets for the long-term portion.


Energy Generation and Storage Leasing


For revenue arrangements where we are the lessor under operating lease agreements for energy generation and storage products, we record lease
revenue from minimum lease payments, including upfront rebates and incentives earned from such systems, on a straight-line basis over the life of the
lease term, assuming all other revenue recognition criteria have been met. The difference between the payments received and the revenue recognized is
recorded as deferred revenue or deferred asset on the consolidated balance sheet.


For solar energy systems where customers purchase electricity from us under PPAs prior to January 1, 2019, we have determined that these
agreements should be accounted for as operating leases pursuant to ASC 840, Leases. Revenue is recognized based on the amount of electricity
delivered at rates specified under the contracts, assuming all other revenue recognition criteria are met.


We record as deferred revenue any amounts that are collected from customers, including lease prepayments, in excess of revenue recognized,
which is recognized as revenue ratably over the respective customer contract term. As of December 31, 2024 and 2023, deferred revenue related to such
customer payments amounted to $164 million and $181 million, respectively. Deferred revenue also includes the portion of rebates and incentives
received from utility companies and various local and state government agencies, which is recognized as revenue over the lease term. As of
December 31, 2024 and 2023, deferred revenue from rebates and incentives was immaterial.


57


---

We capitalize initial direct costs from the execution of agreements for solar energy systems and PPAs, which include the referral fees and sales
commissions, as an element of solar energy systems, net, and subsequently amortize these costs over the term of the related agreements.


Cost of Revenues


Automotive Segment


Automotive Sales


Cost of automotive sales revenue includes direct and indirect materials, labor costs, manufacturing overhead, including depreciation costs of tooling
and machinery, shipping and logistic costs, vehicle connectivity costs, FSD (Supervised) ongoing maintenance costs, electricity costs for our free
Supercharging programs and reserves for estimated warranty expenses. Cost of automotive sales revenues also includes adjustments to warranty
expense and charges to write down the carrying value of our inventory when it exceeds its estimated net realizable value and to provide for obsolete and
on-hand inventory in excess of forecasted demand. Additionally, cost of automotive sales revenue benefits from manufacturing credits earned, amounting
to $625 million and $359 million for the years ended December 31, 2024 and 2023, respectively.


Automotive Leasing


Cost of automotive leasing revenue includes the depreciation of operating lease vehicles, cost of goods sold associated with direct sales-type leases
and warranty expense related to leased vehicles.


Services and Other


Costs of services and other revenue includes cost of used vehicles including refurbishment costs, costs associated with providing non-warranty
after-sales services, costs associated with our body shops and part sales, costs of paid Supercharging, costs to provide vehicle insurance and costs of
retail merchandise sales.


Energy Generation and Storage Segment


Energy Generation and Storage


Cost of energy generation and storage revenue includes direct and indirect material and labor costs, manufacturing overhead, including
depreciation costs of tooling and machinery, freight, warranty expense, and cost of servicing. Cost of energy generation and storage revenue also
includes charges to write down the carrying value of our inventory when it exceeds its estimated net realizable value and to provide for obsolete and onhand inventory in excess of forecasted demand. Additionally, cost of energy generation and storage revenue benefits from manufacturing credits earned,
amounting to $756 million and $115 million for the years ended December 31, 2024 and 2023, respectively. In agreements for solar energy systems and
PPAs where we are the lessor, the cost of revenue is primarily comprised of depreciation of the cost of leased solar energy systems, maintenance costs
associated with those systems and amortization of any initial direct costs.


Research and Development Costs


Research and development costs are expensed as incurred.


Income Taxes


We are subject to income taxes in the U.S. and in many foreign jurisdictions. Income taxes are computed using the asset and liability method, under
which deferred tax assets and liabilities are determined based on the difference between the financial statement and tax bases of assets and liabilities
using enacted tax rates in effect for the year in which the differences are expected to affect taxable income. Valuation allowances are established when
necessary to reduce deferred tax assets to the amount expected to be realized.


58


---

Significant judgment is required in determining our provision for income taxes, our deferred tax assets and liabilities and any valuation allowance
recorded against our net deferred tax assets that are not more likely than not to be realized. We monitor the realizability of our deferred tax assets taking
into account all relevant factors at each reporting period. In completing our assessment of realizability of our deferred tax assets, we consider our history
of income (loss) measured at pre-tax income (loss) adjusted for permanent book-tax differences on a jurisdictional basis, volatility in actual earnings,
excess tax benefits related to stock-based compensation in recent prior years and impacts of the timing of reversal of existing temporary differences. We
also rely on our assessment of the Company’s projected future results of business operations, including uncertainty in future operating results relative to
historical results, volatility in the market price of our common stock and its performance over time, variable macroeconomic conditions impacting our
ability to forecast future taxable income, and changes in business that may affect the existence and magnitude of future taxable income. Our valuation
allowance assessment is based on our best estimate of future results considering all available information.


We record liabilities related to uncertain tax positions when, despite our belief that our tax return positions are supportable, we believe that it is
more likely than not that those positions may not be fully sustained upon review by tax authorities. Accrued interest and penalties related to
unrecognized tax benefits are classified as income tax expense.


The Tax Cuts and Jobs Act subjects a U.S. shareholder to tax on global intangible low-taxed income (“GILTI”) earned by certain foreign subsidiaries.
Under GAAP, we can make an accounting policy election to either treat taxes due on the GILTI inclusion as a current period expense or factor such
amounts into our measurement of deferred taxes. We elected the deferred method, under which we recorded the corresponding deferred tax assets and
liabilities in our consolidated balance sheets.


Comprehensive Income


Comprehensive income is comprised of net income and other comprehensive income (loss). Other comprehensive income (loss) consists of foreign
currency translation adjustments and unrealized net gains and losses on investments that have been excluded from the determination of net income.


Stock-Based Compensation


We use the fair value method of accounting for our stock options and RSUs granted to employees and for our ESPP to measure the cost of employee
services received in exchange for the stock-based awards. The fair value of stock option awards with only service and/or performance conditions is
estimated on the grant or offering date using the Black-Scholes option-pricing model. The Black-Scholes option-pricing model requires inputs such as the
risk-free interest rate, expected term and expected volatility. These inputs are subjective and generally require significant judgment. The fair value of
RSUs is measured on the grant date based on the closing fair market value of our common stock. The resulting cost is recognized over the period during
which an employee is required to provide service in exchange for the awards, usually the vesting period, which is generally four years for stock options
and RSUs and six months for the ESPP. Stock-based compensation expense is recognized on a straight-line basis, net of actual forfeitures in the period.


For performance-based awards, stock-based compensation expense is recognized over the expected performance achievement period of individual
performance milestones when the achievement of each individual performance milestone becomes probable.


As we accumulate additional employee stock-based awards data over time and as we incorporate market data related to our common stock, we may
calculate significantly different volatilities and expected lives, which could materially impact the valuation of our stock-based awards and the stock-based
compensation expense that we will recognize in future periods. Stock-based compensation expense is recorded in Cost of revenues, Research and
development expense and Selling, general and administrative expense in the consolidated statements of operations.


59


---

Noncontrolling Interests and Redeemable Noncontrolling Interests


Noncontrolling interests and redeemable noncontrolling interests represent third-party interests in the net assets under certain funding
arrangements, or funds, that we have entered into to finance the costs of solar energy systems and vehicles under operating leases. We have determined
that the contractual provisions of the funds represent substantive profit-sharing arrangements. We have further determined that the methodology for
calculating the noncontrolling interest and redeemable noncontrolling interest balances that reflects the substantive profit-sharing arrangements is a
balance sheet approach using the hypothetical liquidation at book value (“HLBV”) method. We, therefore, determine the amount of the noncontrolling
interests and redeemable noncontrolling interests in the net assets of the funds at each balance sheet date using the HLBV method, which is presented on
the consolidated balance sheet as noncontrolling interests in subsidiaries and redeemable noncontrolling interests in subsidiaries. Under the HLBV
method, the amounts reported as noncontrolling interests and redeemable noncontrolling interests in the consolidated balance sheet represent the
amounts the third parties would hypothetically receive at each balance sheet date under the liquidation provisions of the funds, assuming the net assets
of the funds were liquidated at their recorded amounts determined in accordance with GAAP and with tax laws effective at the balance sheet date and
distributed to the third parties. The third parties’ interests in the results of operations of the funds are determined as the difference in the noncontrolling
interest and redeemable noncontrolling interest balances in the consolidated balance sheets between the start and end of each reporting period, after
taking into account any capital transactions between the funds and the third parties. However, the redeemable noncontrolling interest balance is at least
equal to the redemption amount. The redeemable noncontrolling interest balance is presented as temporary equity in the mezzanine section of the
consolidated balance sheet since these third parties have the right to redeem their interests in the funds for cash or other assets.


Net Income per Share of Common Stock Attributable to Common Stockholders


Basic net income per share of common stock attributable to common stockholders is calculated by dividing net income attributable to common
stockholders by the weighted-average shares of common stock outstanding for the period. Potentially dilutive shares, which are based on the weightedaverage shares of common stock underlying outstanding stock-based awards, warrants and convertible senior notes using the treasury stock method or
the if-converted method, as applicable, are included when calculating diluted net income per share of common stock attributable to common stockholders
when their effect is dilutive.


The following table presents the reconciliation of net income attributable to common stockholders to net income used in computing basic and
diluted net income per share of common stock (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Net income attributable to common stockholders $ 7,091 $ 14,997 $ 12,556


Less: Buy-outs of noncontrolling interests (39) (2) (27)


Net income used in computing basic net income per share of common stock 7,130 14,999 12,583


Less: Dilutive convertible debt - - (1)


Net income used in computing diluted net income per share of common stock $ 7,130 $ 14,999 $ 12,584


60


---

The following table presents the reconciliation of basic to diluted weighted average shares used in computing net income per share of common
stock attributable to common stockholders (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Weighted average shares used in computing net income per share of common stock,
basic 3,197 3,174 3,130


Add:


Stock-based awards 292 298 310


Convertible senior notes 1 2 3


Warrants 8 11 32


Weighted average shares used in computing net income per share of common stock,
diluted 3,498 3,485 3,475


The following table presents the potentially dilutive shares that were excluded from the computation of diluted net income per share of common
stock attributable to common stockholders, because their effect was anti-dilutive (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Stock-based awards 15 12 4


Cash and Cash Equivalents


All highly liquid investments with an original maturity of three months or less at the date of purchase are considered cash equivalents.


Restricted Cash


We maintain certain cash balances restricted as to withdrawal or use. Our restricted cash is comprised primarily of cash held to service certain
payments under various secured debt facilities, cash held as collateral for sales to lease partners with a resale value guarantee and deposits held for our
insurance services. We record restricted cash as other assets in the consolidated balance sheets and determine current or non-current classification
based on the expected duration of the restriction.


Our total cash and cash equivalents and restricted cash, as presented in the consolidated statements of cash flows, was as follows (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


**December 31,**

**2022**


Cash and cash equivalents $ 16,139 $ 16,398 $ 16,253


Restricted cash included in prepaid expenses and other current assets 494 543 294


Restricted cash included in other non-current assets 404 248 377

Total as presented in the consolidated statements of cash flows $ 17,037 $ 17,189 $ 16,924


Investments


Our investments are all designated as available-for-sale and reported at estimated fair value, with unrealized gains and losses recorded in
accumulated other comprehensive loss which is included within stockholders’ equity. Available-for-sale marketable securities with maturities greater than
three months at the date of purchase are included in short-term investments in our consolidated balance sheets. Interest, dividends, amortization and
accretion of purchase premiums and discounts on these investments are included within Interest income in our consolidated statements of operations.
Interest income on our short-term investments for the years ended December 31, 2024, 2023 and 2022 was $763 million, $388 million and an immaterial
amount, respectively.


61


---

The cost of available-for-sale investments sold is based on the specific identification method. Realized gains and losses on the sale of available-forsale investments are recorded in Other income (expense), net.


We regularly review all of our investments for declines in fair value. The review includes but is not limited to (i) the consideration of the cause of the
decline, (ii) any currently recorded expected credit losses and (iii) the creditworthiness of the respective security issuers. The amortized cost basis of our
investments approximates its fair value.


Accounts Receivable and Allowance for Doubtful Accounts


Accounts receivable primarily include amounts related to receivables from financial institutions and leasing companies offering various financing
products to our customers, sales of energy generation and storage products, sales of regulatory credits to other automotive manufacturers and
government rebates already passed through to customers. We provide an allowance against accounts receivable for the amount we expect to be
uncollectible. We write-off accounts receivable against the allowance when they are deemed uncollectible.


Depending on the day of the week on which the end of a fiscal quarter falls, our accounts receivable balance may fluctuate as we are waiting for
certain customer payments to clear through our banking institutions and receipts of payments from our financing partners, which can take up to
approximately two weeks based on the contractual payment terms with such partners. Our accounts receivable balances associated with sales of energy
storage products are dependent on billing milestones and payment terms negotiated for each contract, and our accounts receivable balances associated
with our sales of regulatory credits are dependent on contractual payment terms. Additionally, government rebates can take up to a year or more to be
collected depending on the customary processing timelines of the specific jurisdictions issuing them. These various factors may have a significant impact
on our accounts receivable balance from period to period. As of December 31, 2024 and 2023, government rebates receivable was $315 million and $378
million, respectively, in Accounts receivable, net for the current portion and an immaterial amount and $207 million, respectively, in Other non-current
assets for the long-term portion in our consolidated balance sheets.


Financing Receivables


We provide financing options to our customers for our automotive and energy products. Financing receivables are carried at amortized cost, net of
allowance for loan losses. Provisions for loan losses are charged to operations in amounts sufficient to maintain the allowance for loan losses at levels
considered adequate to cover expected credit losses on the financing receivables. In determining expected credit losses, we consider our historical level
of credit losses, current economic trends, and reasonable and supportable forecasts that affect the collectability of the future cash flows. Interest income
on financing receivables is recognized over the loan term as revenue in the consolidated statements of operations.


When originating consumer receivables, we review the credit application, the proposed contract terms, credit bureau information (e.g., FICO score)
and other information. Our evaluation emphasizes the applicant’s ability to pay and creditworthiness focusing on payment, affordability, and applicant
credit history as key considerations. Generally, all customers in this portfolio have strong creditworthiness at loan origination.


After origination, we review the credit quality of retail financing based on customer payment activity and aging analysis. For all financing
receivables, we define “past due” as any payment, including principal and interest, which is at least 31 days past the contractual due date. As of
December 31, 2024 and 2023, the vast majority of our financing receivables were at current status with an immaterial balance being past due. As of
December 31, 2024 and 2023, the majority of our financing receivables, excluding MyPower notes receivable, were originated in 2023 and 2022.


We have customer notes receivable under the legacy MyPower loan program, which provided residential customers with the option to finance the
purchase of a solar energy system through a 30-year loan and were all originated prior to year 2018. The outstanding balances, net of any allowance for
expected credit losses, are presented on the consolidated balance sheets as a component of Prepaid expenses and other current assets for the current
portion and as Other non-current assets for the long-term portion. As of December 31, 2024 and 2023, the total outstanding balance of MyPower
customer notes receivable, net of allowance for expected credit losses, was $248 million and $266 million, respectively, of which $4 million and $5 million
were due in the next 12 months as of December 31, 2024 and 2023, respectively. As of December 31, 2024 and 2023, the allowance for expected credit
losses was $33 million and $36 million, respectively.


62


---

Concentration of Risk


Credit Risk


Financial instruments that potentially subject us to a concentration of credit risk consist of cash, cash equivalents, investments, restricted cash,
accounts receivable and other finance receivables. Our cash and investments balances are primarily on deposit at high credit quality financial institutions
or invested in highly rated, investment-grade securities. These deposits are typically in excess of insured limits. As of December 31, 2024 and 2023, no
entity represented 10% or more of our total receivables balance.


Supply Risk


We are dependent on our suppliers, including single source suppliers, and the inability of these suppliers to deliver necessary components of our
products in a timely manner at prices, quality levels and volumes acceptable to us, or our inability to efficiently manage these components from these
suppliers, could have a material adverse effect on our business, prospects, financial condition and operating results.


Inventory Valuation


Inventories are stated at the lower of cost or net realizable value. Cost is computed using standard cost for vehicles and energy products, which
approximates actual cost on a first-in, first-out basis. We record inventory write-downs for excess or obsolete inventories based upon assumptions about
current and future demand forecasts. If our inventory on-hand is in excess of our future demand forecast, the excess amounts are written-off.


We also review our inventory to determine whether its carrying value exceeds the net amount realizable upon the ultimate sale of the inventory.
This requires us to determine the estimated selling price of our vehicles less the estimated cost to convert the inventory on-hand into a finished product.
Once inventory is written-down, a new, lower cost basis for that inventory is established and subsequent changes in facts and circumstances do not result
in the restoration or increase in that newly established cost basis.


Should our estimates of future selling prices or production costs change, additional and potentially material write-downs may be required. A small
change in our estimates may result in a material charge to our reported financial results.


Operating Lease Vehicles


Vehicles that are leased as part of our direct vehicle leasing program are classified as operating lease vehicles at cost less accumulated
depreciation. We generally depreciate their cost, less residual value, using the straight-line-method to cost of automotive leasing revenue over the
contractual period. The gross cost of operating lease vehicles as of December 31, 2024 and 2023 was $7.03 billion and $7.36 billion, respectively.
Operating lease vehicles on the consolidated balance sheets are presented net of accumulated depreciation of $1.45 billion and $1.38 billion as of
December 31, 2024 and 2023, respectively.


Digital Assets, Net


We account for all digital assets held as crypto assets, a subset of indefinite-lived intangible assets in accordance with ASC 350-60, Intangibles Goodwill and Other - Crypto Assets. We have ownership of and control over our digital assets and we may use third-party custodial services to secure it.
The digital assets are initially recorded at cost and are subsequently remeasured on the consolidated balance sheet at fair value. Periods prior to January
1, 2024 include digital assets at cost, net of impairment losses incurred since their acquisition.


We determine and record the fair value of our digital assets in accordance with ASC 820, Fair Value Measurement (“ASC 820”), based on quoted
prices on the active exchange(s) that we have determined is the principal market for such assets (Level I inputs). We determine the cost basis of our
digital assets using the specific identification of each unit received. Realized and unrealized gains and losses are now recorded to Other income
(expense), net in our consolidated statement of operations.


63


---

For periods prior to January 1, 2024, impairment losses were recognized within Restructuring and other in the consolidated statements of operations
in the period in which the impairment was identified. Also for periods prior to January 1, 2024, gains were not recorded until realized upon sale(s), at
which point they were presented net of any impairment losses for the same digital assets held within Restructuring and other. In determining the gain to
be recognized upon sale, we calculate the difference between the sales price and carrying value of the digital assets sold immediately prior to sale.


See Note 3, Digital Assets, Net, for further information regarding digital assets.


Solar Energy Systems, Net


We are the lessor of solar energy systems, which are stated at cost less accumulated depreciation. Depreciation of solar energy systems is
calculated using the straight-line method over the estimated useful lives of 30 to 35 years. The gross cost of solar energy systems as of December 31,
2024 and 2023 was $6.79 billion and $6.87 billion, respectively. Solar energy systems on the consolidated balance sheets are presented net of
accumulated depreciation of $1.86 billion and $1.64 billion as of December 31, 2024 and 2023, respectively.


Property, Plant and Equipment, Net


Property, plant and equipment, net, including leasehold improvements, are recognized at cost less accumulated depreciation. Depreciation is
generally computed using the straight-line method over the estimated useful lives of the respective assets, as follows:


Machinery, equipment, vehicles and office furniture 3 to 15 years


Tooling 4 to 7 years


Building and building improvements 15 to 30 years


Computer equipment and software 3 to 6 years


AI infrastructure 5 to 30 years


Leasehold improvements are depreciated on a straight-line basis over their estimated useful lives. AI infrastructure includes our owned data centers.


Upon the retirement or sale of our property, plant and equipment, the cost and associated accumulated depreciation are removed from the
consolidated balance sheet, and the resulting gain or loss is reflected on the consolidated statement of operations. Maintenance and repair expenditures
are expensed as incurred while major improvements that increase the functionality, output or expected life of an asset are capitalized and depreciated
ratably over the identified useful life.


Long-Lived Assets Including Acquired Intangible Assets


We review our property, plant and equipment, solar energy systems, long-term prepayments and intangible assets for impairment whenever events
or changes in circumstances indicate that the carrying amount of an asset (or asset group) may not be recoverable. We measure recoverability by
comparing the carrying amount to the future undiscounted cash flows that the asset is expected to generate. If the asset is not recoverable, its carrying
amount would be adjusted down to its fair value. For the years ended December 31, 2024, 2023 and 2022, we have recognized no material impairments
of our long-lived assets.


Intangible assets with definite lives are amortized on a straight-line basis over their estimated useful lives, which range from seven to thirty years.


Goodwill


We assess goodwill for impairment annually in the fourth quarter, or more frequently if events or changes in circumstances indicate that it might be
impaired, by comparing its carrying value to the reporting unit’s fair value. For the years ended December 31, 2024, 2023, and 2022, we did not
recognize any impairment of goodwill.


64


---

Capitalization of Software Costs


We capitalize costs incurred in the development of internal use software, during the application development stage to Property, plant and
equipment, net on the consolidated balance sheets. Costs related to preliminary project activities and post-implementation activities are expensed as
incurred. Such costs are amortized on a straight-line basis over their estimated useful life of three to five years.


Software development costs incurred in development of software to be sold, leased, or otherwise marketed, incurred subsequent to the
establishment of technological feasibility and prior to the general availability of the software are capitalized when they are expected to become
significant. Such costs are amortized over the estimated useful life of the applicable software once it is made generally available to our customers.


We evaluate the useful lives of these assets on an annual basis, and we test for impairment whenever events or changes in circumstances occur
that could impact the recoverability of these assets. For the years ended December 31, 2024, 2023, and 2022, we have recognized no impairments of
capitalized software costs.


Foreign Currency


We determine the functional and reporting currency of each of our international subsidiaries and their operating divisions based on the primary
currency in which they operate. In cases where the functional currency is not the U.S. dollar, we recognize a cumulative translation adjustment created by
the different rates we apply to current period income or loss and the balance sheet. For each subsidiary, we apply the monthly average functional
exchange rate to its monthly income or loss and the month-end functional currency rate to translate the balance sheet.


Foreign currency transaction gains and losses are a result of the effect of exchange rate changes on transactions denominated in currencies other
than the functional currency of the respective subsidiary. Transaction gains and losses are recognized in Other income (expense), net, in the consolidated
statements of operations. For the years ended December 31, 2024, 2023 and 2022, we recorded a net foreign currency transaction gain of $57 million,
gain of $122 million and loss of $89 million, respectively.


Warranties


We provide a manufacturer’s warranty on all new and used vehicles and a warranty on the installation and components of the energy generation
and storage systems we sell for periods typically between 10 to 25 years. We accrue a warranty reserve for the products sold by us, which includes our
best estimate of the projected costs to repair or replace items under warranties and recalls if identified. These estimates are based on actual claims
incurred to date and an estimate of the nature, frequency and costs of future claims. These estimates are inherently uncertain and changes to our
historical or projected warranty experience may cause material changes to the warranty reserve in the future. The warranty reserve does not include
projected warranty costs associated with our vehicles subject to operating lease accounting and our solar energy systems under lease contracts or PPAs,
as the costs to repair these warranty claims are expensed as incurred. The portion of the warranty reserve expected to be incurred within the next 12
months is included within Accrued liabilities and other, while the remaining balance is included within Other long-term liabilities on the consolidated
balance sheets. For liabilities that we are entitled to receive indemnification from our suppliers, we record receivables for the contractually obligated
amounts on the consolidated balance sheets as a component of Prepaid expenses and other current assets for the current portion and as Other noncurrent assets for the long-term portion. Warranty expense is recorded as a component of Cost of revenues in the consolidated statements of operations.
Due to the magnitude of our automotive business, our accrued warranty balance is primarily related to our automotive segment.Accrued warranty activity
consisted of the following (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Accrued warranty—beginning of period $ 5,152 $ 3,505 $ 2,101


Warranty costs incurred (1,453) (1,225) (803)


Net changes in liability for pre-existing warranties, including expirations and foreign

exchange impact 287 539 522


Provision for warranty 2,730 2,333 1,685

Accrued warranty—end of period $ 6,716 $ 5,152 $ 3,505


65


---

Customer Deposits


Customer deposits primarily consist of refundable cash payments from customers at the time they place an order or reservation for a vehicle or an
energy product and any additional payments up to the point of delivery or the completion of installation. Customer deposits also include prepayments on
contracts that can be cancelled without significant penalties, such as vehicle maintenance plans. Customer deposits are included in Accrued liabilities and
other on the consolidated balance sheets until refunded, forfeited or applied towards the customer’s purchase balance.


Government Assistance Programs and Incentives


Globally, the operation of our business is impacted by various government programs, incentives, and other arrangements. Government incentives
are recorded in our consolidated financial statements in accordance with their purpose as a reduction of expense, or an offset to the related capital asset.
The benefit is generally recorded when all conditions attached to the incentive have been met or are expected to be met and there is reasonable
assurance of their receipt.


The IRA Incentives


On August 16, 2022, the IRA was enacted into law and is effective for taxable years beginning after December 31, 2022. The IRA includes multiple
incentives to promote clean energy, electric vehicles, battery and energy storage manufacture or purchase, in addition to a new corporate alternative
minimum tax of 15% on adjusted financial statement income of corporations with profits greater than $1 billion. Some of these measures are expected to
materially affect our consolidated financial statements. For the years ended December 31, 2024 and 2023, the impact from our IRA incentive was
primarily a reduction of our costs of revenue in our consolidated statements of operations.


Gigafactory New York—New York State Investment and Lease


We have a lease through the Research Foundation for the SUNY Foundation with respect to Gigafactory New York. Under the lease and a related
research and development agreement, we are continuing to designate further buildouts at the facility. We are required to comply with certain covenants,
including hiring and cumulative investment targets. Under the terms of the arrangement, the SUNY Foundation paid for a majority of the construction
costs related to the manufacturing facility and the acquisition and commissioning of certain manufacturing equipment; and we are responsible for any
construction or equipment costs in excess of such amount (refer to Note 14, Commitments and Contingencies). This incentive reduces the related lease
costs of the facility within the Energy generation and storage cost of revenues and operating expense line items in our consolidated statements of
operations and was not material for any period presented.


Gigafactory Shanghai—Land Use Rights and Economic Benefits


We have an agreement with the local government of Shanghai for land use rights at Gigafactory Shanghai. Under the terms of the arrangement, we
are required to meet a cumulative capital expenditure target and an annual tax revenue target starting at the end of 2023. In addition, the Shanghai
government has granted to our Gigafactory Shanghai subsidiary certain incentives to be used in connection with eligible capital investments at
Gigafactory Shanghai (refer to Note 14, Commitments and Contingencies). Incentives that offset costs of our facilities are recorded as a reduction of the
cost of the capital investment within the Property, plant and equipment, net line item in our consolidated balance sheets and incentives related to our
manufacturing operations are recorded as an offset to cost of revenues in our consolidated statements of operations. For the years ended December 31,
2024 and 2023, the amounts received were immaterial.


Nevada Tax Incentives


In connection with the construction of Gigafactory Nevada, we entered into agreements in 2014 with the State of Nevada and Storey County in
Nevada that provide abatements for specified taxes, discounts to the base tariff energy rates and transferable tax credits of up to $195 million in
consideration of capital investment and hiring targets that were met at Gigafactory Nevada.


66


---

Gigafactory Texas Tax Incentives


In connection with the construction of Gigafactory Texas, we entered into a 20-year agreement in 2020 with Travis County in Texas pursuant to
which we would receive grant funding equal to 70-80% of property taxes paid by us to Travis County and a separate 10-year agreement in 2020 with the
Del Valle Independent School District in Texas pursuant to which a portion of the taxable value of our property would be capped at a specified amount, in
each case subject to our meeting certain minimum economic development metrics through our construction and operations at Gigafactory Texas. This
incentive is recorded as a reduction of the related expenses within the Cost of automotive revenues and operating expense line items of our consolidated
statements of operations. For the years ended December 31, 2024, 2023 and 2022, the grant funding related to property taxes paid were immaterial.


Defined Contribution Plan


We have a 401(k) savings plan in the U.S. that is intended to qualify as a deferred salary arrangement under Section 401(k) of the Internal Revenue
Code and a number of savings plans internationally. Under the 401(k) savings plan, participating employees may elect to contribute up to 90% of their
eligible compensation, subject to certain limitations. Beginning in January 2022, we began to match 50% of each employee’s contributions up to a
maximum of 6% (capped at $3,000) of the employee’s eligible compensation, vested upon one year of service. During the years ended December 31,
2024, 2023 and 2022, we recognized $107 million, $99 million and $91 million, respectively, of expenses related to employer contributions for the 401(k)
savings plan.


Recent Accounting Pronouncements


Recently issued accounting pronouncements not yet adopted


In December 2023, the Financial Accounting Standards Board (“FASB”) issued Accounting Standards Update (“ASU”) No. 2023-09, Improvements to
Income Tax Disclosures (Topic 740). The ASU requires disaggregated information about a reporting entity’s effective tax rate reconciliation as well as
additional information on income taxes paid. The ASU is effective on a prospective basis for annual periods beginning after December 15, 2024. Early
adoption is also permitted for annual financial statements that have not yet been issued or made available for issuance. This ASU will likely result in the
required additional disclosures being included in our consolidated financial statements, once adopted.


In November 2024, the FASB issued ASU No. 2024-03, Disaggregation of Income Statement Expenses (Subtopic 220-40). The ASU requires the
disaggregated disclosure of specific expense categories, including purchases of inventory, employee compensation, depreciation, and amortization, within
relevant income statement captions. This ASU also requires disclosure of the total amount of selling expenses along with the definition of selling
expenses. The ASU is effective for annual periods beginning after December 15, 2026, and interim periods within fiscal years beginning after December
15, 2027. Adoption of this ASU can either be applied prospectively to consolidated financial statements issued for reporting periods after the effective
date of this ASU or retrospectively to any or all prior periods presented in the consolidated financial statements. Early adoption is also permitted. This ASU
will likely result in the required additional disclosures being included in our consolidated financial statements, once adopted. We are currently evaluating
the provisions of this ASU.


Recently adopted accounting pronouncements


In November 2023, the FASB issued ASU No. 2023-07, Improvements to Reportable Segment Disclosures (Topic 280). This ASU updates reportable
segment disclosure requirements by requiring disclosures of significant reportable segment expenses that are regularly provided to the Chief Operating
Decision Maker (“CODM”) and included within each reported measure of a segment's profit or loss. This ASU also requires disclosure of the title and
position of the individual identified as the CODM and an explanation of how the CODM uses the reported measures of a segment’s profit or loss in
assessing segment performance and deciding how to allocate resources. The ASU is effective for annual periods beginning after December 15, 2023, and
interim periods within fiscal years beginning after December 15, 2024. We adopted this ASU retrospectively on December 31, 2024. Refer to Note 17,
Segment Reporting and Information about Geographic Areas for the inclusion of the new required disclosures.


67


---

ASU 2023-08


In December 2023, the FASB issued ASU No. 2023-08, Accounting for and Disclosure of Crypto Assets (Subtopic 350-60) (“new crypto assets
standard”). The new crypto assets standard requires certain crypto assets to be measured at fair value separately on the balance sheet with changes
reported in the statement of operations each reporting period. The new crypto assets standard also enhances the other intangible asset disclosure
requirements by requiring the name, cost basis, fair value, and number of units for each significant crypto asset holding. The new crypto assets standard
is effective for annual periods beginning after December 15, 2024, including interim periods within those fiscal years. Adoption of the new crypto assets
standard requires a cumulative-effect adjustment to the opening balance of retained earnings as of the beginning of the annual reporting period in which
an entity adopts the amendments. Early adoption is also permitted, including adoption in an interim period. However, if the new crypto assets standard is
early adopted in an interim period, an entity must adopt the new crypto assets standard as of the beginning of the fiscal year that includes the interim
period. We adopted the new crypto assets standard on a modified retrospective approach effective January 1, 2024. Refer to Note 3, Digital Assets, Net
for the inclusion of the new required disclosures. The cumulative effect of the changes made on our January 1, 2024 consolidated balance sheet for the
adoption of the new crypto assets standard was as follows (in millions):


**Balances at**

**December 31, 2023**


**Adjustments from Adoption of**

**the New Crypto Assets Standard**


**Balances at**

**January 1, 2024**


**Assets**


Digital assets, net $ 184 $ 303 $ 487


Deferred tax assets 6,733 (67) 6,666


**Stockholders' equity**


Retained earnings 27,882 236 28,118


**Note 3 – Digital Assets, Net**


During the years ended December 31, 2024 and 2023, we purchased and/or received immaterial amounts of digital assets. During the years ended
December 31, 2023 and 2022, we recorded an immaterial amount and $204 million of impairment losses on digital assets, respectively. The table below
summarizes the amounts shown on our consolidated balance sheet as of December 31, 2024 (in millions except units of digital assets).


**December 31, 2024**


**Units** **Cost Basis** **Fair Value**


Digital assets held:


Bitcoin 11,509 $ 386 $ 1,074


Other 1 2


Total 387 1,076


The following table provides details of the activities related to our digital assets for the year ended December 31, 2024 (in millions):


Beginning balance at fair value $ 487


Unrealized gains, net 589


Ending balance $ 1,076


The following tables present summarized unaudited quarterly financial statement data for those impacted line items based on the Company’s
adoption of the new crypto assets standard as described in Note 2, Summary of Significant Accounting Policies (in millions, except per share data):


68


---

**As of:**


**Consolidated Balance Sheets (unaudited):** **March 31, 2024** **June 30, 2024** **September 30, 2024**


**Digital assets, net**


Before adoption $ 184 $ 184 $ 184


Adjustments 638 538 545

As adjusted $ 822 $ 722 $ 729


**Deferred tax assets**


Before adoption $ 6,769 $ 6,692 $ 6,486


Adjustments (141) (119) (120)

As adjusted $ 6,628 $ 6,573 $ 6,366


**Three Months Ended**


**Condensed Consolidated Statements of Operations (unaudited):** **March 31, 2024** **June 30, 2024** **September 30, 2024**


**Other income (expense), net**


Before adoption $ 108 $ 20 $ (270)


Adjustments 335 (100) 7

As adjusted $ 443 $ (80) $ (263)


**Provision for (benefit from) income taxes**


Before adoption $ 409 $ 393 $ 601


Adjustments 74 (22) 1

As adjusted $ 483 $ 371 $ 602


**Net income attributable to common stockholders**


Before adoption $ 1,129 $ 1,478 $ 2,167


Adjustments 261 (78) 6

As adjusted $ 1,390 $ 1,400 $ 2,173


**Net income per share of common stock attributable to common**
**stockholders**


Basic


Before adoption $ 0.37 $ 0.46 $ 0.68


Adjustments 0.08 (0.02)
As adjusted $ 0.45 $ 0.44 $ 0.68


Diluted


Before adoption $ 0.34 $ 0.42 $ 0.62


Adjustments 0.07 (0.02)
As adjusted $ 0.41 $ 0.40 $ 0.62


The unaudited impact of adoption for the three months ended December 31, 2024 was to increase Digital assets, net by $347 million, with a
corresponding increase in Other income (expense), net and decrease our Deferred tax assets by $77 million with a corresponding increase in our Provision
for (benefit from) income taxes, thus contributing $270 million to Net income attributable to common stockholders. These amounts contributed $0.08 to
both basic and diluted net income attributable to common stockholders per share of common stock for the three months ended December 31, 2024.


There were no impairment losses recorded for any period during the year ended December 31, 2024. As a result, the unaudited interim balances of
Digital assets, net did not change throughout the year ended December 31, 2024 prior to the adoption of the new crypto assets standard, which was
adopted as of January 1, 2024.


**Note 4 – Goodwill and Intangible Assets**


Goodwill decreased $9 million within the automotive segment from $253 million as of December 31, 2023 to $244 million as of December 31, 2024.
There were no accumulated impairment losses as of December 31, 2024 and 2023.


69


---

The net carrying value of our intangible assets decreased from $178 million as of December 31, 2023 to $150 million as of December 31, 2024
mainly from amortization.


**Note 5 – Fair Value of Financial Instruments**


ASC 820 states that fair value is an exit price, representing the amount that would be received to sell an asset or paid to transfer a liability in an
orderly transaction between market participants. As such, fair value is a market-based measurement that should be determined based on assumptions
that market participants would use in pricing an asset or a liability. The three-tiered fair value hierarchy, which prioritizes which inputs should be used in
measuring fair value, is comprised of: (Level I) observable inputs such as quoted prices in active markets; (Level II) inputs other than quoted prices in
active markets that are observable either directly or indirectly and (Level III) unobservable inputs for which there is little or no market data. The fair value
hierarchy requires the use of observable market data when available in determining fair value. Our assets and liabilities that were measured at fair value
on a recurring basis were as follows (in millions):


**December 31, 2024** **December 31, 2023**


**Fair Value** **Level I** **Level II** **Level III** **Fair Value** **Level I** **Level II** **Level III**


Certificates of deposit and time

deposits $ 12,767 $ - $ 12,767 $ - $ 6,996 $ - $ 6,996 $

Commercial paper 3,919 - 3,919 - 470 - 470

U.S. government securities 3,620 - 3,620 - 5,136 - 5,136

Corporate debt securities 118 - 118 - 480 - 480

Money market funds 1,753 1,753 - - 109 109 -

Digital assets 1,076 1,076 - - Not applicable


Total $ 23,253 $ 2,829 $ 20,424 $ - $ 13,191 $ 109 $ 13,082 $

All of our money market funds and digital assets are classified within Level I of the fair value hierarchy because they were valued using quoted
prices in active markets. Our U.S. government securities, certificates of deposit, commercial paper, time deposits and corporate debt securities are
classified within Level II of the fair value hierarchy and the market approach was used to determine fair value of these investments.


Our cash, cash equivalents and investments classified by security type as of December 31, 2024 and 2023 consisted of the following (in millions):


**December 31, 2024**


**Gross**

**Unrealized**

**Losses** **Fair Value**


**Cash and Cash**

**Equivalents**


**Short-Term**

**Investments**


**Adjusted Cost**


**Gross**

**Unrealized**

**Gains**


Cash $ 14,386 $ - $ - $ 14,386 $ 14,386 $

Certificates of deposit and time deposits 12,767 - - 12,767 - 12,767


Commercial paper 3,908 11 - 3,919 - 3,919


U.S. government securities 3,618 3 (1) 3,620 - 3,620


Corporate debt securities 117 1 - 118 - 118


Money market funds 1,753 - - 1,753 1,753

Total cash, cash equivalents and short-term

investments $ 36,549 $ 15 $ (1) $ 36,563 $ 16,139 $ 20,424


70


---

**Cash and Cash**

**Equivalents**


**December 31, 2023**


**Gross**

**Unrealized**

**Losses** **Fair Value**


**Short-Term**

**Investments**


**Adjusted Cost**


**Gross**

**Unrealized**

**Gains**


Cash $ 15,903 $ - $ - $ 15,903 $ 15,903 $

Certificates of deposit and time deposits 6,995 1 - 6,996 - 6,996


U.S. government securities 5,136 1 (1) 5,136 277 4,859


Corporate debt securities 485 1 (6) 480 - 480


Commercial paper 470 - - 470 109 361


Money market funds 109 - - 109 109

Total cash, cash equivalents and short-term

investments $ 29,098 $ 3 $ (7) $ 29,094 $ 16,398 $ 12,696


As of December 31, 2024, the vast majority of our short-term investments had contractual maturity dates within one year.


Disclosure of Fair Values


Our financial instruments that are not re-measured at fair value include accounts receivable, financing receivables, other receivables, accounts
payable, accrued liabilities, customer deposits and debt. The carrying values of these financial instruments materially approximate their fair values.


**Note 6 – Inventory**


Our inventory consisted of the following (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


Raw materials $ 5,242 $ 5,390


Work in process 1,532 2,016


Finished goods (1) 3,940 5,049


Service parts 1,303 1,171


Total $ 12,017 $ 13,626


(1) Finished goods inventory includes products-in-transit to fulfill customer orders, new vehicles, used vehicles and energy products available for sale.


We write-down inventory for any excess or obsolete inventory or when we believe that the net realizable value of inventory is less than the carrying
value. During the years ended December 31, 2024, 2023 and 2022, we recorded write-downs of $190 million, $233 million and $144 million, respectively,
in Cost of revenues in the consolidated statements of operations.


71


---

**Note 7 – Property, Plant and Equipment, Net**


Our property, plant and equipment, net, consisted of the following (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


Machinery, equipment, vehicles and office furniture $ 18,339 $ 16,309


Land and buildings 10,677 9,498


AI infrastructure 5,152 1,510


Tooling 3,883 3,129


Leasehold improvements 3,688 3,136


Computer equipment, hardware and software 2,902 2,409


Construction in progress 6,783 5,791


51,424 41,782


Less: Accumulated depreciation (15,588) (12,057)


Total $ 35,836 $ 29,725


Construction in progress is primarily comprised of ongoing construction and expansion of our facilities, equipment and tooling related to the
manufacturing of our products as well as AI-related assets which have not yet been placed in service. Completed assets are transferred to their respective
asset classes and depreciation begins when an asset is ready for its intended use.


Depreciation expense during the years ended December 31, 2024, 2023 and 2022 was $4.12 billion, $3.33 billion and $2.42 billion, respectively.


**Note 8 – Accrued Liabilities and Other**


Our accrued liabilities and other current liabilities consisted of the following (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


Accrued purchases (1) $ 2,253 $ 2,721


Accrued warranty reserve, current portion 1,917 1,546


Payroll and related costs 1,532 1,325


Taxes payable (2) 1,367 1,204


Customer deposits 993 876


Operating lease liabilities, current portion 807 672


Sales return reserve, current portion 305 219


Other current liabilities 1,549 517


Total $ 10,723 $ 9,080


(1) Accrued purchases primarily reflects receipts of goods and services for which we had not yet been invoiced. As we are invoiced for these goods and
services, this balance will reduce and accounts payable will increase.


(2) Taxes payable primarily includes value added tax, income tax, sales tax, property tax and use tax payables.


72


---

**Note 9 – Other Long-Term Liabilities**


Our other long-term liabilities consisted of the following (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


Operating lease liabilities $ 4,603 $ 3,671


Accrued warranty reserve 4,799 3,606


Other non-current liabilities 1,093 876


Total other long-term liabilities $ 10,495 $ 8,153


**Note 10 – Debt**


The following is a summary of our debt and finance leases as of December 31, 2024 (in millions):


**Net Carrying Value** **Unpaid**


**Principal**


**Interest Rates**


**Contractual**


**Contractual**


**Current** **Long-Term** **Balance** **Amount (1)** **Interest Rates** **Maturity Date**


**Balance**


**Unused**


**Committed**


**Amount (1)**


**Recourse debt:**


RCF Credit Agreement - - - 5,000 Not applicable January 2028


Other 4 3 7 - 4.70-5.75% March 2025-January 2031


Total recourse debt 4 3 7 5,000


**Non-recourse debt:**


Automotive Asset-backed Notes 2,255 2,059 4,329 - 3.45-6.57% September 2025-June 2035


China Working Capital Facility - 2,740 2,740 - 1.92 % April 2025 (2)


Energy Asset-backed Notes 54 434 493 - 4.80-6.25% December 2025-June 2050


Cash Equity Debt 30 299 338 - 5.25-5.81% July 2033-January 2035


Total non-recourse debt 2,339 5,532 7,900

Total debt 2,343 5,535 $ 7,907 $ 5,000


Finance leases 113 222


Total debt and finance leases $ 2,456 $ 5,757


The following is a summary of our debt and finance leases as of December 31, 2023 (in millions):


**Net Carrying Value** **Unpaid**


**Principal**


**Interest Rates**


**Contractual**


**Contractual**


**Current** **Long-Term** **Balance** **Amount (1)** **Interest Rates** **Maturity Date**


**Balance**


**Unused**


**Committed**


**Amount (1)**


**Recourse debt:**


2024 Notes $ 37 $ - $ 37 $ - 2.00 % May 2024


RCF Credit Agreement - - - 5,000 Not applicable January 2028


Other - 7 7 28 4.70-5.75% March 2025-January 2031


Total recourse debt 37 7 44 5,028


**Non-recourse debt:**


Automotive Asset-backed Notes 1,906 2,337 4,259 - 0.60-6.57% July 2024-May 2031


Cash Equity Debt 28 330 367 - 5.25-5.81% July 2033-January 2035


Energy Asset-backed Notes 4 8 13 - 4.80 % December 2026


Total non-recourse debt 1,938 2,675 4,639

Total debt 1,975 2,682 $ 4,683 $ 5,028


Finance leases 398 175


Total debt and finance leases $ 2,373 $ 2,857


(1) There are no restrictions on draw-down or use for general corporate purposes with respect to any available committed funds under our RCF Credit
Agreement, except certain specified conditions prior to draw-down. Refer to the section below for the terms of the facility.


(2) The contractual maturity date of the China Working Capital Facility is April 2025, renewable until March 2026 at our discretion. As we have the
intent and ability to refinance the loan on a long-term basis, we recorded it in Debt and finance leases, net of current portion in the consolidated
balance sheets.


73


---

Recourse debt refers to debt that is recourse to our general assets. Non-recourse debt refers to debt that is recourse to only assets of our
subsidiaries. The differences between the unpaid principal balances and the net carrying values are due to debt discounts or deferred issuance costs. As
of December 31, 2024, we were in material compliance with all financial debt covenants.


**2024 Notes**


During the second quarter of 2024, the 2024 Notes reached maturity and were fully settled. Additionally, in 2024, we fully settled the warrants
entered into in connection with the issuance of the 2024 Notes, resulting in the issuance of 11.4 million shares of our common stock.


**Credit Agreement**


In January 2023, we entered into a 5-year senior unsecured revolving credit facility (the “RCF Credit Agreement”) with a syndicate of banks. The RCF
Credit Agreement contains two optional one-year extensions and has a total commitment of up to $5.00 billion, which could be increased up to $7.00
billion under certain circumstances. The underlying borrowings may be used for general corporate purposes. Borrowed funds accrue interest at a variable
rate equal to: (i) for dollar-denominated loans, at our election, (a) Term SOFR (the forward-looking secured overnight financing rate) plus 0.10%, or (b) an
alternate base rate; (ii) for loans denominated in pounds sterling, SONIA (the sterling overnight index average reference rate); or (iii) for loans
denominated in euros, an adjusted EURIBOR (euro interbank offered rate); in each case, plus an applicable margin. The applicable margin will be based on
the rating assigned to our senior, unsecured long-term indebtedness (the “Credit Rating”) from time to time. The fee for undrawn amounts is variable
based on the Credit Rating and is currently 0.125% per annum.


**Automotive Asset-backed Notes**


From time to time, we transfer receivables and/or beneficial interests related to certain vehicles (either leased or financed) into special purpose
entities (“SPEs”) and issue Automotive Asset-backed Notes, backed by these automotive assets to investors. The SPEs are consolidated in the financial
statements. The cash flows generated by these automotive assets are used to service the principal and interest payments on the Automotive Assetbacked Notes and satisfy the SPEs’ expenses, and any remaining cash is distributed to the owners of the SPEs. We recognize revenue earned from the
associated customer lease or financing contracts in accordance with our revenue recognition policy. The SPEs’ assets and cash flows are not available to
our other creditors, and the creditors of the SPEs, including the Automotive Asset-backed Note holders, have no recourse to our other assets.


In 2024, we transferred beneficial interests related to certain leased vehicles and/or financing receivables into SPEs and issued $2.45 billion in
aggregate principal amount of Automotive Asset-backed Notes, with terms similar to our other previously issued Automotive Asset-backed Notes. The
proceeds from the issuance, net of debt issuance costs, were $2.44 billion.


**Energy Asset-backed Notes**


In 2024, we transferred certain financing receivables into an SPE and issued $499 million in aggregate principal amount of Energy Asset-backed
Notes, backed by these financing receivables. The proceeds from issuance, net of debt issuance costs, were $494 million. The SPE is wholly owned by us
and is consolidated in the financial statements. The cash flows generated by these financing receivables are used to service the principal and interest
payments on the Energy Asset-backed Notes and satisfy the SPE’s expenses, and any remaining cash is distributed to us. The SPE’s assets and cash flows
are not available to our other creditors, and the creditors of the SPE, including the Energy Asset-backed Notes holders, have no recourse to our other
assets.


**Cash Equity Debt**


In connection with the cash equity financing deals closed in 2016, our subsidiaries issued $502 million in aggregate principal amount of debt that
bears interest at fixed rates. This debt is secured by, among other things, our interests in certain financing funds and is non-recourse to our other assets.


74


---

**China Working Capital Facility**


In April 2024, one of our subsidiaries entered into a loan agreement (the “China Working Capital Facility”) with lenders in China for an unsecured
revolving facility of up to RMB 20.00 billion to be used for certain production expenditures as well as repayment of certain finance facilities. Borrowed
funds bear interest at a rate equal to the Loan Prime Rate published by the People’s Bank of China minus 1.18%. The China Working Capital Facility is
non-recourse to our assets.


**Pledged Assets**


As of December 31, 2024 and 2023, we had pledged or restricted $5.16 billion and $4.64 billion of our assets (consisting principally of operating
lease vehicles, financing receivables, restricted cash, and equity interests in certain SPEs) as collateral for our outstanding debt.


**Schedule of Principal Maturities of Debt**


The future scheduled principal maturities of debt as of December 31, 2024 were as follows (in millions):


**Recourse debt** **Non-recourse debt** **Total**


2025 $ 4 $ 2,349 $ 2,353


2026 - 4,116 4,116


2027 - 699 699


2028 - 243 243


2029 - 95 95


Thereafter 3 398 401

Total $ 7 $ 7,900 $ 7,907


**Note 11 – Leases**


We have entered into various operating and finance lease agreements for certain of our offices, manufacturing and warehouse facilities, retail and
service locations, data centers, equipment, vehicles, and solar energy systems, worldwide. We determine if an arrangement is a lease, or contains a
lease, at inception and record the lease in our financial statements upon lease commencement, which is the date when the underlying asset is made
available for use by the lessor.


We have lease agreements with lease and non-lease components, and have elected to utilize the practical expedient to account for lease and nonlease components together as a single combined lease component, from both a lessee and lessor perspective with the exception of direct sales-type
leases and production equipment classes embedded in supply agreements. From a lessor perspective, the timing and pattern of transfer are the same for
the non-lease components and associated lease component and, the lease component, if accounted for separately, would be classified as an operating
lease.


We have elected not to present short-term leases on the consolidated balance sheet as these leases have a lease term of 12 months or less at lease
inception and do not contain purchase options or renewal terms that we are reasonably certain to exercise. All other lease assets and lease liabilities are
recognized based on the present value of lease payments over the lease term at commencement date. Because most of our leases do not provide an
implicit rate of return, we used our incremental borrowing rate based on the information available at lease commencement date in determining the
present value of lease payments.


Our leases, where we are the lessee, often include options to extend the lease term for up to 10 years. Some of our leases also include options to
terminate the lease prior to the end of the agreed upon lease term. For purposes of calculating lease liabilities, lease terms include options to extend or
terminate the lease when it is reasonably certain that we will exercise such options.


75


---

Lease expense for operating leases is recognized on a straight-line basis over the lease term as cost of revenues or operating expenses depending
on the nature of the leased asset. Certain operating leases provide for annual increases to lease payments based on an index or rate. We calculate the
present value of future lease payments based on the index or rate at the lease commencement date for new leases. Differences between the calculated
lease payment and actual payment are expensed as incurred. Amortization of finance lease assets is recognized over the lease term as cost of revenues
or operating expenses depending on the nature of the leased asset. Interest expense on finance lease liabilities is recognized over the lease term within
Interest expense in the consolidated statements of operations.


The balances for the operating and finance leases where we are the lessee are presented as follows (in millions) within our consolidated balance
sheets:


**December 31, 2024** **December 31, 2023**


**Operating leases:**


Operating lease right-of-use assets $ 5,160 $ 4,180


Accrued liabilities and other $ 807 $ 672


Other long-term liabilities 4,603 3,671

Total operating lease liabilities $ 5,410 $ 4,343


**Finance leases:**


Solar energy systems, net $ 21 $ 23


Property, plant and equipment, net 350 601

Total finance lease assets $ 371 $ 624


Current portion of long-term debt and finance leases $ 113 $ 398


Long-term debt and finance leases, net of current portion 222 175

Total finance lease liabilities $ 335 $ 573


The components of lease expense are as follows (in millions) within our consolidated statements of operations:


**Year Ended December 31,**


**2024** **2023** **2022**


**Operating lease expense:**


Operating lease expense (1) $ 1,500 $ 1,153 $ 798


**Finance lease expense:**


Amortization of leased assets $ 409 $ 506 $ 493


Interest on lease liabilities 21 45 72


Total finance lease expense $ 430 $ 551 $ 565


Total lease expense $ 1,930 $ 1,704 $ 1,363


(1) Includes short-term leases and variable lease costs, which are immaterial.


76


---

Other information related to leases where we are the lessee is as follows:


**Weighted-average remaining lease term:**


**December 31, 2024** **December 31, 2023**


Operating leases 7.9 years 7.4 years


Finance leases 4.4 years 2.3 years


**Weighted-average discount rate:**


Operating leases 5.3 % 5.6 %


Finance leases 4.7 % 5.5 %


Supplemental cash flow information related to leases where we are the lessee is as follows (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


**Cash paid for amounts included in the measurement of lease liabilities:**


Operating cash outflows from operating leases $ 1,450 $ 1,084 $ 754


Operating cash outflows from finance leases (interest payments) $ 21 $ 47 $ 75


Leased assets obtained in exchange for finance lease liabilities $ 144 $ 10 $ 58


Leased assets obtained in exchange for operating lease liabilities $ 1,808 $ 2,170 $ 1,059


As of December 31, 2024, the maturities of our operating and finance lease liabilities (excluding short-term leases) are as follows (in millions):


**Operating**

**Leases**


**Finance**

**Leases**


2025 $ 1,066 $ 122


2026 958 84


2027 843 69


2028 742 27


2029 642 22


Thereafter 2,428 45

Total minimum lease payments 6,679 369


Less: Interest 1,269 34

Present value of lease obligations 5,410 335


Less: Current portion 807 113

Long-term portion of lease obligations $ 4,603 $ 222


As of December 31, 2024, we have excluded from the table above additional operating leases that have not yet commenced with aggregate rent
payments of $1.10 billion. These operating leases will commence between fiscal year 2025 and 2026 with lease terms of 2 years to 20 years.


77


---

**Operating Lease and Sales-type Lease Receivables**


We are the lessor of certain vehicle and solar energy system arrangements as described in Note 2, Summary of Significant Accounting Policies. As of
December 31, 2024, maturities of our operating lease and sales-type lease receivables from customers for each of the next five years and thereafter were
as follows (in millions):


**Operating**

**Leases**


**Sales-type**

**Leases**


2025 $ 1,265 $ 177


2026 777 185


2027 454 93


2028 240 27


2029 200 2


Thereafter 1,290
Gross lease receivables $ 4,226 $ 484


The above table does not include vehicle sales to customers or leasing partners with a resale value guarantee as the cash payments were received
upfront. For our solar PPA arrangements, customers are charged solely based on actual power produced by the installed solar energy system at a
predefined rate per kilowatt-hour of power produced. The future payments from such arrangements are not included in the above table as they are a
function of the power generated by the related solar energy systems in the future.


**Net Investment in Sales-type Leases**


Net investment in sales-type leases, which is the sum of the present value of the future contractual lease payments, is presented on the
consolidated balance sheets as a component of Prepaid expenses and other current assets for the current portion and as Other non-current assets for the
long-term portion. Lease receivables relating to sales-type leases are presented on the consolidated balance sheets as follows (in millions):


**December 31, 2024** **December 31, 2023**


Gross lease receivables $ 484 $ 780


Unearned interest income (38) (78)


Allowance for expected credit losses (6) (6)

Net investment in sales-type leases $ 440 $ 696


**Reported as:**


Prepaid expenses and other current assets $ 152 $ 189


Other non-current assets 288 507

Net investment in sales-type leases $ 440 $ 696


**Note 12 – Equity Incentive Plans**


In June 2019, we adopted the 2019 Equity Incentive Plan (the “2019 Plan”). The 2019 Plan provides for the grant of stock options, restricted stock,
RSUs, stock appreciation rights, performance units and performance shares to our employees, directors and consultants. Stock options granted under the
2019 Plan may be either incentive stock options or nonstatutory stock options. Incentive stock options may only be granted to our employees.
Nonstatutory stock options may be granted to our employees, directors and consultants. Generally, our stock options and RSUs vest over four years and
our stock options are exercisable over a maximum period of 10 years from their grant dates. Vesting typically terminates when the employment or
consulting relationship ends.


As of December 31, 2024, 113.0 million shares were reserved and available for issuance under the 2019 Plan.


78


---

The following table summarizes our stock option and RSU activity for the year ended December 31, 2024:


**Stock Options** **RSUs**


**Weighted-**


**Weighted-**

**Average**

**Grant**

**Date Fair**

**Value**


**Average**

**Remaining**

**Contractual**

**Life (years)**


**Aggregate**

**Intrinsic**

**Value**

**(in billions)**


**Number**

**of RSUs**

**(in thousands)**


**Number of**

**Options**

**(in thousands)**


**Weighted-**

**Average**

**Exercise**

**Price**


Beginning of period 344,021 $ 35.11 19,088 $ 225.01


Granted 14,979 $ 235.22 12,045 $ 223.98


Exercised or released (10,469) $ 82.04 (7,515) $ 206.02


Cancelled (3,996) $ 205.61 (4,957) $ 221.15


End of period 344,535 $ 40.41 3.51 $ 125.22 18,661 $ 233.02


Vested and expected to vest, December 31, 2024 344,215 $ 40.23 3.50 $ 125.16 18,409 $ 232.99


Exercisable and vested, December 31, 2024 323,847 $ 27.75 3.14 $ 121.79


The weighted-average grant date fair value per share of RSUs granted in the years ended December 31, 2024, 2023 and 2022 was $223.98,
$228.33 and $239.85, respectively. The aggregate release date fair value of RSUs in the years ended December 31, 2024, 2023 and 2022 was $1.75
billion, $2.50 billion and $4.32 billion, respectively.


The aggregate intrinsic value of options exercised during the years ended December 31, 2024, 2023, and 2022 was $1.77 billion, $1.33 billion and
$1.90 billion, respectively.


**ESPP**


Our employees are eligible to purchase our common stock through payroll deductions of up to 15% of their eligible compensation, subject to any
plan limitations. The purchase price would be 85% of the lower of the fair market value on the first and last trading days of each six-month offering
period. During the years ended December 31, 2024, 2023 and 2022, under the ESPP we issued 2.2 million, 2.1 million and 1.4 million shares, respectively.
As of December 31, 2024, there were 95.5 million shares available for issuance under the ESPP.


**Fair Value Assumptions**


We use the fair value method in recognizing stock-based compensation expense. Under the fair value method, we estimate the fair value of each
stock option award with service or service and performance conditions and the ESPP on the grant date generally using the Black-Scholes option pricing
model. The weighted-average assumptions used in the Black-Scholes model for stock options are as follows:


**Year Ended December 31,**


**2024** **2023** **2022**


Risk-free interest rate 3.92 % 3.90 % 3.11 %


Expected term (in years) 4.3 4.5 4.1


Expected volatility 59 % 63 % 63 %


Dividend yield 0.0 % 0.0 % 0.0 %


Grant date fair value per share $ 114.29 $ 121.62 $ 114.51


The fair value of RSUs with service or service and performance conditions is measured on the grant date based on the closing fair market value of
our common stock. The risk-free interest rate is based on the U.S. Treasury yield for zero-coupon U.S. Treasury notes with maturities approximating each
grant’s expected life. We use our historical data in estimating the expected term of our employee grants. The expected volatility is based on the average
of the implied volatility of publicly traded options for our common stock and the historical volatility of our common stock.


79


---

**Other Performance-Based Grants**


From time to time, the Compensation Committee of our Board of Directors grants certain employees performance-based RSUs and stock options.


As of December 31, 2024, we had unrecognized stock-based compensation expense of $490 million under these grants to purchase or receive an
aggregate 5.0 million shares of our common stock. For awards probable of achievement, we estimate the unrecognized stock-based compensation
expense of $421 million will be recognized over a weighted-average period of 4.0 years.


For the years ended December 31, 2024, 2023 and 2022, stock-based compensation expense related to these grants, net of forfeitures, were not
material.


**Summary Stock-Based Compensation Information**


The following table summarizes our stock-based compensation expense by line item in the consolidated statements of operations (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Cost of revenues $ 776 $ 741 $ 594


Research and development 832 689 536


Selling, general and administrative 389 382 430


Restructuring and other $ 2 $ - $
Total $ 1,999 $ 1,812 $ 1,560


Our income tax benefits recognized from stock-based compensation arrangements were immaterial while we were under full valuation allowances
on our U.S. deferred tax assets during the year ended December 31, 2022. With the release of the valuation allowance associated with our federal and
certain state deferred tax assets in 2023, income tax benefits recognized from stock-based compensation expense during the years ended December 31,
2024 and 2023 were $371 million and $326 million, respectively. During the years ended December 31, 2024, 2023 and 2022, stock-based compensation
expense capitalized to our consolidated balance sheets was $198 million, $199 million and $245 million, respectively. As of December 31, 2024, we had
$5.79 billion of total unrecognized stock-based compensation expense related to non-performance awards, which will be recognized over a weightedaverage period of 3.0 years.


**Note 13 – Income Taxes**


Our income before provision for (benefit from) income taxes for the years ended December 31, 2024, 2023 and 2022 was as follows (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Domestic $ 2,292 $ 3,196 $ 5,524


Noncontrolling interest and redeemable noncontrolling interest 62 (23) 31


Foreign 6,636 6,800 8,164

Income before income taxes $ 8,990 $ 9,973 $ 13,719


80


---

A provision for (benefit from) income taxes of $1.84 billion, $(5.00) billion and $1.13 billion has been recognized for the years ended December 31,
2024, 2023 and 2022, respectively. The components of the provision for (benefit from) income taxes for the years ended December 31, 2024, 2023 and
2022 consisted of the following (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Current:


Federal $ - $ 48 $

State 45 57 62


Foreign 1,315 1,243 1,266

Total current 1,360 1,348 1,328


Deferred:


Federal 831 (5,246) 26


State (49) (653) 1


Foreign (305) (450) (223)

Total deferred 477 (6,349) (196)

Total provision for (benefit from) income taxes $ 1,837 $ (5,001) $ 1,132


81


---

The reconciliation of taxes at the federal statutory rate to our provision for (benefit from) income taxes for the years ended December 31, 2024,
2023 and 2022 was as follows (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Tax at statutory federal rate $ 1,887 $ 2,094 $ 2,881


State tax, net of federal benefit 8 (372) 51


Excess tax benefits related to stock-based compensation (267) (288) (745)


Nontaxable manufacturing credit (291) (101)

Foreign income rate differential (545) (816) (923)


U.S. tax credits (317) (593) (276)


GILTI and Subpart F inclusion 882 670 1,279


Unrecognized tax benefits 144 183 252


Change in valuation allowance 163 (5,962) (1,532)


Other 173 184 145


Provision for (benefit from) income taxes $ 1,837 $ (5,001) $ 1,132


Deferred tax assets (liabilities) as of December 31, 2024 and 2023 consisted of the following (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


**Deferred tax assets:**


Net operating loss carry-forwards $ 1,295 $ 2,826


Research and development credits 1,735 1,358


Other tax credits and attributes 1,325 827


Deferred revenue 1,101 1,035


Inventory and warranty reserves 1,769 1,258


Operating lease right-of-use liabilities 1,186 930


Capitalized research and development costs 2,448 1,344


Deferred GILTI tax assets 691 760


Other 412 436

Total deferred tax assets 11,962 10,774


Valuation allowance (1,224) (892)

Deferred tax assets, net of valuation allowance 10,738 9,882


**Deferred tax liabilities:**


Depreciation and amortization (2,658) (2,122)


Operating lease right-of-use assets (1,097) (859)


Other (561) (249)

Total deferred tax liabilities (4,316) (3,230)

Deferred tax assets (liabilities), net of valuation allowance $ 6,422 $ 6,652


82


---

As of December 31, 2024, we maintained valuation allowances of $1.22 billion for deferred tax assets that are not more likely than not to be
realized, which primarily included our California deferred tax assets, U.S. foreign tax credits and certain foreign operating losses. The valuation allowance
on our net deferred tax assets increased by $332 million during the year ended December 31, 2024, and decreased by $6.46 billion and $1.73 billion
during the years ended December 31, 2023 and 2022, respectively. The valuation allowance increase during the year ended December 31, 2024 was
primarily due to the changes of our California deferred tax assets, U.S. foreign tax credits and certain foreign operating losses. The change in valuation
allowance during the year ended December 31, 2023 was primarily due to the release of our valuation allowance with respect to our U.S. federal and
certain state deferred tax assets. In the fourth quarter of 2023, based on the relevant weight of positive and negative evidence, including the amount of
our taxable income in recent years which was objective and verifiable, and consideration of our expected future taxable earnings, we concluded that it is
more likely than not that most of our U.S. federal and certain state deferred tax assets are realizable and released the valuation allowance on these
deferred tax assets. The valuation allowance change during the years ended December 31, 2022 was primarily due to changes in our U.S. deferred tax
assets and liabilities. Our deferred tax assets without a valuation allowance are more likely than not to be realized given the expectation of future
earnings in the respective jurisdictions.


As of December 31, 2024, we had $4.34 billion of federal and $8.59 billion of state net operating loss carry-forwards available to offset future
taxable income, an immaterial amount of which, if not utilized, will begin to expire in 2026 for federal and 2025 for state purposes. Federal and state laws
can impose substantial restrictions on the utilization of net operating loss and tax credit carry-forwards in the event of an “ownership change,” as defined
in Section 382 of the Internal Revenue Code. We have determined that no significant limitation would be placed on the utilization of our net operating loss
and tax credit carry-forwards due to prior ownership changes or expirations.


As of December 31, 2024, we had federal research and development tax credits of $1.48 billion, federal renewable energy tax credits of $1.01
billion, and state research and development tax credits of $1.06 billion. Most of our state research and development tax credits were in the state of
California. If not utilized, some of the federal tax credits may expire in various amounts beginning in 2035. However, California research and development
tax credits can be carried forward indefinitely.


As of December 31, 2024, we intend to indefinitely reinvest our foreign earnings and cash unless such repatriation results in no or minimal tax costs.
We have recorded the taxes associated with the foreign earnings we intend to repatriate in the future. For the earnings we intend to indefinitely reinvest,
no deferred tax liabilities for foreign withholding or other taxes have been recorded. The estimated amount of such unrecognized withholding tax liability
associated with the indefinitely reinvested earnings is approximately $309 million.


**Uncertain Tax Positions**


The changes to our gross unrecognized tax benefits were as follows (in millions):


December 31, 2021 $ 531


Increases in balances related to prior year tax positions 136


Decreases in balances related to prior year tax positions (12)


Increases in balances related to current year tax positions 222


Decreases in balances related to expiration of the statute of limitations (7)

December 31, 2022 870


Increases in balances related to prior year tax positions 59


Decreases in balances related to settlement with tax authorities (6)


Increases in balances related to current year tax positions 255


Decreases in balances related to expiration of the statute of limitations (4)

December 31, 2023 1,174


Increases in balances related to prior year tax positions 51


Decreases in balances related to prior year tax positions (27)


Increases in balances related to current year tax positions 227


Decreases in balances related to settlement with tax authorities (4)


Decreases in balances related to expiration of the statute of limitations (4)

December 31, 2024 $ 1,417


83


---

We include interest and penalties related to unrecognized tax benefits in income tax expense. We recognized net interest and penalties related to
unrecognized tax benefits in provision for (benefit from) income taxes line of our consolidated statements of operations of $23 million, $17 million and
$27 million for the years ended December 31, 2024, 2023 and 2022, respectively. As of December 31, 2024, and 2023, we have accrued $69 million and
$47 million, respectively, related to interest and penalties on our unrecognized tax benefits. Unrecognized tax benefits of $1.14 billion, if recognized,
would affect our effective tax rate.


We file income tax returns in the U.S. and various state and foreign jurisdictions. We are currently under examination by the Internal Revenue
Service (“IRS”) for the years 2015 to 2018. Additional tax years within the periods 2004 to 2014 and 2019 to 2023 remain subject to examination for
federal income tax purposes. All net operating losses and tax credits generated to date are subject to adjustment for U.S. federal and state income tax
purposes. Our returns for 2004 and subsequent tax years remain subject to examination in U.S. state and foreign jurisdictions.


Given the uncertainty in timing and outcome of our tax examinations, an estimate of the range of the reasonably possible change in gross
unrecognized tax benefits within twelve months cannot be made at this time.


**Note 14 – Commitments and Contingencies**


**Operating Lease Arrangement in Buffalo, New York**


We have an operating lease arrangement through the Research Foundation for the SUNY Foundation with respect to Gigafactory New York. Under
the lease and a related research and development agreement, we are continuing to further develop the facility.


Under this agreement, we are obligated to, among other things, meet employment targets as well as specified minimum numbers of personnel in
the State of New York and in Buffalo, New York and spend or incur $5.00 billion in combined capital, operational expenses, costs of goods sold and other
costs in the State of New York during the 10-year period beginning April 30, 2018. On an annual basis during the initial lease term, as measured on each
anniversary of such date, if we fail to meet these specified investment and job creation requirements, it may result in our incurring financial liabilities in
the form of “program payments” which would not be expected to have a material adverse effect to our financial operations, the termination of our lease
at Gigafactory New York, and/or the need to adjust certain of our operations.


In 2021, an amendment was executed to extend our overall agreement to spend or incur $5.00 billion in combined capital, operational expenses,
costs of goods sold and other costs in the State of New York through December 31, 2029. As of December 31, 2024, we have met and expect to meet the
requirements under this arrangement, as may be modified and discussed from time to time, based on our current and anticipated level of operations.


**Operating Lease Arrangement in Shanghai, China**


We have an operating lease arrangement for an initial term of 50 years with the local government of Shanghai for land use rights where we have
been constructing Gigafactory Shanghai. Under the terms of the arrangement, we are required to spend RMB 14.08 billion in capital expenditures by the
end of 2023, which was achieved in 2023, and to generate RMB 2.23 billion of annual tax revenues starting at the end of 2023. As of December 31, 2024
and 2023, we had met and expect to meet the tax revenue requirements based on our current level of spend and sales.


84


---

**Legal Proceedings**


Litigation Relating to 2018 CEO Performance Award


On June 4, 2018, a purported Tesla stockholder filed a putative class and derivative action in the Delaware Court of Chancery against Elon Musk and
the members of Tesla’s board of directors as then constituted, alleging corporate waste, unjust enrichment and that such board members breached their
fiduciary duties by approving the stock-based compensation plan awarded to Elon Musk in 2018 (the “2018 CEO Performance Award”). Trial was held
November 14-18, 2022. On January 30, 2024, the Court issued an opinion finding that the 2018 CEO Performance Award should be rescinded. Plaintiff’s
counsel filed a brief seeking a fee award of 29,402,900 Tesla shares, plus expenses of $1,120,115.50. Tesla opposed the fee request, and at Tesla’s 2024
Annual Meeting of Stockholders, 72% of the disinterested voting shares of Tesla, excluding shares owned by Mr. Musk and Kimbal Musk, voted to ratify
the 2018 CEO Performance Award. Because Tesla’s disinterested stockholders voted to ratify the 2018 CEO Performance Award, Mr. Musk and the other
director defendants, joined by Tesla, filed a brief seeking to revise the Court’s January 30, 2024 opinion. On December 2, 2024, the Court issued an
opinion denying the motion to revise the Court’s January 30, 2024 opinion and awarded Plaintiff’s counsel fees in the amount of $345 million. A final
judgment was entered by the Court, and the director defendants and Tesla appealed the decisions to the Delaware Supreme Court.


Litigation Related to Directors’ Compensation


On June 17, 2020, a purported Tesla stockholder filed a derivative action in the Delaware Court of Chancery, purportedly on behalf of Tesla, against
certain of Tesla’s current and former directors regarding compensation awards granted to Tesla’s directors, other than Elon Musk, between 2017 and
2020. The suit asserts claims for breach of fiduciary duty and unjust enrichment and seeks declaratory and injunctive relief, unspecified damages and
other relief. Defendants filed their answer on September 17, 2020.


On July 14, 2023, the parties filed a Stipulation and Agreement of Compromise and Settlement, which does not involve an admission of any
wrongdoing by any party. Pursuant to the terms of the agreement, Tesla provided notice of the proposed settlement to stockholders of record as of July
14, 2023. The Court held a hearing regarding the settlement on October 13, 2023, after which it took the settlement and plaintiff counsels’ fee request
under advisement. On January 8, 2025, the Court approved the settlement and awarded Plaintiff’s counsel fees in the amount of approximately
$176 million. A final judgment was entered by the Court on January 13, 2025. Tesla intends to appeal the Court’s fee award on or before the appeal
deadline of February 12, 2025. The settlement is not expected to have an adverse impact on our results of operations, cash flows or financial position.


Litigation Relating to Potential Going Private Transaction


Between August 10, 2018 and September 6, 2018, nine purported stockholder class actions were filed against Tesla and Elon Musk in connection
with Mr. Musk’s August 7, 2018 Twitter post that he was considering taking Tesla private. On January 16, 2019, Plaintiffs filed their consolidated complaint
in the United States District Court for the Northern District of California and added as defendants the members of Tesla’s board of directors. The
consolidated complaint asserts claims for violations of the federal securities laws and seeks unspecified damages and other relief. The parties stipulated
to certification of a class of stockholders, which the court granted on November 25, 2020. Trial started on January 17, 2023, and on February 3, 2023, a
jury rendered a verdict in favor of the defendants on all counts. After trial, plaintiffs filed a motion for judgment as a matter of law and a motion for new
trial, which the Court denied and judgement was entered in favor of defendants on July 11, 2023. On November 6, 2024, the United States Court of
Appeals for the Ninth Circuit affirmed the district court’s dismissal of all claims.


Between October 17, 2018 and March 8, 2021, seven derivative lawsuits were filed in the Delaware Court of Chancery, purportedly on behalf of
Tesla, against Mr. Musk and the members of Tesla’s board of directors, as constituted at relevant times, in relation to statements made and actions
connected to a potential going private transaction, with certain of the lawsuits challenging additional Twitter posts by Mr. Musk, among other things.
Several of those actions were consolidated, and all have been stayed. In addition to these cases, two derivative lawsuits were filed on October 25, 2018
and February 11, 2019 in the U.S. District Court for the District of Delaware, purportedly on behalf of Tesla, against Mr. Musk and the members of the
Tesla board of directors as then constituted. Those cases have also been consolidated and stayed.


85


---

On October 21, 2022, a lawsuit was filed in the Delaware Court of Chancery by a purported shareholder of Tesla alleging, among other things, that
board members breached their fiduciary duties in connection with their oversight of the Company’s 2018 settlement with the SEC, as amended. Among
other things, the plaintiff seeks reforms to the Company’s corporate governance and internal procedures, unspecified damages, and attorneys’ fees. The
lawsuit has been stayed pending resolution of a motion to consolidate certain derivative lawsuits in the Delaware Court of Chancery referenced below.

On November 15, 2021, JPMorgan Chase Bank filed a lawsuit against Tesla in the Southern District of New York alleging breach of a stock warrant
agreement that was entered into as part of a convertible notes offering in 2014. Tesla denied any wrongdoing and filed multiple counterclaims. On
November 27, 2024, the parties agreed to settle their claims.


Certain Derivative Lawsuits in Delaware


Before converting from a Delaware to Texas corporation on June 13, 2024, three separate derivative actions brought by purported Tesla
stockholders were filed in the Delaware Court of Chancery on May 24, June 10 and June 13, 2024, purportedly on behalf of Tesla, against current and
former directors regarding topics involving Elon Musk and others, X Corp. (formerly Twitter) and x.AI. These suits assert various claims, including breach
of fiduciary duty and breach of contract, and seek unspecified damages and other relief. On August 6, 2024, the plaintiffs in these three actions moved to
consolidate the matters into a single case. The Court consolidated two of the three cases.


Litigation and Investigations Relating to Alleged Discrimination and Harassment


On February 9, 2022, the California Civil Rights Department (“CRD,” formerly “DFEH”) filed a civil complaint against Tesla in Alameda County,
California Superior Court, alleging systemic race discrimination, hostile work environment and pay equity claims, among others. CRD’s amended
complaint seeks monetary damages and injunctive relief. The case is currently in discovery. Trial is scheduled for September 15, 2025.


Additionally, on June 1, 2022 the Equal Employment Opportunity Commission (“EEOC”) issued a cause finding against Tesla that closely parallels the
CRD’s allegations. On September 28, 2023, the EEOC filed a civil complaint against Tesla in the United States District Court for the Northern District of
California asserting claims for race harassment and retaliation and seeking, among other things, monetary and injunctive relief.


On June 16, 2022, two Tesla stockholders filed separate derivative actions in the U.S. District Court for the Western District of Texas, purportedly on
behalf of Tesla, against certain of Tesla’s current and former directors. Both suits assert claims for breach of fiduciary duty, unjust enrichment, and
violation of the federal securities laws in connection with alleged race and gender discrimination and sexual harassment. Among other things, plaintiffs
seek declaratory and injunctive relief, unspecified damages payable to Tesla, and attorneys’ fees. On July 22, 2022, the Court consolidated the two cases
and on September 6, 2022, plaintiffs filed a consolidated complaint. On November 7, 2022, the defendants filed a motion to dismiss the case and on
September 15, 2023, the Court dismissed the action but granted plaintiffs leave to file an amended complaint. On November 2, 2023, plaintiff filed an
amended complaint purportedly on behalf of Tesla, against Elon Musk. On December 19, 2023, the defendants moved to dismiss the amended complaint,
which the Court granted on April 12, 2024, with leave for plaintiffs to amend. On May 15, 2024, plaintiffs filed a second amended consolidated complaint
purportedly on behalf of Tesla, against Mr. Musk. On July 1, 2024, the defendants moved to dismiss the second amended consolidated complaint.


86


---

Other Litigation Related to Our Products and Services


We are also subject to various lawsuits that seek monetary and other injunctive relief. These lawsuits include proposed class actions and other
consumer claims that allege, among other things, purported defects and misrepresentations related to our products and services. For example, on
September 14, 2022, a proposed class action was filed against Tesla, Inc. and related entities in the U.S. District Court for the Northern District of
California, alleging various claims about the Company’s driver assistance technology systems under state and federal law. This case was later
consolidated with several other proposed class actions, and a Consolidated Amended Complaint was filed on October 28, 2022, which seeks damages and
other relief on behalf of all persons who purchased or leased from Tesla between January 1, 2016, to the present. On October 5, 2022, a proposed class
action complaint was filed in the U.S. District Court for the Eastern District of New York asserting similar state and federal law claims against the same
defendants. On September 30, 2023, the Court dismissed this action with leave to amend the complaint. On November 20, 2023, the plaintiff moved to
amend the complaint, which Tesla opposed. On August 8, 2024, the Court denied the plaintiff’s motion for leave to file an amended complaint and entered
judgment for Tesla. On September 5, 2024, the plaintiff filed a notice of appeal to United States Court of Appeals for the Second Circuit, and the parties
are briefing the matter. On March 22, 2023, the plaintiffs in the Northern District of California consolidated action filed a motion for a preliminary
injunction to order Tesla to (1) cease using the term “Full Self-Driving Capability” (FSD Capability), (2) cease the sale and activation of FSD Capability and
deactivate FSD Capability on Tesla vehicles, and (3) provide certain notices to consumers about proposed court-findings about the accuracy of the use of
the terms Autopilot and FSD Capability. Tesla opposed the motion. On September 30, 2023, the Court denied the request for a preliminary injunction,
compelled four of five plaintiffs to arbitration, and dismissed the claims of the fifth plaintiff with leave to amend the complaint. On October 31, 2023, the
remaining plaintiff in the Northern District of California action filed an amended complaint, which Tesla moved to dismiss, and on May 15, 2024, the Court
granted in part and denied in part Tesla’s motion. On October 2, 2023, a similar proposed class action was filed in San Diego County Superior Court in
California. Tesla subsequently removed the San Diego County case to federal court and on January 8, 2024, the federal court granted Tesla’s motion to
transfer the case to the U.S. District Court for the Northern District of California. Tesla moved to compel arbitration, which the plaintiff did not oppose, and
on June 27, 2024, the Court stayed the case pending arbitration.


On February 27, 2023, a proposed class action was filed in the U.S. District Court for the Northern District of California against Tesla, Inc., Elon Musk
and certain current and former Company executives. The complaint alleges that the defendants made material misrepresentations and omissions about
the Company’s Autopilot and FSD Capability technologies and seeks money damages and other relief on behalf of persons who purchased Tesla stock
between February 19, 2019, and February 17, 2023. An amended complaint was filed on September 5, 2023, naming only Tesla, Inc. and Elon Musk as
defendants. On November 6, 2023, Tesla moved to dismiss the amended complaint. On September 30, 2024, the Court granted Tesla’s motion to dismiss
without prejudice. On November 26, 2024, the court issued a final judgment in Tesla’s favor, and on December 23, 2024, the plaintiffs filed a notice of
appeal to the United States Court of Appeals for the Ninth Circuit.


On March 14, 2023, a proposed class action was filed against Tesla, Inc. in the U.S. District Court for the Northern District of California. Several
similar complaints were also filed in the same court and these cases have now all been consolidated. These complaints allege that Tesla violates federal
antitrust and warranty laws through its repair, service, and maintenance practices and seeks, among other relief, damages for persons who paid Tesla for
repairs services or Tesla compatible replacement parts from March 2019 to March 2023. On July 17, 2023, these plaintiffs filed a consolidated amended
complaint. On September 27, 2023, the court granted Tesla’s motion to compel arbitration as to three of the plaintiffs, and on November 17, 2023, the
court granted Tesla’s motion to dismiss without prejudice. The plaintiffs filed a Consolidated Second Amended Complaint on December 12, 2023, which
Tesla moved to dismiss. Plaintiffs also appealed the court’s arbitration order, which was denied. On June 17, 2024, the Court granted in part and denied in
part Tesla’s motion to dismiss the Consolidated Second Amended Complaint.


The Company intends to vigorously defend itself in these matters; however, we cannot predict the outcome or impact. We are unable to reasonably
estimate the possible loss or range of loss, if any, associated with these claims, unless noted.


87


---

Certain Investigations and Other Matters


We regularly receive requests for information, including subpoenas, from regulators and governmental authorities such as the National Highway
Traffic Safety Administration, the National Transportation Safety Board, the Securities and Exchange Commission (“SEC”), the Department of Justice
(“DOJ”), and various local, state, federal, and international agencies. The ongoing requests for information include topics such as operations, technology
(e.g., vehicle functionality, vehicle incidents, Autopilot and FSD Capability), compliance, finance, data privacy, and other matters related to Tesla’s
business, its personnel, and related parties. We routinely cooperate with such formal and informal requests for information, investigations, and other
inquiries. To our knowledge no government agency in any ongoing investigation has concluded that any wrongdoing occurred. We cannot predict the
outcome or impact of any ongoing matters. Should the government decide to pursue an enforcement action, there exists the possibility of a material
adverse impact on our business, results of operation, prospects, cash flows, financial position or brand.


We are also subject to various other legal proceedings, risks and claims that arise from the normal course of business activities. For example, during
the second quarter of 2023, a foreign news outlet reported that it obtained certain misappropriated data including, purportedly non-public Tesla business
and personal information. Tesla has made notifications to potentially affected individuals (current and former employees) and regulatory authorities and
we are working with certain law enforcement and other authorities. On August 5, 2023, a putative class action was filed in the United States District Court
for the Northern District of California, purportedly on behalf of all U.S. individuals impacted by the data incident, followed by several additional lawsuits,
that each assert claims under various state laws and seeks monetary damages and other relief. If an unfavorable ruling or development were to occur in
these or other possible legal proceedings, risks and claims, there exists the possibility of a material adverse impact on our business, results of operations,
prospects, cash flows, financial position or brand.


**Letters of Credit**


As of December 31, 2024, we had $448 million of unused letters of credit outstanding.


**Note 15 – Variable Interest Entity Arrangements**


We have entered into various arrangements with investors to facilitate the funding and monetization of our solar energy systems and vehicles. In
particular, our wholly owned subsidiaries and fund investors have formed and contributed cash and assets into various financing funds and entered into
related agreements. We have determined that the funds are VIEs and we are the primary beneficiary of these VIEs by reference to the power and benefits
criterion under ASC 810. We have considered the provisions within the agreements, which grant us the power to manage and make decisions that affect
the operation of these VIEs, including determining the solar energy systems and the associated customer contracts to be sold or contributed to these
VIEs, redeploying solar energy systems and managing customer receivables. We consider that the rights granted to the fund investors under the
agreements are more protective in nature rather than participating.


As the primary beneficiary of these VIEs, we consolidate in the financial statements the financial position, results of operations and cash flows of
these VIEs, and all intercompany balances and transactions between us and these VIEs are eliminated in the consolidated financial statements. Cash
distributions of income and other receipts by a fund, net of agreed upon expenses, estimated expenses, tax benefits and detriments of income and loss
and tax credits, are allocated to the fund investor and our subsidiary as specified in the agreements.


Generally, our subsidiary has the option to acquire the fund investor’s interest in the fund for an amount based on the market value of the fund or
the formula specified in the agreements.


Upon the sale or liquidation of a fund, distributions would occur in the order and priority specified in the agreements.


Pursuant to management services, maintenance and warranty arrangements, we have been contracted to provide services to the funds, such as
operations and maintenance support, accounting, lease servicing and performance reporting. In some instances, we have guaranteed payments to the
fund investors as specified in the agreements. A fund’s creditors have no recourse to our general credit or to that of other funds. Certain assets of the
funds have been pledged as collateral for their obligations.


88


---

The aggregate carrying values of the VIEs’ assets and liabilities, after elimination of any intercompany transactions and balances, in the
consolidated balance sheets were as follows (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


**Assets**


Current assets


Cash and cash equivalents $ 49 $ 66


Accounts receivable, net 18 13


Prepaid expenses and other current assets 276 361


Total current assets 343 440


Operating lease vehicles, net 392

Solar energy systems, net 2,310 3,278


Other non-current assets 183 369


Total assets $ 3,228 $ 4,087


**Liabilities**


Current liabilities


Accrued liabilities and other $ 32 $ 67


Deferred revenue 6 6


Current portion of debt and finance leases 2,114 1,564


Total current liabilities 2,152 1,637


Deferred revenue, net of current portion 71 99


Debt and finance leases, net of current portion 1,834 2,041


Total liabilities $ 4,057 $ 3,777


**Note 16 – Related Party Transactions**


Tesla periodically does business with certain entities with which its CEO and directors are affiliated, such as x.AI, SpaceX, The Boring Company, X
Corp. and Redwood Materials, in accordance with our Related Person Transactions Policy. Such transactions have not had to date, and are not currently
expected to have, a material impact on our consolidated financial statements.


89


---

**Note 17 – Segment Reporting and Information about Geographic Areas**


Our Chief Executive Officer, as the CODM, organizes our company, manages resource allocations and measures performance among two operating
and reportable segments: (i) automotive and (ii) energy generation and storage. The automotive segment includes the design, development,
manufacturing, sales and leasing of electric vehicles as well as sales of automotive regulatory credits. Additionally, the automotive segment is also
comprised of services and other, which includes sales of used vehicles, non-warranty maintenance services and collision, part sales, paid Supercharging,
insurance services revenue and retail merchandise sales. The energy generation and storage segment includes the design, manufacture, installation,
sales and leasing of solar energy generation and energy storage products and related services and sales of solar energy systems incentives.


Our CODM does not evaluate operating segments using asset or liability information. The CODM uses gross profit to allocate operating and capital
resources and assesses performance of each segment by comparing actual gross profit results to historical results and previously forecasted financial
information. The following table presents revenues, cost of revenues and gross profit by reportable segment (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


Automotive segment


Revenues $ 87,604 $ 90,738 $ 77,553


Cost of revenues (1) $ 72,794 $ 74,219 $ 56,988


Gross profit $ 14,810 $ 16,519 $ 20,565


Energy generation and storage segment


Revenues $ 10,086 $ 6,035 $ 3,909


Cost of revenues (2) $ 7,446 $ 4,894 $ 3,621


Gross profit $ 2,640 $ 1,141 $ 288


(1) Depreciation and amortization included in Cost of revenues for the automotive segment for the years ended December 31, 2024, 2023 and 2022
was $3.68 billion, $3.45 billion and $2.81 billion, respectively.


(2) Depreciation and amortization included in Cost of revenues for the energy generation and storage segment for the years ended December 31,
2024, 2023 and 2022 was $377 million, $343 million and $331 million, respectively.


The following table presents revenues by geographic area based on the sales location of our products (in millions):


**Year Ended December 31,**


**2024** **2023** **2022**


United States $ 47,725 $ 45,235 $ 40,553


China 20,944 21,745 18,145


Other international 29,021 29,793 22,764


Total $ 97,690 $ 96,773 $ 81,462


The following table presents long-lived assets by geographic area (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


United States $ 32,461 $ 26,629


Germany 4,175 4,258


Other international 4,124 4,067


Total $ 40,760 $ 34,954


90


---

The following table presents inventory by reportable segment (in millions):


**December 31,**

**2024**


**December 31,**

**2023**


Automotive $ 9,988 $ 11,139


Energy generation and storage 2,029 2,487


Total $ 12,017 $ 13,626


**Note 18 – Restructuring and Other**


In the second quarter of 2024, we initiated and substantially completed certain restructuring actions to reduce costs and improve efficiency. As a
result, we recognized $583 million of employee termination expenses in Restructuring and other in our consolidated income statement. These expenses
were substantially paid with an immaterial accrual remaining in Accrued liabilities and other in our consolidated balance sheet as of December 31, 2024.


During the year ended December 31, 2022, we recorded an impairment loss of $204 million as well as realized gains of $64 million in connection
with converting our holdings of digital assets into fiat currency. We also recorded other expenses of $36 million during the second quarter of the year
ended December 31, 2022, related to employee terminations.


**ITEM 9. CHANGES IN AND DISAGREEMENTS WITH ACCOUNTANTS ON ACCOUNTING AND FINANCIAL DISCLOSURE**


None.


**ITEM 9A. CONTROLS AND PROCEDURES**


Evaluation of Disclosure Controls and Procedures


Our management, with the participation of our Chief Executive Officer and our Chief Financial Officer, evaluated the effectiveness of our disclosure
controls and procedures pursuant to Rule 13a-15 under the Securities Exchange Act of 1934, as amended (the “Exchange Act”). In designing and
evaluating the disclosure controls and procedures, our management recognizes that any controls and procedures, no matter how well designed and
operated, can provide only reasonable assurance of achieving the desired control objectives. In addition, the design of disclosure controls and procedures
must reflect the fact that there are resource constraints and that our management is required to apply its judgment in evaluating the benefits of possible
controls and procedures relative to their costs.


Based on this evaluation, our Chief Executive Officer and our Chief Financial Officer concluded that, as of December 31, 2024, our disclosure
controls and procedures were designed at a reasonable assurance level and were effective to provide reasonable assurance that the information we are
required to disclose in reports that we file or submit under the Exchange Act is recorded, processed, summarized and reported within the time periods
specified in the SEC rules and forms, and that such information is accumulated and communicated to our management, including our Chief Executive
Officer and our Chief Financial Officer, as appropriate, to allow timely decisions regarding required disclosures.


Management’s Report on Internal Control over Financial Reporting


Our management is responsible for establishing and maintaining adequate internal control over financial reporting. Internal control over financial
reporting is a process designed by, or under the supervision of, our Chief Executive Officer and Chief Financial Officer to provide reasonable assurance
regarding the reliability of financial reporting and the preparation of financial statements for external purposes in accordance with generally accepted
accounting principles and includes those policies and procedures that (1) pertain to the maintenance of records that in reasonable detail accurately and
fairly reflect the transactions and dispositions of our assets; (2) provide reasonable assurance that transactions are recorded as necessary to permit
preparation of financial statements in accordance with generally accepted accounting principles, and that our receipts and expenditures are being made
only in accordance with authorizations of our management and directors and (3) provide reasonable assurance regarding prevention or timely detection
of unauthorized acquisition, use or disposition of our assets that could have a material effect on the financial statements.


91


---

Under the supervision and with the participation of our management, including our Chief Executive Officer and Chief Financial Officer, we conducted
an evaluation of the effectiveness of our internal control over financial reporting based on criteria established in Internal Control – Integrated Framework
(2013) issued by the Committee of Sponsoring Organizations of the Treadway Commission (“COSO”). Our management concluded that our internal
control over financial reporting was effective as of December 31, 2024.


Our independent registered public accounting firm, PricewaterhouseCoopers LLP, has audited the effectiveness of our internal control over financial
reporting as of December 31, 2024, as stated in their report which is included herein.


Limitations on the Effectiveness of Controls


Because of inherent limitations, internal control over financial reporting may not prevent or detect misstatements and projections of any evaluation
of effectiveness to future periods are subject to the risk that controls may become inadequate because of changes in conditions, or that the degree of
compliance with the policies or procedures may deteriorate.


Changes in Internal Control over Financial Reporting


There was no change in our internal control over financial reporting that occurred during the quarter ended December 31, 2024, which has
materially affected, or is reasonably likely to materially affect, our internal control over financial reporting.


**ITEM 9B. OTHER INFORMATION**


None of the Company’s directors or officers adopted, modified or terminated a Rule 10b5-1 trading arrangement or a non-Rule 10b5-1 trading
arrangement during the Company’s fiscal quarter ended December 31, 2024, as such terms are defined under Item 408(a) of Regulation S-K, except as
follows:


On December 6, 2024, Ira Ehrenpreis, one of our directors, adopted a Rule 10b5-1 trading arrangement for the potential exercise of options to
purchase 761,961 shares of our common stock, and the subsequent sale of our common stock subject to certain conditions, in amounts sufficient to cover
tax withholding obligations and yield aggregate net proceeds to Mr. Ehrenpreis of $15 million, after payment of commissions and fees. The arrangement's
expiration date is June 3, 2025.


**ITEM 9C. DISCLOSURE REGARDING FOREIGN JURISDICTIONS THAT PREVENT INSPECTIONS**


Not applicable.


92


---

**PART III**


**ITEM 10. DIRECTORS, EXECUTIVE OFFICERS AND CORPORATE GOVERNANCE**


The information required by this Item 10 of Form 10-K will be included in our 2025 Proxy Statement to be filed with the Securities and Exchange
Commission in connection with the solicitation of proxies for our 2025 Annual Meeting of Stockholders and is incorporated herein by reference. The 2025
Proxy Statement will be filed with the Securities and Exchange Commission within 120 days after the end of the fiscal year to which this report relates.


**ITEM 11. EXECUTIVE COMPENSATION**


The information required by this Item 11 of Form 10-K will be included in our 2025 Proxy Statement and is incorporated herein by reference.


**ITEM 12. SECURITY OWNERSHIP OF CERTAIN BENEFICIAL OWNERS AND MANAGEMENT AND RELATED STOCKHOLDER MATTERS**


The information required by this Item 12 of Form 10-K will be included in our 2025 Proxy Statement and is incorporated herein by reference.


**ITEM 13. CERTAIN RELATIONSHIPS AND RELATED TRANSACTIONS AND DIRECTOR INDEPENDENCE**


The information required by this Item 13 of Form 10-K will be included in our 2025 Proxy Statement and is incorporated herein by reference.


**ITEM 14. PRINCIPAL ACCOUNTANT FEES AND SERVICES**


The information required by this Item 14 of Form 10-K will be included in our 2025 Proxy Statement and is incorporated herein by reference.


93


---

**PART IV**


**ITEM 15. EXHIBITS AND FINANCIAL STATEMENT SCHEDULES**


1. Financial statements (see Index to Consolidated Financial Statements in Part II, Item 8 of this report)


2. All financial statement schedules have been omitted since the required information was not applicable or was not present in amounts sufficient to
require submission of the schedules, or because the information required is included in the consolidated financial statements or the accompanying
notes


3. The exhibits listed in the following Index to Exhibits are filed or incorporated by reference as part of this report


**INDEX TO EXHIBITS**


**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


3.1 [Certificate of Formation of the Registrant](https://www.sec.gov/Archives/edgar/data/1318605/000162828024032662/tsla-2024x06x30xex31.htm) 10-Q 001-34756 3.1 July 24, 2024


3.2 [Bylaws of the Registrant.](https://www.sec.gov/Archives/edgar/data/1318605/000162828024032662/tsla-2024x06x30xex32.htm) 10-Q 001-34756 3.2 July 24, 2024


4.1 Specimen common stock certificate of the
Registrant.


4.2 Fifth Amended and Restated Investors’ Rights
Agreement, dated as of August 31, 2009, between
Registrant and certain holders of the Registrant’s
capital stock named therein.


4.3 Amendment to Fifth Amended and Restated
Investors’ Rights Agreement, dated as of May 20,
2010, between Registrant and certain holders of
the Registrant’s capital stock named therein.


4.4 Amendment to Fifth Amended and Restated
Investors’ Rights Agreement between Registrant,
Toyota Motor Corporation and certain holders of
the Registrant’s capital stock named therein.


4.5 Amendment to Fifth Amended and Restated
Investor’s Rights Agreement, dated as of June 14,
2010, between Registrant and certain holders of
the Registrant’s capital stock named therein.


4.6 Amendment to Fifth Amended and Restated
Investor’s Rights Agreement, dated as of
[November 2, 2010, between Registrant and](https://www.sec.gov/Archives/edgar/data/1318605/000119312510248220/dex41.htm)
certain holders of the Registrant’s capital stock
named therein.


4.7 Waiver to Fifth Amended and Restated Investor’s
Rights Agreement, dated as of May 22, 2011,
between Registrant and certain holders of the
Registrant’s capital stock named therein.


----X


S-1 333-164593 4.2 January 29, 2010


S-1/A 333-164593 4.2A May 27, 2010


S-1/A 333-164593 4.2B May 27, 2010


S-1/A 333-164593 4.2C June 15, 2010


8-K 001-34756 4.1 November 4, 2010


S-1/A 333-174466 4.2E June 2, 2011


94


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.8 Amendment to Fifth Amended and Restated
Investor’s Rights Agreement, dated as of May 30,
2011, between Registrant and certain holders of
the Registrant’s capital stock named therein.


4.9 Sixth Amendment to Fifth Amended and Restated
Investors’ Rights Agreement, dated as of May 15,
2013 among the Registrant, the Elon Musk
Revocable Trust dated July 22, 2003 and certain
other holders of the capital stock of the Registrant
named therein.


4.10 Waiver to Fifth Amended and Restated Investor’s
Rights Agreement, dated as of May 14, 2013,
between the Registrant and certain holders of the
capital stock of the Registrant named therein.


4.11 Waiver to Fifth Amended and Restated Investor’s
Rights Agreement, dated as of August 13, 2015,
between the Registrant and certain holders of the
capital stock of the Registrant named therein.


4.12 Waiver to Fifth Amended and Restated Investors’
Rights Agreement, dated as of May 18, 2016,
between the Registrant and certain holders of the
capital stock of the Registrant named therein.


4.13 Waiver to Fifth Amended and Restated Investors’
Rights Agreement, dated as of March 15, 2017,
between the Registrant and certain holders of the
capital stock of the Registrant named therein.


4.14 Waiver to Fifth Amended and Restated Investors’
Rights Agreement, dated as of May 1, 2019,
between the Registrant and certain holders of the
capital stock of the Registrant named therein.


4.15 Indenture, dated as of May 22, 2013, by and
[between the Registrant and U.S. Bank National](https://www.sec.gov/Archives/edgar/data/1318605/000119312513231437/d542515dex41.htm)
Association.


4.16 Indenture, dated as of October 15, 2014, between
[SolarCity and U.S. Bank National Association, as](https://www.sec.gov/Archives/edgar/data/1408356/000119312514371976/d800964dex41.htm)
trustee.


4.17 Tenth Supplemental Indenture, dated as of March
9, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.00% Solar Bonds,
Series 2015/6-10.


8-K 001-34756 4.1 June 1, 2011


8-K 001-34756 4.1 May 20, 2013


8-K 001-34756 4.2 May 20, 2013


8-K 001-34756 4.1 August 19, 2015


8-K 001-34756 4.1 May 24, 2016


8-K 001-34756 4.1 March 17, 2017


8-K 001-34756 4.1 May 3, 2019


8-K 001-34756 4.1 May 22, 2013


S-3ASR(1) 333-199321 4.1 October 15, 2014


8-K(1) 001-35758 4.3 March 9, 2015


95


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.18 Eleventh Supplemental Indenture, dated as of
March 9, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.75% Solar Bonds,
Series 2015/7-15.


4.19 Fifteenth Supplemental Indenture, dated as of
March 19, 2015, by and between SolarCity and
the Trustee, related to SolarCity’s 4.70% Solar
Bonds, Series 2015/C4-10.


4.20 Sixteenth Supplemental Indenture, dated as of
March 19, 2015, by and between SolarCity and
the Trustee, related to SolarCity’s 5.45% Solar
Bonds, Series 2015/C5-15.


4.21 Twentieth Supplemental Indenture, dated as of
March 26, 2015, by and between SolarCity and
the Trustee, related to SolarCity’s 4.70% Solar
Bonds, Series 2015/C9-10.


4.22 Twenty-First Supplemental Indenture, dated as of
March 26, 2015, by and between SolarCity and
the Trustee, related to SolarCity’s 5.45% Solar
Bonds, Series 2015/C10-15.


4.23 Twenty-Sixth Supplemental Indenture, dated as of
April 2, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C14-10.


4.24 Thirtieth Supplemental Indenture, dated as of
April 9, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C19-10.


4.25 Thirty-First Supplemental Indenture, dated as of
April 9, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C20-15.


4.26 Thirty-Fifth Supplemental Indenture, dated as of
April 14, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C24-10.


4.27 Thirty-Sixth Supplemental Indenture, dated as of
April 14, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C25-15.


8-K(1) 001-35758 4.4 March 9, 2015


8-K(1) 001-35758 4.5 March 19, 2015


8-K(1) 001-35758 4.6 March 19, 2015


8-K(1) 001-35758 4.5 March 26, 2015


8-K(1) 001-35758 4.6 March 26, 2015


8-K(1) 001-35758 4.5 April 2, 2015


8-K(1) 001-35758 4.5 April 9, 2015


8-K(1) 001-35758 4.6 April 9, 2015


8-K(1) 001-35758 4.5 April 14, 2015


8-K(1) 001-35758 4.6 April 14, 2015


96


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.28 Thirty-Eighth Supplemental Indenture, dated as of
April 21, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C27-10.


4.29 Thirty-Ninth Supplemental Indenture, dated as of
April 21, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C28-15.


4.30 Forty-Third Supplemental Indenture, dated as of
April 27, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C32-10.


4.31 Forty-Fourth Supplemental Indenture, dated as of
April 27, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C33-15.


4.32 Forty-Eighth Supplemental Indenture, dated as of
May 1, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.00% Solar Bonds,
Series 2015/12-10.


4.33 Forty-Ninth Supplemental Indenture, dated as of
May 1, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.75% Solar Bonds,
Series 2015/13-15.


4.34 Fifty-Second Supplemental Indenture, dated as of
May 11, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C36-10.


4.35 Fifty-Third Supplemental Indenture, dated as of
May 11, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C37-15.


4.36 Fifty-Seventh Supplemental Indenture, dated as of
May 18, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C40-10.


4.37 Fifty-Eighth Supplemental Indenture, dated as of
May 18, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C41-15.


8-K(1) 001-35758 4.3 April 21, 2015


8-K(1) 001-35758 4.4 April 21, 2015


8-K(1) 001-35758 4.5 April 27, 2015


8-K(1) 001-35758 4.6 April 27, 2015


8-K(1) 001-35758 4.5 May 1, 2015


8-K(1) 001-35758 4.6 May 1, 2015


8-K(1) 001-35758 4.4 May 11, 2015


8-K(1) 001-35758 4.5 May 11, 2015


8-K(1) 001-35758 4.4 May 18, 2015


8-K(1) 001-35758 4.5 May 18, 2015


97


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.38 Sixty-First Supplemental Indenture, dated as of
May 26, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C44-10.


4.39 Sixty-Second Supplemental Indenture, dated as of
May 26, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C45-15.


4.40 Seventieth Supplemental Indenture, dated as of
June 16, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C52-10.


4.41 Seventy-First Supplemental Indenture, dated as of
June 16, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C53-15.


4.42 Seventy-Fourth Supplemental Indenture, dated as
of June 22, 2015, by and between SolarCity and
the Trustee, related to SolarCity’s 4.70% Solar
Bonds, Series 2015/C56-10.


4.43 Seventy-Fifth Supplemental Indenture, dated as of
June 22, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C57-15.


4.44 Eightieth Supplemental Indenture, dated as of
June 29, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C61-10.


4.45 Eighty-First Supplemental Indenture, dated as of
June 29, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C62-15.


4.46 Ninetieth Supplemental Indenture, dated as of July
20, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 4.70% Solar Bonds,
Series 2015/C71-10.


4.47 Ninety-First Supplemental Indenture, dated as of
July 20, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.45% Solar Bonds,
Series 2015/C72-15.


8-K(1) 001-35758 4.4 May 26, 2015


8-K(1) 001-35758 4.5 May 26, 2015


8-K(1) 001-35758 4.4 June 16, 2015


8-K(1) 001-35758 4.5 June 16, 2015


8-K(1) 001-35758 4.4 June 23, 2015


8-K(1) 001-35758 4.5 June 23, 2015


8-K(1) 001-35758 4.5 June 29, 2015


8-K(1) 001-35758 4.6 June 29, 2015


8-K(1) 001-35758 4.5 July 21, 2015


8-K(1) 001-35758 4.6 July 21, 2015


98


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.48 Ninety-Fifth Supplemental Indenture, dated as of
July 31, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.00% Solar Bonds,
Series 2015/20-10.


4.49 Ninety-Sixth Supplemental Indenture, dated as of
July 31, 2015, by and between SolarCity and the
Trustee, related to SolarCity’s 5.75% Solar Bonds,
Series 2015/21-15.


4.50 One Hundred-and-Fifth Supplemental Indenture,
dated as of August 10, 2015, by and between
SolarCity and the Trustee, related to SolarCity’s
4.70% Solar Bonds, Series 2015/C81-10.


4.51 One Hundred-and-Eleventh Supplemental
Indenture, dated as of August 17, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015007455/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C8715.


4.52 One Hundred-and-Sixteenth Supplemental
Indenture, dated as of August 24, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015007546/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C9215.


4.53 One Hundred-and-Twenty-First Supplemental
Indenture, dated as of August 31, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015007649/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C9715.


4.54 One Hundred-and-Twenty-Eighth Supplemental
Indenture, dated as of September 14, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015007969/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C10110.


4.55 One Hundred-and-Twenty-Ninth Supplemental
Indenture, dated as of September 14, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015007969/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C10215.


4.56 One Hundred-and-Thirty-Third Supplemental
Indenture, dated as of September 28, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015008193/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C10610.


8-K(1) 001-35758 4.5 July 31, 2015


8-K(1) 001-35758 4.6 July 31, 2015


8-K(1) 001-35758 4.5 August 10, 2015


8-K(1) 001-35758 4.6 August 17, 2015


8-K(1) 001-35758 4.6 August 24, 2015


8-K(1) 001-35758 4.6 August 31, 2015


8-K(1) 001-35758 4.5 September 15, 2015


8-K(1) 001-35758 4.6 September 15, 2015


8-K(1) 001-35758 4.5 September 29, 2015


99


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.57 One Hundred-and-Thirty-Fourth Supplemental
Indenture, dated as of September 28, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015008193/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C10715.


4.58 One Hundred-and-Thirty-Eighth Supplemental
Indenture, dated as of October 13, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015008369/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C11110.


4.59 One Hundred-and-Forty-Third Supplemental
Indenture, dated as of October 30, 2015, by and
between SolarCity and the Trustee, related to
SolarCity’s 5.00% Solar Bonds, Series 2015/25-10.


4.60 One Hundred-and-Forty-Fourth Supplemental
Indenture, dated as of October 30, 2015, by and
between SolarCity and the Trustee, related to
SolarCity’s 5.75% Solar Bonds, Series 2015/26-15.


4.61 One Hundred-and-Forty-Eighth Supplemental
Indenture, dated as of November 4, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015009335/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C11610.


4.62 One Hundred-and-Fifty-Third Supplemental
Indenture, dated as of November 16, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015010841/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C12110.


4.63 One Hundred-and-Fifty-Fourth Supplemental
Indenture, dated as of November 16, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015010841/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C12215.


4.64 One Hundred-and-Fifty-Eighth Supplemental
Indenture, dated as of November 30, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011167/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C12610.


4.65 One Hundred-and-Fifty-Ninth Supplemental
Indenture, dated as of November 30, 2015, by
[and between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011167/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C12715.


8-K(1) 001-35758 4.6 September 29, 2015


8-K(1) 001-35758 4.5 October 13, 2015


8-K(1) 001-35758 4.5 October 30, 2015


8-K(1) 001-35758 4.6 October 30, 2015


8-K(1) 001-35758 4.5 November 4, 2015


8-K(1) 001-35758 4.5 November 17, 2015


8-K(1) 001-35758 4.6 November 17, 2015


8-K(1) 001-35758 4.5 November 30, 2015


8-K(1) 001-35758 4.6 November 30, 2015


100


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


4.66 One Hundred-and-Sixty-Third Supplemental
Indenture, dated as of December 14, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011493/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C13110.


4.67 One Hundred-and-Sixty-Fourth Supplemental
Indenture, dated as of December 14, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011493/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C13215.


4.68 One Hundred-and-Sixty-Eighth Supplemental
Indenture, dated as of December 28, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011647/scty-ex45_9.htm)
SolarCity’s 4.70% Solar Bonds, Series 2015/C13610.


4.69 One Hundred-and-Sixty-Ninth Supplemental
Indenture, dated as of December 28, 2015, by and
[between SolarCity and the Trustee, related to](https://www.sec.gov/Archives/edgar/data/1408356/000156459015011647/scty-ex46_10.htm)
SolarCity’s 5.45% Solar Bonds, Series 2015/C13715.


4.70 One Hundred-and-Seventy-Third Supplemental
Indenture, dated as of January 29, 2016, by and
between SolarCity and the Trustee, related to
SolarCity’s 5.00% Solar Bonds, Series 2016/4-10.


4.71 One Hundred-and-Seventy-Fourth Supplemental
Indenture, dated as of January 29, 2016, by and
between SolarCity and the Trustee, related to
SolarCity’s 5.75% Solar Bonds, Series 2016/5-15.


8-K(1) 001-35758 4.5 December 14, 2015


8-K(1) 001-35758 4.6 December 14, 2015


8-K(1) 001-35758 4.5 December 28, 2015


8-K(1) 001-35758 4.6 December 28, 2015


8-K(1) 001-35758 4.5 January 29, 2016


8-K(1) 001-35758 4.6 January 29, 2016


4.72 Description of Registrant’s Securities - - - - X


10.1** Form of Indemnification Agreement between the
Registrant and its directors and officers.


S-1/A 333-164593 10.1 June 15, 2010


10.2** [2003 Equity Incentive Plan.](https://www.sec.gov/Archives/edgar/data/1318605/000119312510129878/dex102.htm) S-1/A 333-164593 10.2 May 27, 2010


10.3** Form of Stock Option Agreement under 2003
Equity Incentive Plan.


10.4** Amended and Restated 2010 Equity Incentive
Plan.


10.5** Form of Stock Option Agreement under 2010
Equity Incentive Plan.


10.6** Form of Restricted Stock Unit Award Agreement
under 2010 Equity Incentive Plan.


S-1 333-164593 10.3 January 29, 2010


10-K 001-34756 10.4 February 23, 2018


10-K 001-34756 10.6 March 1, 2017


10-K 001-34756 10.7 March 1, 2017


101


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


10.7** Amended and Restated 2010 Employee Stock
Purchase Plan, effective as of February 1, 2017.


10-K 001-34756 10.8 March 1, 2017


10.8** [2019 Equity Incentive Plan.](https://www.sec.gov/Archives/edgar/data/1318605/000119312519171236/d763161dex42.htm) S-8 333-232079 4.2 June 12, 2019


10.9** Form of Stock Option Agreement under 2019
Equity Incentive Plan.


10.10** Form of Restricted Stock Unit Award Agreement
under 2019 Equity Incentive Plan.


10.11** Employee Stock Purchase Plan, effective as of
June 12, 2019.


10.12** 2012 SolarCity Equity Incentive Plan and form of
agreements used thereunder.


10.13** Offer Letter between the Registrant and Elon
Musk dated October 13, 2008.


10.14** Performance Stock Option Agreement between
[the Registrant and Elon Musk dated January 21,](https://www.sec.gov/Archives/edgar/data/1318605/000119312518035345/d524719ddef14a.htm)
2018.


10.15 Indemnification Agreement, effective as of June
23, 2020, between Registrant and Elon R. Musk.


10.16 Form of Call Option Confirmation relating to
[1.25% Convertible Senior Notes Due March 1,](https://www.sec.gov/Archives/edgar/data/1318605/000119312514084484/d686051dex103.htm)
2021.


10.17† Supply Agreement between Panasonic
[Corporation and the Registrant dated October 5,](https://www.sec.gov/Archives/edgar/data/1318605/000119312512081990/d279413dex1050.htm)
2011.


10.18† Amendment No. 1 to Supply Agreement between
[Panasonic Corporation and the Registrant dated](https://www.sec.gov/Archives/edgar/data/1318605/000119312514069681/d668062dex1035a.htm)
October 29, 2013.


10.19 Agreement between Panasonic Corporation and
the Registrant dated July 31, 2014.


10.20† General Terms and Conditions between Panasonic
[Corporation and the Registrant dated October 1,](https://www.sec.gov/Archives/edgar/data/1318605/000119312516735804/d253219dex102.htm)
2014.


10.21 Letter Agreement, dated as of February 24, 2015,
regarding addition of co-party to General Terms
[and Conditions, Production Pricing Agreement and](https://www.sec.gov/Archives/edgar/data/1318605/000156459016013195/tsla-ex1025a_208.htm)
Investment Letter Agreement between Panasonic
Corporation and the Registrant.


S-8 333-232079 4.3 June 12, 2019


S-8 333-232079 4.4 June 12, 2019


S-8 333-232079 4.5 June 12, 2019


S-1(1) 333-184317 10.3 October 5, 2012


S-1 333-164593 10.9 January 29, 2010


DEF 14A 001-34756 Appendix A February 8, 2018


10-Q 001-34756 10.4 July 28, 2020


8-K 001-34756 10.3 March 5, 2014


10-K 001-34756 10.50 February 27, 2012


10-K 001-34756 10.35A February 26, 2014


10-Q 001-34756 10.1 November 7, 2014


8-K 001-34756 10.2 October 11, 2016


10-K 001-34756 10.25A February 24, 2016


102


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


10.22† Investment Letter Agreement between Panasonic
[Corporation and the Registrant dated October 1,](https://www.sec.gov/Archives/edgar/data/1318605/000119312514403635/d812482dex104.htm)
2014.


10.23 Amendment to Gigafactory Documents, dated
April 5, 2016, by and among the Registrant,
[Panasonic Corporation, Panasonic Corporation of](https://www.sec.gov/Archives/edgar/data/1318605/000156459016018886/tsla-ex102_181.htm)
North America and Panasonic Energy Corporation
of North America.


10.24†† 2019 Pricing Agreement (Japan Cells) with respect
to 2011 Supply Agreement, executed September
[20, 2019, by and among the Registrant, Tesla](https://www.sec.gov/Archives/edgar/data/1318605/000156459019038256/tsla-ex106_429.htm)
Motors Netherlands B.V., Panasonic Corporation
and SANYO Electric Co., Ltd.


10.25†† 2020 Pricing Agreement (Gigafactory 2170 Cells),
entered into on June 9, 2020, by and among
[Registrant, Tesla Motors Netherlands B.V.,](https://www.sec.gov/Archives/edgar/data/0001318605/000156459020033670/tsla-ex103_487.htm)
Panasonic Corporation and Panasonic Corporation
[of North America.](https://www.sec.gov/Archives/edgar/data/1318605/000156459020033670/tsla-ex101_6.htm)


10.26†† 2021 Pricing Agreement (Japan Cells) with respect
to 2011 Supply Agreement, executed December
[29, 2020, by and among the Registrant, Tesla](https://www.sec.gov/Archives/edgar/data/1318605/000156459021004599/tsla-ex1039_377.htm)
Motors Netherlands B.V., Panasonic Corporation of
North America and SANYO Electric Co., Ltd.


10.27†† Amended and Restated Factory Lease, executed
as of March 26, 2019, by and between the
[Registrant and Panasonic Energy North America, a](https://www.sec.gov/Archives/edgar/data/1318605/000156459019026445/tsla-ex103_198.htm)
division of Panasonic Corporation of North
America, as tenant.


10.28†† Lease Amendment, executed September 20,
2019, by and among the Registrant, Panasonic
Corporation of North America, on behalf of its
division Panasonic Energy of North America, with
respect to the Amended and Restated Factory
Lease, executed as of March 26, 2019.


10.29†† Second Lease Amendment, entered into on June
9, 2020, by and between the Registrant and
Panasonic Energy of North America, a division of
Panasonic Corporation of North America, with
respect to the Amended and Restated Factory
Lease dated January 1, 2017.


10.30† Agreement for Tax Abatement and Incentives,
dated as of May 7, 2015, by and between Tesla
[Motors, Inc. and the State of Nevada, acting by](https://www.sec.gov/Archives/edgar/data/1318605/000156459015006666/tsla-ex101_265.htm)
and through the Nevada Governor’s Office of
Economic Development.


10-Q 001-34756 10.4 November 7, 2014


10-Q 001-34756 10.2 May 10, 2016


10-Q 001-34756 10.6 October 29, 2019


10-Q 001-34756 10.3 July 28, 2020


10-K 001-34756 10.39 February 8, 2021


10-Q 001-34756 10.3 July 29, 2019


10-Q 001-34756 10.7 October 29, 2019


10-Q 001-34756 10.1 July 28, 2020


10-Q 001-34756 10.1 August 7, 2015


103


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


10.31 Amended and Restated Agreement For Research
& Development Alliance on Triex Module
Technology, effective as of September 2, 2014, by
[and between The Research Foundation For The](https://www.sec.gov/Archives/edgar/data/1408356/000119312514399634/d800656dex1016.htm)
State University of New York, on behalf of the
College of Nanoscale Science and Engineering of
the State University of New York, and Silevo, Inc.


10.32 First Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
October 31, 2014, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, Inc.


10.33 Second Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
December 15, 2014, by and between The
Research Foundation For The State University of
New York, on behalf of the College of Nanoscale
Science and Engineering of the State University of
New York, and Silevo, Inc.


10.34 Third Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
February 12, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, Inc.


10.35 Fourth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of March
30, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, Inc.


10.36 Fifth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of June
30, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, LLC.


10-Q(1) 001-35758 10.16 November 6, 2014


10-K(1) 001-35758 10.16a February 24, 2015


10-K(1) 001-35758 10.16b February 24, 2015


10-Q(1) 001-35758 10.16c May 6, 2015


10-Q(1) 001-35758 10.16d May 6, 2015


10-Q(1) 001-35758 10.16e July 30, 2015


104


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


10.37 Sixth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
September 1, 2015, by and between The
Research Foundation For The State University of
New York, on behalf of the College of Nanoscale
Science and Engineering of the State University of
New York, and Silevo, LLC.


10.38 Seventh Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
October 9, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, LLC.


10.39 Eighth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
October 26, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, LLC.


10.40 Ninth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of
December 9, 2015, by and between The Research
Foundation For The State University of New York,
on behalf of the College of Nanoscale Science and
Engineering of the State University of New York,
and Silevo, LLC.


10.41 Tenth Amendment to Amended and Restated
Agreement For Research & Development Alliance
on Triex Module Technology, effective as of March
31, 2017, by and between The Research
Foundation For The State University of New York,
on behalf of the Colleges of Nanoscale Science
and Engineering of the State University of New
York, and Silevo, LLC.


10.42 Eleventh Amendment to Amended and Restated
Agreement for Research & Development Alliance
on Triex Module Technology, effective as of July
22, 2020, among the Research Foundation for the
State University of New York, Silevo, LLC and
Tesla Energy Operations, Inc.


10-Q(1) 001-35758 10.16f October 30, 2015


10-Q(1) 001-35758 10.16g October 30, 2015


10-Q(1) 001-35758 10.16h October 30, 2015


10-K(1) 001-35758 10.16i February 10, 2016


10-Q 001-34756 10.8 May 10, 2017


10-Q 001-34756 10.6 July 28, 2020


105


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


10.43 Twelfth Amendment to Amended and Restated
Agreement for Research & Development Alliance
on Triex Module Technology, effective as of May 1,
2021, among the Research Foundation for the
State University of New York, Silevo, LLC and Tesla
Energy Operations, Inc.


10.44†† Grant Contract for State-Owned Construction Land
Use Right, dated as of October 17, 2018, by and
between Shanghai Planning and Land Resource
Administration Bureau, as grantor, and Tesla
(Shanghai) Co., Ltd., as grantee (English
translation).


10.45 Credit Agreement, dated as of January 20, 2023,
among Tesla, Inc., the Lenders and Issuing Banks
[from time to time party thereto, Citibank, N.A., as](https://www.sec.gov/Archives/edgar/data/1318605/000095017023001409/tsla-ex10_59.htm)
Administrative Agent and Deutsche Bank
Securities, Inc., as Syndication Agent


10-Q 001-34756 10.1 October 25, 2021


10-Q 001-34756 10.2 July 29, 2019


10-K 001-34756 10.59 January 31, 2023


19 Insider Trading Policy - - - - X


21.1 List of Subsidiaries of the Registrant - - - - X


23.1 Consent of PricewaterhouseCoopers LLP,
Independent Registered Public Accounting Firm


31.1 Rule 13a-14(a) / 15(d)-14(a) Certification of
Principal Executive Officer


31.2 Rule 13a-14(a) / 15(d)-14(a) Certification of
Principal Financial Officer


----X


----X


----X


32.1* Section 1350 Certifications - - - - X


97 [Tesla, Inc. Clawback Policy](https://www.sec.gov/Archives/edgar/data/1318605/000162828024002390/tsla-2023x12x31xex97.htm) 10-K 001-34756 97 January 29, 2024


101.INS Inline XBRL Instance Document - - - - X


101.SCH Inline XBRL Taxonomy Extension Schema
Document


101.CAL Inline XBRL Taxonomy Extension Calculation
Linkbase Document.


101.DEF Inline XBRL Taxonomy Extension Definition
Linkbase Document


101.LAB Inline XBRL Taxonomy Extension Label Linkbase
Document


----X


----X


----X


----X


106


---

**Exhibit**

**Number**


**Incorporated by Reference** **Filed**

**Exhibit Description** **Form** **File No.** **Exhibit** **Filing Date** **Herewith**


101.PRE Inline XBRL Taxonomy Extension Presentation
Linkbase Document


104 Cover Page Interactive Data File (formatted as
inline XBRL with applicable taxonomy extension
information contained in Exhibits 101)


----X


- Furnished herewith
** Indicates a management contract or compensatory plan or arrangement

- Confidential treatment has been requested for portions of this exhibit
†† Portions of this exhibit have been redacted in compliance with Regulation S-K Item 601(b)(10).
(1) Indicates a filing of SolarCity
(2) Indicates a filing of Maxwell Technologies, Inc.


**ITEM 16. FORM 10-K SUMMARY**


None.


107


---

**SIGNATURES**


Pursuant to the requirements of Section 13 or 15(d) the Securities Exchange Act of 1934, the registrant has duly caused this report to be signed on
its behalf by the undersigned, thereunto duly authorized.


Tesla, Inc.


Date: January 29, 2025 /s/ Elon Musk


Elon Musk


Chief Executive Officer


(Principal Executive Officer)


Pursuant to the requirements of the Securities Exchange Act of 1934, this report has been signed below by the following persons on behalf of the
registrant and in the capacities and on the dates indicated.


**Signature** **Title** **Date**


/s/ Elon Musk Chief Executive Officer and Director (Principal Executive Officer) January 29, 2025


Elon Musk


/s/ Vaibhav Taneja


Vaibhav Taneja


Chief Financial Officer (Principal Financial Officer and Principal
Accounting Officer) January 29, 2025


/s/ Robyn Denholm Director January 29, 2025


Robyn Denholm


/s/ Ira Ehrenpreis Director January 29, 2025


Ira Ehrenpreis


/s/ Joseph Gebbia Director January 29, 2025


Joseph Gebbia


/s/ James Murdoch Director January 29, 2025


James Murdoch


/s/ Kimbal Musk Director January 29, 2025


Kimbal Musk


/s/ JB Straubel Director January 29, 2025


JB Straubel


/s/ Kathleen Wilson-Thompson Director January 29, 2025


Kathleen Wilson-Thompson


108


---

By AUTHORIZED SIGNATURE THIS CERTIFIES THAT is the owner of CUSIP DATED COUNTERSIGNED AND REGISTERED: COMPUTERSHARE TRUST COMPANY, N.A. TRANSFER AGENT AND REGISTRAR, FULLY-PAID AND NON-ASSESSABLE SHARES OF THE COMMON STOCK OF Tesla, Inc. (hereinafter called the “Company”), transferable on the books of the Company in person or by duly authorized attorney, upon surrender of this Certificate properly endorsed. This Certificate and the shares represented hereby, are issued and shall be held subject to all of the provisions of the Certificate of Formation and the Bylaws of the Company (copies of which are on file with the Company and with the Transfer Agent), to all of which each holder, by acceptance hereof, assents. This Certificate is not valid unless countersigned and registered by the Transfer Agent and Registrar. Witness the facsimile seal of the Company and the facsimile signatures of its duly authorized officers. COMMON STOCK PAR VALUE $0.001 COMMON STOCK Certificate Number Shares . TESLA, INC. INCORPORATED UNDER THE LAWS OF THE STATE OF TEXAS Chief Executive Officer General Counsel and Secretary SEE REVERSE FOR CERTAIN DEFINITIONS THIS CERTIFICATE IS TRANSFERABLE IN CITIES DESIGNATED BY THE TRANSFER AGENT, AVAILABLE ONLINE AT www.computershare.com 88160R 10 1 ZQ|CERT#|COY|CLS|RGSTRY|ACCT#|TRANSTYPE|RUN#|TRANS# DD-MMM-YYYY * * 0 0 0 0 0 0 * * * * * * * * * * * * * * * * * * * * * 0 0 0 0 0 0 * * * * * * * * * * * * * * * * * * * * * 0 0 0 0 0 0 * * * * * * * * * * * * * * * * * * * * * 0 0 0 0 0 0 * * * * * * * * * * * * * * * * * * * * * 0 0 0 0 0 0 * * * * * * * * * * * * * * ** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David


Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Alexander David Sample **** Mr. Sample **** Mr. Sample **000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares*** *000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****


000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****0 00000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****00 0000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000 000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****0000 00**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****00000 0**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000 **Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000* *Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000** Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**Shares****000000**S * *ZERO HUNDRED THOUSAND ZERO HUNDRED AND ZERO** MR. SAMPLE & MRS SAMPLE & MR. A PLE & MRS. SAMPLE ZQ00000000 Certificate Num bers 1234567890/1234567890 1234567890/1234567890 1234567890/1234567890 1234567890/1234567890 1234567890/1234567890 1234567890/1234567890 Total Transaction Num /No. 123456 Denom . 123456 Total 1234567 MR A SAMPLE DESIGNATION (IF ANY) ADD 1 ADD 2 ADD 3 ADD 4 PO BOX 43004, Providence, RI 02940

3004 CUSIP XXXXXX XX X Holder ID XXXXXXXXXX Insurance Value 1,000,000.00 Num ber of Shares 123456 DTC 12345678 123456789012345 Exhibit 4.1


---

The IRS requires that the named transfer agent (“we”) report the cost basis of certain shares or units acquired after January 1, 2011. If your shares or units are covered by the legislation, and you requested to sell or transfer the shares or units using a specific cost basis calculation method, then we have processed as you requested. If you did not specify a cost basis calculation method, then we have defaulted to the first in, first out (FIFO) method. Please consult your tax advisor if you need additional information about cost basis. If you do not keep in contact with the issuer or do not have any activity in your account for the time period specified by state law, your property may become subject to state unclaimed property laws and transferred to the appropriate state. For value received, ____________________________hereby sell, assign and transfer unto ________________________________________________________________________________________________________________________________ ________________________________________________________________________________________________________________________________ ________________________________________________________________________________________________________________________________ _______________________________________________________________________________________________________________________ Shares _______________________________________________________________________________________________________________________ Attorney Dated: __________________________________________20__________________ Signature: ____________________________________________________________ Signature: ____________________________________________________________ Notice: The signature to this assignment must correspond with the name as written upon the face of the certificate, in every particular, without alteration or enlargement, or any change whatever. PLEASE INSERT SOCIAL SECURITY OR OTHER IDENTIFYING NUMBER


OF ASSIGNEE (PLEASE PRINT OR TYPEWRITE NAME AND ADDRESS, INCLUDING POSTAL ZIP CODE, OF ASSIGNEE) of the capital stock represented by the within Certificate, and do hereby irrevocably constitute and appoint to transfer the said stock on the books of the within-named Company with full power of substitution in the premises. . Tesla, Inc. THE COMPANY WILL FURNISH WITHOUT CHARGE TO EACH STOCKHOLDER WHO SO REQUESTS, A SUMMARY OF THE POWERS, DESIGNATIONS, PREFERENCES AND RELATIVE, PARTICIPATING, OPTIONAL OR OTHER SPECIAL RIGHTS OF EACH CLASS OF STOCK OF THE COMPANY AND THE QUALIFICATIONS, LIMITATIONS OR RESTRICTIONS OF SUCH PREFERENCES AND RIGHTS, AND THE VARIATIONS IN RIGHTS, PREFERENCES AND LIMITATIONS DETERMINED FOR EACH SERIES, WHICH ARE FIXED BY THE CERTIFICATE OF INCORPORATION OF THE COMPANY, AS AMENDED, AND THE RESOLUTIONS OF THE BOARD OF DIRECTORS OF THE COMPANY, AND THE AUTHORITY OF THE BOARD OF DIRECTORS TO DETERMINE VARIATIONS FOR FUTURE SERIES. SUCH REQUEST MAY BE MADE TO THE OFFICE OF THE SECRETARY OF THE COMPANY OR TO THE TRANSFER AGENT. THE BOARD OF DIRECTORS MAY REQUIRE THE OWNER OF A LOST OR DESTROYED STOCK CERTIFICATE, OR HIS LEGAL REPRESENTATIVES, TO GIVE THE COMPANY A BOND TO INDEMNIFY IT AND ITS TRANSFER AGENTS AND REGISTRARS AGAINST ANY CLAIM THAT MAY BE MADE AGAINST THEM ON ACCOUNT OF THE ALLEGED LOSS OR DESTRUCTION OF ANY SUCH CERTIFICATE. Signature(s) Guaranteed: Medallion Guarantee Stamp THE SIGNATURE(S) SHOULD BE GUARANTEED BY AN ELIGIBLE GUARANTOR INSTITUTION (Banks, Stockbrokers, Savings and Loan Associations and Credit Unions) WITH MEMBERSHIP IN AN APPROVED


SIGNATURE GUARANTEE MEDALLION PROGRAM, PURSUANT TO S.E.C. RULE 17Ad-15. The following abbreviations, when used in the inscription on the face of this certificate, shall be construed as though they were written out in full according to applicable laws or regulations: TEN COM - as tenants in common UNIF GIFT MIN ACT - ............................................Custodian ................................................ (Cust) (Minor) TEN ENT - as tenants by the entireties under Uniform Gifts to Minors Act......................................................... (State) JT TEN - as joint tenants with right of survivorship UNIF TRF MIN ACT - ............................................Custodian (until age ................................) (Cust) .............................under Uniform Transfers to Minors Act ................... (Minor) (State) Additional abbreviations may also be used though not in the above list.


---

**Exhibit 4.72**


**DESCRIPTION OF THE REGISTRANT’S SECURITIES REGISTERED PURSUANT**

**TO SECTION 12 OF THE SECURITIES EXCHANGE ACT OF 1934**


As of January 29, 2025, Tesla, Inc. had one class of common stock registered under Section 12 of the Securities Exchange Act
of 1934, as amended (the “Exchange Act”).


The following description of our common stock is a summary and does not purport to be complete. It is subject to and qualified
in its entirety by reference to our certificate of formation (the “Certificate of Formation”) and our bylaws (the “Bylaws”), each of
which is incorporated herein by reference as an exhibit to the Annual Report on Form 10-K filed with the Securities and Exchange
Commission, of which this Exhibit 4.72 is a part. We encourage you to read our Certificate of Formation, our Bylaws and the
applicable provisions of the Texas Business Organizations Code (the “TBOC”) for additional information.


**Authorized Capital Stock**


Our authorized capital stock consists of 6,100,000,000 shares, with a par value of $0.001 per share, of which 6,000,000,000
shares are designated as common stock.


The holders of common stock are entitled to one vote per share on all matters submitted to a vote of our shareholders and do
not have cumulative voting rights. Accordingly, holders of a majority of the shares of common stock entitled to vote in any election of
directors have the power to elect all of the directors standing for election. Subject to preferences that may be applicable to any
preferred stock outstanding at the time, the holders of outstanding shares of common stock are entitled to receive ratably any
dividends declared by our board of directors out of assets legally available. Upon our liquidation, dissolution or winding up, holders of
our common stock are entitled to share ratably in all assets remaining after payment of liabilities and the liquidation preference of
any then outstanding shares of preferred stock. Holders of common stock have no preemptive or conversion rights or other
subscription rights. There are no redemption or sinking fund provisions applicable to the common stock.


We have certain outstanding securities that may be converted, exercised or exchanged into shares of our common stock.


**Registration Rights**


Certain holders of unregistered common stock purchased in private placements, or their permitted transferees, are entitled to
rights with respect to the registration of such shares under the Securities Act of 1933, as amended, or the Securities Act. These rights
are provided under the terms of an investors’ rights agreement between us and the holders of these shares, or the investors’ rights
agreement, and include demand registration rights, short-form registration rights and piggyback registration rights. All fees, costs
and expenses of underwritten registrations will be borne by us and all selling expenses, including underwriting discounts and selling
commissions, will be borne by the holders of the shares being sold.


The registration rights terminate with respect to an individual holder after the date that is five years following such time when
the holder can sell all of the holder’s shares in any three month period under Rule 144 or another similar exemption under the
Securities Act, unless such holder holds at least 2% of our voting stock.


---

**Listing**


Our common stock is listed on the Nasdaq Global Select Market under the symbol “TSLA.”


**Transfer Agent and Registrar**


The transfer agent and registrar for our common stock is Computershare Trust Company, N.A.


**Anti-Takeover Effects of Texas Law and Our Certificate of Formation and Bylaws**


Our Certificate of Formation and our Bylaws contain certain provisions that could have the effect of delaying, deterring or
preventing another party from acquiring control of us. These provisions and certain provisions of Texas law, which are summarized
below, are expected to discourage coercive takeover practices and inadequate takeover bids. These provisions are also designed, in
part, to encourage persons seeking to acquire control of us to negotiate first with our board of directors. We believe that the benefits
of increased protection of our potential ability to negotiate more favorable terms with an unfriendly or unsolicited acquirer outweigh
the disadvantages of discouraging a proposal to acquire us.


**Limits on Ability of Shareholders to Act by Written Consent or Call a Special Meeting**


Our Certificate of Formation provides that our shareholders may act by written consent only if all holders of shares entitled to
vote on such action adopts a resolution by unanimous written consent. This may deter action by written consent or lengthen the
amount of time required to take shareholder actions. As a result, even a holder controlling a majority of our capital stock would not
be able to amend our Bylaws or remove directors without holding a meeting of our shareholders called in accordance with our
Bylaws.


In addition, our Certificate of Formation provides that special meetings of shareholders may be called by the chairperson of the
board, the chief executive officer, the president (to the extent required by the TBOC), our board of directors, or by shareholders
holding not less than 50% (or the highest percentage of ownership that may be set under the TBOC) of the Corporation’s then
outstanding shares of capital stock entitled to vote at such meeting. The threshold required for shareholders to call a special meeting
may delay the ability of our shareholders to force consideration of a proposal or for holders controlling a majority of our capital stock
to take any action, including the removal of directors.


**Requirements for Advance Notification of Shareholder Nominations and Proposals**


Our Bylaws establish advance notice procedures with respect to shareholder proposals and the nomination of candidates for
election as directors, other than nominations made by or at the direction of our board of directors or a committee of our board of
directors. These provisions may have the effect of precluding the conduct of certain business at a meeting if the proper procedures
are not followed. These provisions may also discourage or deter a potential acquirer from conducting a solicitation of proxies to elect
the acquirer’s own slate of directors or otherwise attempting to obtain control of our company.


**Board Classification**


Our board of directors is divided into three classes, one of which classes is elected each year by our shareholders to serve for a
three-year term. A third party may be discouraged from making a tender offer or otherwise attempting to obtain control of us as it is
more difficult and time-consuming for shareholders to replace a majority of the directors on a classified board.


2


---

**No Cumulative Voting**


Our Certificate of Formation and Bylaws do not permit cumulative voting in the election of directors. Cumulative voting allows a
shareholder to vote a portion or all of its shares for one or more candidates for seats on the board of directors. Without cumulative
voting, a minority stockholder may not be able to gain as many seats on our board of directors as the shareholder would be able to
gain if cumulative voting were permitted. The absence of cumulative voting makes it more difficult for a minority shareholder to gain
a seat on our board of directors to influence our board’s decision regarding a takeover.


**Amendment of Certificate of Formation Provisions**


The amendment of our Certificate of Formation requires approval by holders of at least two-thirds of our outstanding capital
stock entitled to vote generally in the election of directors.


**Texas Anti-Takeover Statute**


We are subject to the provisions of Section 21.606 of the TBOC regulating corporate takeovers. In general, Section 21.606
prohibits a publicly held Texas corporation from engaging, under certain circumstances, in a business combination with an affiliated
shareholder for a period of three years following the date the person became an affiliated shareholder unless:


   - prior to the date of the transaction, our board of directors approved either the business combination or the transaction
that resulted in the shareholder becoming an affiliated stockholder; or


   - at or subsequent to the date of the transaction, the business combination is approved by our board of directors and
authorized at an annual or special meeting of shareholders, and not by written consent, by the affirmative vote of at
least two-thirds of the outstanding voting stock which is not owned by the affiliated stockholder at a meeting of
shareholders called for that purpose not less than six months after the affiliated shareholder’s share acquisition date.


Generally, a business combination includes a merger, share exchange, asset or stock sale, or other transaction resulting in a
financial benefit to the interested stockholder. An interested shareholder is a person who, together with affiliates and associates,
owns or, within three years prior to the determination of interested shareholder status did own, 15% or more of a corporation’s
outstanding voting stock. We expect the existence of this provision to have an anti-takeover effect with respect to transactions our
board of directors does not approve in advance. We also anticipate that Section 21.606 may also discourage attempts that might
result in a premium over the market price for the shares of common stock held by shareholders.


The provisions of Texas law and the provisions of our Certificate of Formation and Bylaws could have the effect of discouraging
others from attempting hostile takeovers and, as a consequence, they might also inhibit temporary fluctuations in the market price of
our common stock that often result from actual or rumored hostile takeover attempts. These provisions might also have the effect of
preventing changes in our management. It is possible that these provisions could make it more difficult to accomplish transactions
that shareholders might otherwise deem to be in their best interests.


3
**Exhibit 19**


---

**TESLA, INC.**


___________________


**INSIDER TRADING POLICY**


**and**


**Guidelines with Respect to Certain Transactions in Securities**


---

**TABLE OF CONTENTS**


**Page**

INTRODUCTION 1

Legal prohibitions on insider trading 1

Detection and prosecution of insider trading 1

Penalties for violation of insider trading laws and this Policy 1

Insider Trading Compliance Officer 2

Reporting violations 2

Personal responsibility 2


PERSONS AND TRANSACTIONS COVERED BY THIS POLICY 2

Persons covered by this Policy 2

Types of transactions covered by this Policy 3

Responsibilities regarding the nonpublic information of other companies 3

Applicability of this Policy after your departure 3

No exceptions based on personal circumstances 3


MATERIAL NONPUBLIC INFORMATION 3

“Material” information 3

“Nonpublic” information 4


POLICIES REGARDING MATERIAL NONPUBLIC INFORMATION 5

Confidentiality of nonpublic information 5

No trading on material nonpublic information 5

No disclosing material nonpublic information for the benefit of others 5

Responding to outside inquiries for information 6


TRADING BLACKOUT PERIODS 6

Quarterly blackout periods 6

Special blackout periods 7

Regulation BTR blackouts 7

No “safe harbors” 7


PRE-CLEARANCE OF TRADES 7


ADDITIONAL RESTRICTIONS AND GUIDANCE 8

Short sales 8

Derivative securities and hedging transactions 8

Using Company securities as collateral for loans 9

Holding Company securities in margin accounts 9

Placing open orders with brokers 9


LIMITED EXCEPTIONS 9

Transactions pursuant to a trading plan that complies with SEC rules 9


---

Receipt and vesting of stock options, restricted stock units, restricted stock and stock appreciation
rights 10

Exercise of stock options for cash 10

Purchases from the employee stock purchase plan 10

Certain 401(k) plan transactions 10

Stock splits, stock dividends and similar transactions 11

Inheritance and bona fide gifts 11

Change in form of ownership 11

Other exceptions 11


COMPLIANCE WITH SECTION 16 OF THE SECURITIES EXCHANGE ACT 11

Obligations under Section 16 11

Notification requirements to facilitate Section 16 reporting 11

Personal responsibility 12


ADDITIONAL INFORMATION 12

Availability of Policy 12

Amendments 12

Ancillary Documents 12


SCHEDULE A (Individuals subject to Section 16 reporting and pre-clearance obligations)


SCHEDULE B (Forms of ancillary documents)


---

**INTRODUCTION**


Tesla, Inc. (together with its subsidiaries, the “ **Company** ”) opposes the unauthorized disclosure of any nonpublic information
acquired in the course of your service with the Company and the misuse of material nonpublic information in securities trading.
Any such actions will be deemed violations of this Insider Trading Policy (the “ **Policy** ”) and you may be subject to disciplinary
actions as described below.


**Legal prohibitions on insider trading**


The antifraud provisions of U.S. federal securities laws prohibit directors, officers, employees and other individuals who
possess material nonpublic information from trading on the basis of that information. Transactions will be considered “on the
basis of” material nonpublic information if the person engaged in the transaction was aware of the material nonpublic information
at the time of the transaction. It is not a defense that the person did not “use” the information for purposes of the transaction.


Disclosing material nonpublic information directly or indirectly to others who then trade based on that information or making
recommendations or expressing opinions as to transactions in securities while aware of material nonpublic information (which is
sometime referred to as “ **tipping** ”) is also illegal. Both the person who provides the information, recommendation or opinion and
the person who trades based on it may be liable.


These illegal activities are commonly referred to as “ **insider trading** .” State securities laws and securities laws of other
jurisdictions also impose restrictions on insider trading.


In addition, a company, as well as individual directors, officers and other supervisory personnel, may be subject to liability as
“controlling persons” for failure to take appropriate steps to prevent insider trading by those under their supervision, influence or
control.


It is also Company policy to comply with applicable securities laws concerning trading in Company securities on the Company’s
behalf.


**Detection and prosecution of insider trading**


The U.S. Securities and Exchange Commission (the “ **SEC** ”), the Financial Industry Regulatory Authority and the Nasdaq Stock
Market use sophisticated electronic surveillance techniques to investigate and detect insider trading, and the SEC and the U.S.
Department of Justice pursue insider trading violations vigorously. Cases involving trading through foreign accounts, trading by
family members and friends and trading involving only a small number of shares have been successfully prosecuted.


**Penalties for violation of insider trading laws and this Policy**


Civil and criminal penalties. As of the effective date of this Policy, potential penalties for insider trading violations under U.S.
federal securities laws include:


      - imprisonment;


      - disgorging any profits made or losses avoided;

      - substantial criminal fines;

      - substantial damages in a private lawsuit;


      - substantial civil fines based on the profit gained or loss avoided;

      - a bar against serving as an officer or director of a public company; and

      - an injunction against future violations.


Page 1


---

Civil and criminal penalties also apply to tipping. The SEC has imposed large penalties in tipping cases even when the
disclosing person did not trade or gain any benefit from another person’s trading.


Controlling person liability. As of the effective date of this Policy, the penalty for “controlling person” liability includes civil
fines, as well as potential criminal fines and imprisonment. The civil penalties can extend personal liability to directors, officers
and managers.


Company disciplinary actions. If the Company has a reasonable basis to conclude that you have failed to comply with this
Policy, you may be subject to disciplinary action by the Company, up to and including dismissal for cause, regardless of whether
or not your failure to comply with this Policy results in a violation of law. It is not necessary for the Company to wait for the filing
or conclusion of any civil or criminal action against an alleged violator before taking disciplinary action. In addition, the Company
may give stop transfer and other instructions to the Company’s transfer agent to enforce compliance with this Policy.


**Insider Trading Compliance Officer**


Please direct any questions, requests or reports as to any of the matters discussed in this Policy to the Company’s Insider
Trading Compliance Officer, who is the Company’s General Counsel, or in the absence of a General Counsel, someone acting in
the General Counsel’s stead (the “ **Insider Trading Compliance Officer** ”). The Insider Trading Compliance Officer is generally
responsible for the administration of this Policy. The Insider Trading Compliance Officer may select others to assist with the
execution of such Officer’s duties, each of whom shall also be referred to as the Insider Trading Compliance Officer for purposes of
this Policy.


**Reporting violations**


It is your responsibility to help enforce this Policy. You should be alert to possible violations and promptly report violations or
suspected violations of this Policy to the Insider Trading Compliance Officer. If your situation requires that your identity be kept
secret, your anonymity will be preserved to the greatest extent reasonably possible. If you wish to remain anonymous, you may
send a letter addressed to the Insider Trading Compliance Officer at Tesla, Inc., 1 Tesla Road, Austin, Texas 78725 or through the
Integrity Line pursuant to the reporting procedures set forth in the Company’s Code of Business Ethics. If you make an
anonymous report, please provide as much detail as possible, including any evidence that you believe may be relevant to the
possible violation.


**Personal responsibility**


The ultimate responsibility for complying with this Policy and applicable laws and regulations rests with you. If securities
transactions ever become the subject of scrutiny, they are likely to be viewed after- the-fact with the benefit of hindsight. As a
result, you should use your best judgment at all times and carefully consider how the transaction may be construed in the bright
light of hindsight. We advise you to seek assistance if you have any questions at all and consult with your personal legal and
financial advisors, as needed. The rules relating to insider trading can be complex, and a violation of insider trading laws can carry
severe consequences.


**PERSONS AND TRANSACTIONS COVERED BY THIS POLICY**


**Persons covered by this Policy**


This Policy applies to all directors, officers, employees and agents (such as consultants and independent contractors) of the
Company. This Policy also applies to your family members who reside with you, anyone else who lives in your household, and
family members who do not live in your household but whose securities transactions are directed by you or are subject to your
influence or control (such as parents or


Page 2


---

children who consult with you before they trade in Company securities), as well as persons that are your economic dependents
and any other individuals or entities whose transactions in securities you

influence, direct or control (including, for example, a venture or other investment fund, if you influence, direct or control
transactions by the fund) (such individuals and entities, “Additional Covered Persons”). You are responsible for making sure that
these Additional Covered Persons comply with this Policy. Accordingly, you should make such Additional Covered Persons aware
of the need to confer with you before they trade in Company Securities, and you should treat all such transaction for the purposes
of this Policy and applicable securities laws concerning trading while in possession of material nonpublic information as if the
transactions were from your own account.


**Types of transactions covered by this Policy**


Except as discussed in the section entitled “ **Limited Exceptions**,” this Policy applies to all transactions involving the
securities of the Company or the securities of other companies as to which you possess material nonpublic information obtained
in the course of your service with the Company. This Policy therefore applies to purchases, sales and other transfers of common
stock, options, warrants, preferred stock, debt securities (such as debentures, bonds and notes) and other securities. This Policy
also applies to any arrangements that affect economic exposure to changes in the prices of these securities. These arrangements
may include, among other things, transactions in derivative securities (such as exchange-traded put or call options), hedging
transactions, short sales and certain decisions with respect to participation in benefit plans. This Policy also applies to any offers
with respect to the transactions discussed above. You should note that there are no exceptions from insider trading laws or this
Policy based on the size of the transaction.


**Responsibilities regarding the nonpublic information of other companies**


This Policy prohibits the unauthorized disclosure or other misuse of any nonpublic information of other companies, such as the
Company’s distributors, vendors, customers, collaborators, suppliers and competitors. This Policy also prohibits insider trading
and tipping based on the material nonpublic information of other companies.


**Applicability of this Policy after your departure**


You are expected to comply with this Policy until such time as you are no longer affiliated with the Company and you no longer
possess any material nonpublic information subject to this Policy. In addition, if you are subject to a trading blackout under this
Policy at the time you cease to be affiliated with the Company, you are expected to abide by the applicable trading restrictions
until at least the end of the relevant blackout period.


**No exceptions based on personal circumstances**


There may be instances where you suffer financial harm or other hardship or are otherwise required to forgo a planned
transaction because of the restrictions imposed by this Policy. Personal financial emergency or other personal circumstances are
not mitigating factors under securities laws and will not excuse a failure to comply with this Policy.


**MATERIAL NONPUBLIC INFORMATION**


**“Material” information**


Information should be regarded as material if there is a substantial likelihood that a reasonable investor would consider it
important in deciding whether to buy, hold or sell securities or would view the information as significantly altering the total mix of
information in the marketplace about the issuer of the


Page 3


---

security. In general, any information that could reasonably be expected to affect the market price of a security is likely to be
material. Either positive or negative information may be material.

It is not possible to define all categories of “material” information. However, some examples of information that could be
regarded as material include information with respect to:


   - Financial results, financial condition, earnings pre-announcements, guidance, projections or forecasts, particularly if
inconsistent with the Company’s guidance or the expectations of the investment community;


   - Restatements of financial results, or material impairments, write-offs or restructurings;


   - Changes in independent auditors, or notification that the Company may no longer rely on an audit report;


   - Business plans or budgets;


   - Creation of significant financial obligations, or any significant default under or acceleration of any financial obligation;


   - Impending bankruptcy or financial liquidity problems;


   - Significant developments involving business relationships, including execution, modification or termination of
significant agreements or orders with customers, suppliers, distributors, manufacturers or other business partners;


   - Product introductions, modifications, defects or recalls or significant pricing changes or other product announcements
of a significant nature;


   - Significant developments in research and development or relating to intellectual property;


   - Significant cybersecurity incidents;


   - Significant legal or regulatory developments, whether actual or threatened;


   - Actual or threatened major litigation or governmental proceedings or investigations, or the actual or potential
settlement of such litigation, proceedings or investigations;


   - Major events involving the Company’s securities, including calls of securities for redemption, adoption of stock
repurchase programs, option repricings, stock splits, changes in dividend policies, public or private securities
offerings, modification to the rights of security holders or notice of delisting;


   - Significant corporate events, such as a pending or proposed merger, joint venture or tender offer, a significant
investment, the acquisition or disposition of a significant business or asset or a change in control of the Company;


   - The existence of a special blackout period; and


   - Major personnel changes, such as changes in senior management or lay-offs, or changes in the board of directors.


If you have any questions as to whether information should be considered “material,” you should consult with the Insider
Trading Compliance Officer. In general, it is advisable to resolve any close questions as to the materiality of any information by
assuming that the information is material.


**“Nonpublic” information**


Information is considered nonpublic if the information has not been broadly disseminated to the public for a sufficient period to
be reflected in the price of the security. Information can be broadly disseminated to the public in a press release, a public filing
with the SEC, a pre-announced public webcast or another broad,


Page 4


---

non-exclusionary form of public communication. You may not attempt to “beat the market” by trading simultaneously with, or
shortly after, the official release of material information. Although there is no fixed period for how long it takes the market to
absorb information, out of prudence a person in possession of material nonpublic information should refrain from any trading
activity for at least one full trading day following its official release. Any questions as to whether information is nonpublic should
be directed to the Insider Trading Compliance Officer.

The term “ **trading day** ” means a day on which national stock exchanges are open for trading. A “ **full** ” trading day has
elapsed when, after the public disclosure, trading in the relevant security has opened and then closed.


**POLICIES REGARDING MATERIAL NONPUBLIC INFORMATION**


**Confidentiality of nonpublic information**


The unauthorized use or disclosure of nonpublic information relating to the Company or other companies is prohibited. All
nonpublic information you acquire in the course of your service with the Company may only be used for legitimate Company
business purposes. In addition, nonpublic information of others should be handled in accordance with the terms of any relevant
nondisclosure agreements, and the use of any such nonpublic information should be limited to the purpose for which it was
disclosed.


You must use all reasonable efforts to safeguard nonpublic information in the Company’s possession. You may not disclose
nonpublic information about the Company or any other company, unless required by law, or unless (i) disclosure is required for
legitimate Company business purposes, (ii) you are authorized to disclose the information and (iii) appropriate steps have been
taken to prevent misuse of that information (for example, entering into an appropriate nondisclosure agreement that restricts the
disclosure and use of the information, if applicable). This restriction also applies to internal communications within the Company
and to communications with agents of the Company. In cases where disclosing nonpublic information to third parties is required,
you should coordinate with the Legal Department.


In addition, all officers, employees and agents of the Company are required to comply with any confidential information or
invention assignment agreement with the Company to which they are subject.


**No trading on material nonpublic information**


Except as discussed in the section entitled “ **Limited Exceptions** ” below, you may not, directly or indirectly through others,
engage in any transaction involving the Company’s securities while aware of material nonpublic information relating to the
Company. It is not an excuse that you did not “use” the information in your transaction.


Similarly, you may not engage in transactions involving the securities of any other company if you are aware of material
nonpublic information about that company (except to the extent the transactions are analogous to those presented in the section
entitled “ **Limited Exceptions** ”). For example, you may be involved in a proposed transaction involving a prospective business
relationship or transaction with another company. If information about that transaction constitutes material nonpublic information
for that other company, you would be prohibited from engaging in transactions involving the securities of that other company (as
well as transactions involving Company securities, if that information is material to the Company). It is important to note that
“materiality” is different for different companies. Information that is not material to the Company may be material to another
company.


**No disclosing material nonpublic information for the benefit of others**


Page 5


---

You may not disclose material nonpublic information concerning the Company or any other company to friends, family
members or any other person or entity not authorized to receive such information where such person or entity may benefit by
trading on the basis of such information. In addition, you may not make recommendations or express opinions on the basis of
material nonpublic information as to trading in the securities of companies to which such information relates. You are prohibited
from engaging in these actions whether or not you derive any profit or personal benefit from doing so. This prohibition against

disclosure of material nonpublic information includes disclosure (even anonymous disclosure) via the internet, blogs, investor
forums or chat rooms where companies and their prospects are discussed.


**Responding to outside inquiries for information**


In the event you receive an inquiry from someone outside of the Company, such as a stock analyst, for information, you should
refer the inquiry to the Company’s Investor Relations Department. The Company is required under Regulation FD (Fair Disclosure)
of the U.S. federal securities laws to avoid the selective disclosure of material nonpublic information. In general, the regulation
provides that when a public company discloses material nonpublic information, it must provide broad, non-exclusionary access to
the information. Violations of this regulation can subject the Company to SEC enforcement actions, which may result in injunctions
and severe monetary penalties. The Company has established procedures for releasing material information in a manner that is
designed to achieve broad public dissemination of the information immediately upon its release in compliance with applicable law.
Please consult the Company’s External Communications Policy for more details.


**TRADING BLACKOUT PERIODS**


To limit the likelihood of trading at times when there is a significant risk of insider trading exposure, the Company has
instituted quarterly trading blackout periods and may institute special trading blackout periods from time to time. In addition, to
comply with applicable legal requirements, the Company may also institute blackout periods that prevent directors and officers
from trading in Company securities at a time when employees are prevented from trading Company securities in the Company’s
401(k) plan


It is important to note that whether or not you are subject to a particular blackout period, you remain subject to the
prohibitions on trading on the basis of material nonpublic information and any other applicable restrictions in this Policy.


**Quarterly blackout periods**


Except as discussed in the section entitled “ **Limited Exceptions** ” below, all directors and executive officers, and employees
and agents identified by the Company must refrain from conducting transactions involving the Company’s securities during
quarterly blackout periods. Even if you are not specifically identified as being subject to quarterly blackout periods, you should
exercise caution when engaging in transactions during quarterly blackout periods because of the heightened risk of insider
trading exposure.


Quarterly blackout periods begin at the end of the first trading day following the fifteenth day of the last month of each fiscal
quarter and end after the first full trading day following public disclosure of the financial results for that fiscal quarter. This period
is a particularly sensitive time for transactions involving the Company’s securities from the perspective of compliance with
applicable securities laws due to the fact that, during this period, individuals may often possess or have access to material
nonpublic information relevant to the expected financial results for the quarter. However, irrespective of whether you actually
possess, have access to, or access such information, any failure to comply with a quarterly blackout period other than in
accordance with the section entitled “ **Limited Exceptions** ” below will be a violation of this Policy.


Page 6


---

From time to time, the Company may identify persons who should be subject to quarterly blackout periods, and shall notify
such persons. Additional Covered Persons associated with such individuals so notified are also subject to the quarterly blackout
periods.

**Special blackout periods**


From time to time, the Company may also prohibit directors, officers, employees and agents from engaging in transactions
involving the Company’s securities when, in the judgment of the Insider Trading Compliance Officer, a trading blackout is
warranted. The Company will generally impose special blackout periods when there are material developments known to the
Company that have not yet been disclosed to the public. For example, the Company may impose a special blackout period in
anticipation of announcing interim earnings guidance or a significant transaction or business development. However, special
blackout periods may be declared for any reason.


The Company will notify those persons subject to a special blackout period. Each person who has been so identified and
notified by the Company (and related Additional Covered Persons) may not engage in any transaction involving the Company’s
securities until instructed otherwise by the Insider Trading Compliance Officer.


**Regulation BTR blackouts**


Directors and executive officers may also be subject to trading blackouts pursuant to Regulation Blackout Trading Restriction,
or Regulation BTR, under U.S. federal securities laws. In general, Regulation BTR prohibits any director or executive officer from
engaging in certain transactions involving Company securities during periods when 401(k) plan participants are prevented from
purchasing, selling or otherwise acquiring or transferring an interest in certain securities held in individual account plans. Any
profits realized from a transaction that violates Regulation BTR are recoverable by the Company, regardless of the intentions of
the director or officer effecting the transaction. In addition, individuals who engage in such transactions are subject to sanction by
the SEC as well as potential criminal liability. The Company has provided, or will provide, separate memoranda and other
appropriate materials to its directors and executive officers regarding compliance with Regulation BTR.


The Company will notify directors and officers if they are subject to a blackout trading restriction under Regulation BTR. Failure
to comply with an applicable trading blackout in accordance with Regulation BTR is a violation of law and this Policy.


**No “safe harbors”**


There are no unconditional “safe harbors” for trades made at particular times, and all persons subject to this Policy should
exercise good judgment at all times. Even when a quarterly blackout period is not in effect, you may be prohibited from engaging
in transactions involving the Company’s securities because you possess material nonpublic information, are subject to a special
blackout period or are otherwise restricted under this Policy.


**PRE-CLEARANCE OF TRADES**


Except as discussed in the section entitled “ **Limited Exceptions** ” below, directors and executive officers should refrain from
engaging in any transaction involving the Company’s securities without first obtaining pre **-** clearance of the transaction from the
Insider Trading Compliance Officer. In addition, the Company has determined that certain other employees and agents of the
Company that may have regular or special access to material nonpublic information should refrain from engaging in any
transaction involving the Company’s securities without first obtaining pre **-** clearance of the transaction from the Insider Trading
Compliance Officer. The Insider Trading Compliance Officer may not engage in a transaction involving the


Page 7


---

Company’s securities unless the Company’s Chief Executive Officer, Chief Financial Officer, Chief Accounting Officer or their
delegate, or if there are more than one Insider Trading Compliance Officer, another such Insider Trading Compliance Officer, has
pre-cleared the transaction. Individuals

subject to pre **-** clearance requirements are listed on **Schedule A** . From time to time, the Company may identify other persons who
should be subject to the pre **-** clearance requirements set forth above, and the Insider Trading Compliance Officer may update and
revise **Schedule A** as appropriate.


These pre-clearance procedures are intended to decrease insider trading risks associated with transactions by individuals with
regular or special access to material nonpublic information. In addition, requiring pre-clearance of transactions by directors and
officers facilitates compliance with Rule 144 resale restrictions under the Securities Act of 1933, as amended and the liability and
reporting provisions of Section 16 under the Securities Exchange Act of 1934, as amended (the “ **Exchange Act** ”) and Regulation
BTR. Pre-clearance of a trade, however, is not a defense to a claim of insider trading and does not excuse you from otherwise
complying with insider trading laws or this Policy. Further, pre-clearance of a transaction does not constitute an affirmation by the
Company or the Insider Trading Compliance Officer that you are not in possession of material nonpublic information.


The Insider Trading Compliance Officer is under no obligation to approve a transaction submitted for pre-clearance, and may
determine not to permit the transaction.


**ADDITIONAL RESTRICTIONS AND GUIDANCE**


This section addresses certain types of transactions that may expose you and the Company to significant risks. You should
understand that, even though a transaction may not be expressly prohibited by this section, you are responsible for ensuring that
the transaction otherwise complies with other provisions in this Policy that may apply to the transaction, such as the general
prohibition against insider trading as well as pre- clearance procedures and blackout periods, to the extent applicable.


**Short sales**


Short sales (i.e., the sale of a security that must be borrowed to make delivery) and “selling short against the box” (i.e., a sale
with a delayed delivery) with respect to Company securities are prohibited under this Policy. Short sales may signal to the market
possible bad news about the Company or a general lack of confidence in the Company’s prospects, and an expectation that the
value of the Company’s securities will decline. In addition, short sales are effectively a bet against the Company’s success and
may reduce the seller’s incentive to improve the Company’s performance. Short sales may also create a suspicion that the seller
is engaged in insider trading.


**Derivative securities and hedging transactions**


You are prohibited from engaging in transactions in publicly-traded options, such as puts and calls, and other derivative
securities with respect to the Company’s securities. This prohibition extends to any hedging or similar transaction designed to
decrease the risks associated with holding Company securities. Stock options, stock appreciation rights, other securities issued
pursuant to Company benefit plans or other compensatory arrangements with the Company, and broad-based index options,
futures or baskets are not subject to this prohibition.


Transactions in derivative securities may reflect a short-term and speculative interest in the Company’s securities and may
create the appearance of impropriety, even where a transaction does not involve trading on inside information. Trading in
derivatives may also focus attention on short-term performance at the expense of the Company’s long-term objectives. In
addition, the application of securities laws to derivatives


Page 8


---

transactions can be complex, and persons engaging in derivatives transactions run an increased risk of violating securities laws.

**Using Company securities as collateral for loans**


You should exercise caution in pledging Company securities as collateral for loans. If you default on the loan, the lender may
sell the pledged securities as collateral in a foreclosure sale. The sale, even though not initiated at your request, is still considered
a sale for your benefit and, if made at a time when you are aware of material nonpublic information or otherwise are not
permitted to trade in Company securities, may result in inadvertent insider trading violations, Section 16 and Regulation BTR
violations (for officers and directors), violations of this Policy and unfavorable publicity for you and the Company.


**Holding Company securities in margin accounts**


You may not hold Company securities in margin accounts. Under typical margin arrangements, if you fail to meet a margin call,
the broker may be entitled to sell securities held in the margin account without your consent. The sale, even though not initiated
at your request, is still considered a sale for your benefit and, if made at a time when you are aware of material nonpublic
information or are otherwise not permitted to trade, may result in inadvertent insider trading violations, Section 16 violations (for
officers and directors), violations of this Policy and unfavorable publicity for you and the Company.


**Placing open orders with brokers**


Except in accordance with an approved trading plan (as discussed below), you should exercise caution when placing open
orders, such as limit orders or stop orders, with brokers, particularly where the order is likely to remain outstanding for an
extended period of time. Open orders may result in the execution of a trade at a time when you are aware of material nonpublic
information or otherwise are not permitted to trade in Company securities, which may result in inadvertent insider trading
violations, Section 16 and Regulation BTR violations (for officers and directors), violations of this Policy and unfavorable publicity
for you and the Company. If you are subject to any blackout periods or pre-clearance requirements, you should inform any broker
with whom you place any open order at the time it is placed of your obligation to comply with such blackout periods and/or preclearance requirements.


**LIMITED EXCEPTIONS**


The following are certain limited exceptions to the restrictions imposed by the Company under this Policy. Please be aware
that even if a transaction is subject to an exception to this Policy, you will need to separately assess whether the transaction
complies with applicable law. For example, even if a transaction is indicated as exempt from this Policy, you may need to comply
with the “short-swing” trading restrictions under Section 16 of the Exchange Act, to the extent applicable. You are responsible for
complying with applicable law at all times.


**Transactions pursuant to a trading plan that complies with SEC rules**


The SEC has enacted rules that provide an affirmative defense against alleged violations of U.S. federal insider trading laws for
transactions pursuant to trading plans that meet certain requirements. In general, these rules, as set forth in Rule 10b5-1 under
the Exchange Act, provide for an affirmative defense if you enter into a contract, provide instructions or adopt a written plan for
trading securities when you are not aware of material nonpublic information. The contract, instructions or plan must be made or
entered into in good faith and not as a part of a plan or scheme to evade the insider trading laws and must (i) specify the amount,
price and date of the transaction, (ii) specify an objective method for determining the amount, price and date of the transaction
and/or (iii) place any subsequent discretion for determining the amount, price and


Page 9


---

date of the transaction in another person who is not, at the time of the transaction, aware of material nonpublic information.

Transactions made pursuant to a written trading plan that (i) complies with the affirmative defense set forth in Rule 10b5-1
and (ii) is approved by the Insider Trading Compliance Officer, are not subject to the restrictions in this Policy against trades made
while aware of material nonpublic information or to the pre- clearance procedures or blackout periods established under this
Policy. In approving a trading plan, the Insider Trading Compliance Officer may, in furtherance of the objectives expressed in this
Policy, impose criteria in addition to those set forth in Rule 10b5-1. Therefore, you must confer with the Insider Trading
Compliance Officer prior to entering into any trading plan. No transactions may occur under such contract, instructions or plans
until the expiration of the applicable cooling-off period (minimum of 90 days for directors and officers and 30 days for all other
employees and agents).


The SEC rules regarding trading plans are complex and must be complied with completely to be effective. The description
provided above is only a summary, and the Company strongly advises that you consult with your personal legal advisor if you
intend to adopt a trading plan. While trading plans are subject to review and approval by the Company, the individual adopting
the trading plan is ultimately responsible for compliance with Rule 10b5-1 and ensuring that the trading plan complies with this
Policy.


Trading plans must be filed with the Insider Trading Compliance Officer. The Company may publicly disclose information
regarding trading plans that you may enter into.


**Receipt and vesting of stock options, restricted stock units, restricted stock and stock appreciation rights**


The trading restrictions under this Policy do not apply to the grant or award to you of stock options, restricted stock units,
restricted stock or stock appreciation rights by the Company. The trading restrictions under this Policy also do not apply to the
vesting, cancellation or forfeiture of stock options, restricted stock units, restricted stock or stock appreciation rights in
accordance with applicable plans and agreements. However, the trading restrictions do apply to any subsequent sales of any such
securities.


**Exercise of stock options for cash**


The trading restrictions under this Policy do not apply to the exercise of stock options for cash under the Company’s stock
option plans. Likewise, the trading restrictions under this Policy do not apply to the exercise of stock options in a stock-for-stock
exercise with the Company or an election to have the Company withhold securities to cover tax obligations in connection with an
option exercise. However, the trading restrictions under this Policy do apply to (i) the sale of any securities issued upon the
exercise of a stock option, (ii) a cashless exercise of a stock option through a broker, since this involves selling a portion of the
underlying shares to cover the costs of exercise, and (iii) any other market sale for the purpose of generating the cash needed to
pay the exercise price of an option.


**Purchases from the employee stock purchase plan**


The trading restrictions in this Policy do not apply to elections with respect to participation in the Company’s employee stock
purchase plan or to purchases of securities under the plan. However, the trading restrictions do apply to any subsequent sales of
any such securities.


**Certain 401(k) plan transactions**


The trading restrictions in this Policy do not apply to purchases of Company stock in the 401(k) plan resulting from periodic
contributions to the plan based on your payroll contribution election. The trading restrictions do apply, however, to elections you
make under the 401(k) plan to (i) increase or decrease the


Page 10


---

percentage of your contributions that will be allocated to a Company stock fund, (ii) move balances into or out of a Company
stock fund, (iii) borrow money against your 401(k) plan account if the loan will result in liquidation of some or all of your Company
stock fund balance, and (iv) pre-pay a plan loan if the pre- payment will result in the allocation of loan proceeds to a Company
stock fund.


**Stock splits, stock dividends and similar transactions**


The trading restrictions under this Policy do not apply to a change in the number of securities held as a result of a stock split or
stock dividend applying equally to all securities of a class, or similar transactions.


**Inheritance and bona fide gifts**


The trading restrictions under this Policy do not apply to transfers by will or the laws of descent and distribution. In addition,
bona fide gifts involving Company securities are not transactions subject to this policy, unless you have reason to believe that the
recipient intends to sell the Company securities while you are aware of material nonpublic information.


**Change in form of ownership**


Transactions that involve merely a change in the form in which you own securities are not subject to the trading restrictions
under this Policy. For example, you may transfer shares to an inter vivos trust of which you are the sole beneficiary during your
lifetime.


**Other exceptions**


Any other exception from this Policy must be approved by the Insider Trading Compliance Officer, in consultation with the
Board of Directors or an independent committee of the Board of Directors.


**COMPLIANCE WITH SECTION 16 OF THE SECURITIES EXCHANGE ACT**


**Obligations under Section 16**


Section 16 of the Exchange Act, and the related rules and regulations, set forth (i) reporting obligations,
(ii) limitations on “short-swing” transactions and (iii) limitations on short sales and other transactions applicable to directors,
officers, large shareholders and certain other persons.


The Board of Directors of the Company has determined that the persons specified as Section 16 insiders on **Schedule A** are
required to comply with Section 16 of the Exchange Act, and the related rules and regulations, because of their positions with the
Company. The Insider Trading Compliance Officer may amend **Schedule A** from time to time as appropriate to reflect the
election of new officers or directors, any change in the responsibilities of officers or other employees and any promotions,
demotions, resignations or departures.


**Schedule A** may not necessarily contain an exhaustive list of persons subject to Section 16 requirements at any given time.
Even if you are not listed on **Schedule A**, you may be subject to Section 16 reporting obligations because of your shareholdings,
for example.


**Notification requirements to facilitate Section 16 reporting**


To facilitate timely reporting of transactions pursuant to Section 16 requirements, each person subject to Section 16 reporting
requirements must provide, or must ensure that such person’s broker provides, the Company with detailed information (e.g.,
trade date, number of shares, exact price, etc.) regarding such person’s transactions involving the Company’s securities,
including gifts, transfers, pledges and


Page 11


---

transactions pursuant to a trading plan, both prior to (to confirm compliance with pre-clearance procedures, if applicable) and
promptly following execution.


**Personal responsibility**


The obligation to file Section 16 reports, and to otherwise comply with Section 16, is personal. The Company is not
responsible for the failure to comply with Section 16 requirements.


**ADDITIONAL INFORMATION**


**Availability of Policy**


This Policy will be made available to all directors, officers, employees and agents of the Company when they commence
service with the Company. Each director, officer, employee and agent of the Company is required, if requested, to acknowledge
that he or she understands, and agrees to comply with, this Policy.


**Amendments**


We are committed to continuously reviewing and updating our policies and procedures. The Company therefore reserves the
right to amend, alter or terminate this Policy at any time and for any reason, subject to applicable law. A current copy of the
Company’s policies regarding insider trading may be obtained by contacting the Insider Trading Compliance Officer.


**Ancillary Documents**


Attached as **Schedule B** are forms of various ancillary documents that may be used from time to time in connection with the
matters discussed in this Policy. The Insider Trading Compliance Officer may amend, alter, substitute or terminate any of these
ancillary documents at any time and for any reason, subject to applicable law.


                                           -  * *


Nothing in this Insider Trading Policy creates or implies an employment contract or term of employment.


The policies in this Insider Trading Policy do not constitute a complete list of Company policies or a complete list of the types
of conduct that can result in discipline, up to and including discharge.


Page 12


**Exhibit 21.1**


**SUBSIDIARIES OF TESLA, INC.**


---

Name of Subsidiary Jurisdiction of
Incorporation or Organization


Alabama Service LLC Delaware


All EV Holdings, LLC Delaware


Allegheny Solar 1, LLC Delaware


Allegheny Solar Manager 1, LLC Delaware


Alset Transport GmbH Germany


Alset Warehouse GmbH Germany


Ancon Holdings II, LLC Delaware


Ancon Holdings III, LLC Delaware


Ancon Holdings, LLC Delaware


Ancon Solar Corporation Delaware


Ancon Solar I, LLC Delaware


Ancon Solar II Lessee Manager, LLC Delaware


Ancon Solar II Lessee, LLC Delaware


Ancon Solar II Lessor, LLC Delaware


Ancon Solar III Lessee Manager, LLC Delaware


Ancon Solar III Lessee, LLC Delaware


Ancon Solar III Lessor, LLC Delaware


Ancon Solar Managing Member I, LLC Delaware


Arpad Solar Borrower, LLC Delaware


Arpad Solar I, LLC Delaware


Arpad Solar Manager I, LLC Delaware


AU Solar 1, LLC Delaware


AU Solar 2, LLC Delaware


Banyan SolarCity Manager 2010, LLC Delaware


Banyan SolarCity Owner 2010, LLC Delaware


Barbacoa Battery Storage, LLC Texas


Basking Solar Manager II, LLC Delaware


Beatrix Solar I, LLC Delaware


Bernese Solar Manager I, LLC Delaware


Blue Skies Solar I, LLC Delaware


Blue Skies Solar II, LLC Delaware


BT Connolly Storage, LLC Texas


Caballero Solar Managing Member I, LLC Delaware


Caballero Solar Managing Member II, LLC Delaware


Caballero Solar Managing Member III, LLC Delaware


Castello Solar I, LLC Delaware


Castello Solar II, LLC Delaware


Castello Solar III, LLC Delaware


Chaparral SREC Borrower, LLC Delaware


Chaparral SREC Holdings, LLC Delaware


Chestnut Storage, LLC North Carolina


Chompie Solar I, LLC Delaware


Chompie Solar II, LLC Delaware


Chompie Solar Manager I, LLC Delaware


Chompie Solar Manager II, LLC Delaware


---

Colorado River Project, LLC Delaware


Community Solar Partners, LLC Delaware


Compass Automation Incorporated Illinois


Connecticut Auto Repair and Service LLC Delaware


Corpus Battery Storage, LLC Texas


Dom Solar General Partner I, LLC Delaware


Dom Solar Lessor I, LP Cayman Islands


Domino Solar Ltd. Cayman Islands


Dom Solar Limited Partner I, LLC Delaware


El Rey EV, LLC Delaware


Falconer Solar Manager I, LLC Delaware


Firehorn Solar I, LLC Cayman Islands


Firehorn Solar Manager I, LLC Delaware


FocalPoint Solar Borrower, LLC Delaware


FocalPoint Solar I, LLC Delaware


FocalPoint Solar Manager I, LLC Delaware


Fontane Solar I, LLC Delaware


Fotovoltaica GI 4, S. de R.L. de C.V. Mexico


Fotovoltaica GI 5, S. de R.L. de C.V. Mexico


FP System Owner, LLC Delaware


Giga Insurance Texas, Inc. Texas


Giga Texas Energy, LLC Delaware


Tesla Automation (Shanghai) Co. Ltd. China


Grohmann USA, Inc. Delaware


Guilder Solar, LLC Delaware


Hamilton Solar, LLC Delaware


Harborfields LLC Delaware


Harpoon Solar I, LLC Delaware


Harpoon Solar Manager I, LLC Delaware


Haymarket Holdings, LLC Delaware


Haymarket Manager 1, LLC Delaware


Haymarket Solar 1, LLC Delaware


Hibar Systems Europe GmbH Germany


Hive Battery Inc. Delaware


Ikehu Manager I, LLC Delaware


IL Buono Solar I, LLC Delaware


Iliosson, S.A. de C.V. Mexico


Industrial Maintenance Technologies, Inc. California


Kansas Repair LLC Delaware


Klamath Falls Solar 1, LLC Delaware


Knight Solar Managing Member I, LLC Delaware


Knight Solar Managing Member II, LLC Delaware


Knight Solar Managing Member III, LLC Delaware


Landlord 2008-A, LLC Delaware


Lincoln Auto Repair and Service LLC Delaware


Louis Solar II, LLC Delaware


Louis Solar III, LLC Delaware


Louis Solar Manager II, LLC Delaware


Louis Solar Manager III, LLC Delaware


Louis Solar Master Tenant I, LLC Delaware


---

Louis Solar MT Manager I, LLC Delaware


Louis Solar Owner I, LLC Delaware


Louis Solar Owner Manager I, LLC Delaware


Master Tenant 2008-A, LLC Delaware


Matterhorn Solar I, LLC Delaware


Maxwell Technologies, Inc. Delaware


Megalodon Solar, LLC Delaware


Monte Rosa Solar I, LLC Delaware


Mound Solar Manager V, LLC Delaware


Mound Solar Manager VI, LLC Delaware


Mound Solar Manager X, LLC Delaware


Mound Solar Manager XI, LLC Delaware


Mound Solar Manager XII, LLC Delaware


Mound Solar Master Tenant IX, LLC Delaware


Mound Solar Master Tenant V, LLC California


Mound Solar Master Tenant VI, LLC Delaware


Mound Solar Master Tenant VII, LLC Delaware


Mound Solar Master Tenant VIII, LLC Delaware


Mound Solar MT Manager IX, LLC Delaware


Mound Solar MT Manager VII, LLC Delaware


Mound Solar MT Manager VIII, LLC Delaware


Mound Solar Owner IX, LLC Delaware


Mound Solar Owner Manager IX, LLC Delaware


Mound Solar Owner Manager VII, LLC Delaware


Mound Solar Owner Manager VIII, LLC Delaware


Mound Solar Owner V, LLC California


Mound Solar Owner VI, LLC Delaware


Mound Solar Owner VII, LLC Delaware


Mound Solar Owner VIII, LLC Delaware


Mound Solar Partnership X, LLC Delaware


Mound Solar Partnership XI, LLC Delaware


Mound Solar Partnership XII, LLC Delaware


MS SolarCity 2008, LLC Delaware


MS SolarCity Commercial 2008, LLC Delaware


MS SolarCity Residential 2008, LLC Delaware


New Mexico Sales and Vehicle Service LLC Delaware


NBA SolarCity AFB, LLC California


NBA SolarCity Commercial I, LLC California


NBA SolarCity Solar Phoenix, LLC California


Northern Nevada Research Co., LLC Nevada


Oranje Solar I, LLC Delaware


Oranje Solar Manager I, LLC Delaware


Palmetto Auto Repair and Service LLC Delaware


Paramount Energy Fund I Lessee, LLC Delaware


Paramount Energy Fund I Lessor, LLC Delaware


PEF I MM, LLC Delaware


Perbix Machine Company, Inc. Minnesota


Presidio Solar I, LLC Delaware


Presidio Solar II, LLC Delaware


Presidio Solar III, LLC Delaware


---

Pukana La Solar I, LLC Delaware


R9 Solar 1, LLC Delaware


Roadster Automobile Sales and Service (Beijing) Co., Ltd. China


Roadster Finland Oy Finland


SA VPP Holding Trust Australia


SA VPP Project Trust Australia


Sequoia Pacific Holdings, LLC Delaware


Sequoia Pacific Manager I, LLC Delaware


Sequoia Pacific Solar I, LLC Delaware


Sequoia SolarCity Owner I, LLC Delaware


Sierra Solar Power (Hong Kong) Limited Hong Kong


SiiLion, Inc. Delaware


Silevo, LLC Delaware


Smith II Battery Storage, LLC Texas


Solar Aquarium Holdings, LLC Delaware


Solar Energy of America 1, LLC Delaware


Solar Energy of America Manager 1, LLC Delaware


Solar Explorer, LLC Delaware


Solar Gezellig Holdings, LLC Delaware


Solar House I, LLC Delaware


Solar House II, LLC Delaware


Solar House III, LLC Delaware


Solar House IV, LLC Delaware


Solar Integrated Fund I, LLC Delaware


Solar Integrated Fund II, LLC Delaware


Solar Integrated Fund III, LLC Delaware


Solar Integrated Fund IV-A, LLC Delaware


Solar Integrated Fund V, LLC Delaware


Solar Integrated Fund VI, LLC Delaware


Solar Integrated Manager I, LLC Delaware


Solar Integrated Manager II, LLC Delaware


Solar Integrated Manager III, LLC Delaware


Solar Integrated Manager IV-A, LLC Delaware


Solar Integrated Manager V, LLC Delaware


Solar Integrated Manager VI, LLC Delaware


Solar Services Company, LLC Delaware


Solar Ulysses Manager I, LLC Delaware


Solar Ulysses Manager II, LLC Delaware


Solar Voyager, LLC Delaware


Solar Warehouse Manager I, LLC Delaware


Solar Warehouse Manager II, LLC Delaware


Solar Warehouse Manager III, LLC Delaware


Solar Warehouse Manager IV, LLC Delaware


SolarCity Alpine Holdings, LLC Delaware


SolarCity Amphitheatre Holdings, LLC Delaware


SolarCity Arbor Holdings, LLC Delaware


SolarCity Arches Holdings, LLC Delaware


SolarCity AU Holdings, LLC Delaware


SolarCity Cruyff Holdings, LLC Delaware


SolarCity Electrical, LLC Delaware


---

SolarCity Electrical New York Corporation Delaware


SolarCity Finance Company, LLC Delaware


SolarCity Finance Holdings, LLC Delaware


SolarCity Foxborough Holdings, LLC Delaware


SolarCity FTE Series 1, LLC Delaware


SolarCity FTE Series 2, LLC Delaware


SolarCity Fund Holdings, LLC Delaware


SolarCity Grand Canyon Holdings, LLC Delaware


SolarCity Holdings 2008, LLC Delaware


SolarCity International, Inc. Delaware


SolarCity Leviathan Holdings, LLC Delaware


SolarCity LMC Series I, LLC Delaware


SolarCity LMC Series II, LLC Delaware


SolarCity LMC Series III, LLC Delaware


SolarCity LMC Series IV, LLC Delaware


SolarCity LMC Series V, LLC Delaware


SolarCity Mid-Atlantic Holdings, LLC Delaware


SolarCity Nitro Holdings, LLC Delaware


SolarCity Orange Holdings, LLC Delaware


SolarCity Series Holdings I, LLC Delaware


SolarCity Series Holdings II, LLC Delaware


SolarCity Series Holdings IV, LLC Delaware


SolarCity Steep Holdings, LLC Delaware


SolarCity Ulu Holdings, LLC Delaware


SolarCity Village Holdings, LLC Delaware


SolarRock, LLC Delaware


SolarStrong, LLC Delaware


Sparrowhawk Solar I, LLC Delaware


SREC Holdings, LLC Delaware


Swanson Battery Storage, LLC Texas


TALT Holdings, LLC Delaware


TALT TBM Holdings, LLC Delaware


TBM Partnership II, LLC Delaware


TEO Engineering, Inc. California


TES 2017-1, LLC Delaware


TES Holdings 2017-1, LLC Delaware


Tesla 2014 Warehouse SPV LLC Delaware


Tesla Auto Lease Trust 2021-A Delaware


Tesla Auto Lease Trust 2021-B Delaware


Tesla Auto Lease Trust 2022-A Delaware


Tesla Auto Lease Trust 2023-A Delaware


Tesla Auto Lease Trust 2023-B Delaware


Tesla Auto Lease Trust 2024-A Delaware


Tesla Auto Lease Trust 2024-B Delaware


Tesla Electric Vehicle Trust 2023-1 Delaware


Tesla Autobidder International B.V. Netherlands


Tesla Automation GmbH Germany


Tesla Automobile Information Service (Dalian) Co., Ltd. China


Tesla Automobile Management and Service (Haikou) Co., Ltd. China


Tesla Automobile Sales and Service (Beijing) Co., Ltd. China


---

Tesla Automobile Sales and Service (Changchun) Co., Ltd. China


Tesla Automobile Sales and Service (Changsha) Co., Ltd. China


Tesla Automobile Sales and Service (Chengdu) Co., Ltd. China


Tesla Automobile Sales and Service (Chongqing) Co., Ltd. China


Tesla Automobile Sales and Service (Dalian) Co., Ltd. China


Tesla Automobile Sales and Service (Fuzhou) Co., Ltd. China


Tesla Automobile Sales and Service (Guangzhou) Co., Ltd. China


Tesla Automobile Sales and Service (Guangzhou Panyu District) Co., Ltd. China


Tesla Automobile Sales and Service (Guiyang) Co., Ltd. China


Tesla Automobile Sales and Service (Haerbin) Co., Ltd. China


Tesla Automobile Sales and Service (Hangzhou) Co., Ltd. China


Tesla Automobile Sales and Service (Hefei) Co., Ltd. China


Tesla Automobile Sales and Service (Hohhot) Co., Ltd. China


Tesla Automobile Sales and Service (Jinan) Co., Ltd. China


Tesla Automobile Sales and Service (Kunming) Co., Ltd. China


Tesla Automobile Sales and Service (Lanzhou) Co., Ltd. China


Tesla Automobile Sales and Service (Nanchang) Co., Ltd. China


Tesla Automobile Sales and Service (Nanjing) Co., Ltd. China


Tesla Automobile Sales and Service (Nanning) Co., Ltd. China


Tesla Automobile Sales and Service (Ningbo) Co., Ltd. China


Tesla Automobile Sales and Service (Ningbo) Co., Ltd. China


Tesla Automobile Sales and Service (Qingdao) Co., Ltd. China


Tesla Automobile Sales and Service (Shanghai) Co., Ltd. China


Tesla Automobile Sales and Service (Shenyang) Co., Ltd. China


Tesla Automobile Sales and Service (Shenzhen) Co., Ltd. China


Tesla Automobile Sales and Service (Shijiazhuang) Co., Ltd. China


Tesla Automobile Sales and Service (Suzhou) Co. Ltd. China


Tesla Automobile Sales and Service (Taiyuan) Co., Ltd. China


Tesla Automobile Sales and Service (Tianjin) Co. Ltd. China


Tesla Automobile Sales and Service (Urumqi) Co. Ltd. China


Tesla Automobile Sales and Service (Wenzhou) Co., Ltd. China


Tesla Automobile Sales and Service (Wuhan) Co., Ltd. China


Tesla Automobile Sales and Service (Wuxi) Co., Ltd. China


Tesla Automobile Sales and Service (Xi'an) Co., Ltd. China


Tesla Automobile Sales and Service (Xiamen) Co., Ltd. China


Tesla Automobile Sales and Service (Xining) Co., Ltd. China


Tesla Automobile Sales and Service (Yinchuan) Co., Ltd. China


Tesla Automobile Sales and Service (Zhengzhou) Co. Ltd. China


Tesla Automobiles Sales and Service Mexico, S. de R.L. de C.V. Mexico


Tesla (Beijing) New Energy R&D Co., Ltd. China


Tesla Belgium BV Belgium


Tesla Canada Finance ULC Canada


Tesla Canada Lease Finance GP ULC Canada


Tesla Canada Lease Finance LP Canada


Tesla Charging, LLC Delaware


Tesla Chile SpA Chile


Tesla Construction Inc. Texas


Tesla Construction (Shanghai) Co., Ltd. China


Tesla Czech Republic s.r.o. Czech Republic


Tesla Energia Macau Limitada Macau


---

Tesla Engineering Germany GmbH Germany


Tesla Energy d.o.o. Slovenia


Tesla Energy Management LLC Delaware


Tesla Energy Operations, Inc. Delaware


Tesla Energy Ventures Australia Pty Ltd Australia


Tesla Energy Ventures France S.à r.l. France


Tesla Energy Ventures Limited United Kingdom


Tesla Energy Ventures Holdings B.V. Netherlands


Tesla Finance LLC Delaware


Tesla Financial Leasing (China) Co., Ltd. China


Tesla Financial Services GmbH Germany


Tesla Financial Services Holdings B.V. Netherlands


Tesla Financial Services Limited United Kingdom


Tesla Fleet Operations LLC Texas


Tesla France S.à r.l. France


Tesla Germany GmbH Germany


Tesla General Insurance, Inc. Arizona


Tesla Greece Single Member P.C. Greece


Tesla Gulf Limited Company Saudi Arabia


Tesla Hrvatska d.o.o. Croatia


Tesla Hungary Kft. Hungary


Tesla India Motors and Energy Private Limited India


Tesla Insurance Brokers (China) Co., Ltd. China


Tesla Insurance Holdings, LLC Delaware


Tesla Insurance, Inc. Delaware


Tesla Insurance Company California


Tesla Insurance Company of Hawaii, LLC Hawaii


Tesla Insurance Services, Inc. California


Tesla Insurance Services of Texas, Inc. Texas


Tesla International B.V. Netherlands


Tesla Investments LLC Delaware


Tesla Italy S.r.l. Italy


Tesla Jordan Car Trading LLC Jordan


Tesla Korea Limited Republic of Korea


Tesla Lease Trust Delaware


Tesla Lithuania UAB Lithuania


Tesla LLC Delaware


Tesla Manufacturing Brandenburg SE Germany


Tesla Manufacturing Mexico, S. de R.L. de C.V. Mexico


Tesla Manufacturing Mexico Holding, S. de R.L. de C.V. Mexico


Tesla Michigan, Inc. Michigan


Tesla Mississippi LLC Delaware


Tesla Motors Australia, Pty Ltd Australia


Tesla Motors Austria GmbH Austria


Tesla Motors (Beijing) Co., Ltd. China


Tesla Motors Canada ULC Canada


Tesla Motors Colombia S.A.S Colombia


Tesla Motors Holding B.V. Netherlands


Tesla Motors Denmark ApS Denmark


Tesla Motors FL, Inc. Florida


---

Tesla Motors HK Limited Hong Kong


Tesla Motors Iceland ehf. Iceland


Tesla Motors Ireland Limited Ireland


Tesla Motors Israel Ltd. Israel


Tesla Motors Japan GK Japan


Tesla Motors Limited United Kingdom


Tesla Motors Luxembourg S.à r.l. Luxembourg


Tesla Motors MA, Inc. Massachusetts


Tesla Motors Netherlands B.V. Netherlands


Tesla Motors New York LLC New York


Tesla Motors NL LLC Delaware


Tesla Motors NV, Inc. Nevada


Tesla Motors PA, Inc. Pennsylvania


Tesla Motors Philippines Inc. Philippines


Tesla Motors Romania S.R.L. Romania


Tesla Motors Sales and Service LLC Turkey


Tesla Motors Singapore Holdings Pte. Ltd. Singapore


Tesla Motors Singapore Private Limited Singapore


Tesla Motors Stichting Netherlands


Tesla Motors Taiwan Limited Taiwan


Tesla Motors TN, Inc. Tennessee


Tesla Motors TX, Inc. Texas


Tesla Motors UT, Inc. Utah


Tesla Nambe LLC Delaware


Tesla New Zealand ULC New Zealand


Tesla Norway AS Norway


Tesla Poland sp. z o.o. Poland


Tesla Property &Casualty, Inc. California


Tesla Portugal, Sociedade Unipessoal LDA Portugal


Tesla Puerto Rico LLC Puerto Rico


Tesla Qatar LLC Qatar


Tesla Rental LLC Delaware


Tesla Sales, Inc. Delaware


Tesla Sdn. Bhd. Malaysia


Tesla Shanghai Co., Ltd China


Tesla (Shanghai) New Energy Co., LTD. China


Tesla Spain, S.L. Unipersonal Spain


Tesla Solar Systems, LLC Delaware


Tesla Sustainable Energy Trust 2024-1 Delaware


Tesla Switzerland GmbH Switzerland


Tesla (Thailand) Ltd. Thailand


Tesla TH1 LLC Delaware


Tesla TH2 LLC Delaware


Telsa Toronto Automation ULC Canada


Tesla Toronto International Holdings ULC Canada


Tesla Transport B.V. Netherlands


Tesla US Property Holdings, LLC Texas


Tesla Wholesale Energy Holdings, LLC Delaware


The Big Green Solar I, LLC Delaware


The Big Green Solar Manager I, LLC Delaware


---

Three Rivers Solar 1, LLC Delaware


Three Rivers Solar 2, LLC Delaware


Three Rivers Solar 3, LLC Delaware


Three Rivers Solar Manager 1, LLC Delaware


Three Rivers Solar Manager 2, LLC Delaware


Three Rivers Solar Manager 3, LLC Delaware


TM International C.V. Netherlands


TM Sweden AB Sweden


TSET Holdings, LLC Delaware


USB SolarCity Manager IV, LLC Delaware


USB SolarCity Owner IV, LLC California


Visigoth Solar 1, LLC Delaware


Visigoth Solar Holdings, LLC Delaware


Visigoth Solar Managing Member 1, LLC Delaware


VPP Project 1 (SA) Pty Ltd. Australia


Weisshorn Solar I, LLC Cayman Islands


Weisshorn Solar Manager I, LLC Delaware


Zep Solar LLC California


CONSENT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM


**Exhibit 23.1**


We hereby consent to the incorporation by reference in the Registration Statements on Form S-8 (Nos. 333-232079, 333-223169, 333-216376, 333209696, 333-198002, 333-187113, 333-183033, and 333-167874) of Tesla, Inc. of our report dated January 29, 2025 relating to the financial statements
and the effectiveness of internal control over financial reporting, which appears in this Form 10-K.


/s/ PricewaterhouseCoopers LLP


San Jose, California
January 29, 2025


**Exhibit 31.1**


**CERTIFICATIONS**


I, Elon Musk, certify that:


1. I have reviewed this Annual Report on Form 10-K of Tesla, Inc.;


2. Based on my knowledge, this report does not contain any untrue statement of a material fact or omit to state a material fact necessary to make the
statements made, in light of the circumstances under which such statements were made, not misleading with respect to the period covered by this
report;


3. Based on my knowledge, the financial statements, and other financial information included in this report, fairly present in all material respects the
financial condition, results of operations and cash flows of the registrant as of, and for, the periods presented in this report;


4. The registrant’s other certifying officer and I are responsible for establishing and maintaining disclosure controls and procedures (as defined in
Exchange Act Rules 13a-15(e) and 15d-15(e)) and internal control over financial reporting (as defined in Exchange Act Rules 13a-15(f) and 15d15(f)) for the registrant and have:


---

(a) Designed such disclosure controls and procedures, or caused such disclosure controls and procedures to be designed under our
supervision, to ensure that material information relating to the registrant, including its consolidated subsidiaries, is made known to us
by others within those entities, particularly during the period in which this report is being prepared;


(b) Designed such internal control over financial reporting, or caused such internal control over financial reporting to be designed under
our supervision, to provide reasonable assurance regarding the reliability of financial reporting and the preparation of financial
statements for external purposes in accordance with generally accepted accounting principles;


(c) Evaluated the effectiveness of the registrant’s disclosure controls and procedures and presented in this report our conclusions about
the effectiveness of the disclosure controls and procedures, as of the end of the period covered by this report based on such evaluation;
and


(d) Disclosed in this report any change in the registrant’s internal control over financial reporting that occurred during the registrant’s
most recent fiscal quarter (the registrant’s fourth fiscal quarter in the case of an annual report) that has materially affected, or is
reasonably likely to materially affect, the registrant’s internal control over financial reporting; and


5. The registrant’s other certifying officer and I have disclosed, based on our most recent evaluation of internal control over financial reporting, to the
registrant’s auditors and the audit committee of the registrant’s Board of Directors (or persons performing the equivalent functions):


(a) All significant deficiencies and material weaknesses in the design or operation of internal control over financial reporting which are
reasonably likely to adversely affect the registrant’s ability to record, process, summarize and report financial information; and


(b) Any fraud, whether or not material, that involves management or other employees who have a significant role in the registrant’s
internal control over financial reporting.


Date: January 29, 2025 /s/ Elon Musk


Elon Musk


Chief Executive Officer


(Principal Executive Officer)


**Exhibit 31.2**


**CERTIFICATIONS**


I, Vaibhav Taneja, certify that:


1. I have reviewed this Annual Report on Form 10-K of Tesla, Inc.;


2. Based on my knowledge, this report does not contain any untrue statement of a material fact or omit to state a material fact necessary to make the
statements made, in light of the circumstances under which such statements were made, not misleading with respect to the period covered by this
report;


3. Based on my knowledge, the financial statements, and other financial information included in this report, fairly present in all material respects the
financial condition, results of operations and cash flows of the registrant as of, and for, the periods presented in this report;


4. The registrant’s other certifying officer and I are responsible for establishing and maintaining disclosure controls and procedures (as defined in
Exchange Act Rules 13a-15(e) and 15d-15(e)) and internal control over financial reporting (as defined in Exchange Act Rules 13a-15(f) and 15d15(f)) for the registrant and have:


(a) Designed such disclosure controls and procedures, or caused such disclosure controls and procedures to be designed under our
supervision, to ensure that material information relating to the registrant, including its consolidated subsidiaries, is made known to us
by others within those entities, particularly during the period in which this report is being prepared;


(b) Designed such internal control over financial reporting, or caused such internal control over financial reporting to be designed under
our supervision, to provide reasonable assurance regarding the reliability of financial reporting and the preparation of financial
statements for external purposes in accordance with generally accepted accounting principles;


(c) Evaluated the effectiveness of the registrant’s disclosure controls and procedures and presented in this report our conclusions about
the effectiveness of the disclosure controls and procedures, as of the end of the period covered by this report based on such evaluation;
and


(d) Disclosed in this report any change in the registrant’s internal control over financial reporting that occurred during the registrant’s
most recent fiscal quarter (the registrant’s fourth fiscal quarter in the case of an annual report) that has materially affected, or is
reasonably likely to materially affect, the registrant’s internal control over financial reporting; and


5. The registrant’s other certifying officer and I have disclosed, based on our most recent evaluation of internal control over financial reporting, to the
registrant’s auditors and the audit committee of the registrant’s Board of Directors (or persons performing the equivalent functions):


(a) All significant deficiencies and material weaknesses in the design or operation of internal control over financial reporting which are
reasonably likely to adversely affect the registrant’s ability to record, process, summarize and report financial information; and


(b) Any fraud, whether or not material, that involves management or other employees who have a significant role in the registrant’s
internal control over financial reporting.


---

Date: January 29, 2025 /s/ Vaibhav Taneja


Vaibhav Taneja


Chief Financial Officer


(Principal Financial Officer and

Principal Accounting Officer)


**SECTION 1350 CERTIFICATIONS**


**Exhibit 32.1**


I, Elon Musk, certify, pursuant to 18 U.S.C. Section 1350, that, to my knowledge, the Annual Report of Tesla, Inc. on Form 10-K for the annual period ended
December 31, 2024, (i) fully complies with the requirements of Section 13(a) or 15(d) of the Securities Exchange Act of 1934 and (ii) that the information
contained in such Form 10-K fairly presents, in all material respects, the financial condition and results of operations of Tesla, Inc.


Date: January 29, 2025 /s/ Elon Musk


Elon Musk


Chief Executive Officer


(Principal Executive Officer)


I, Vaibhav Taneja, certify, pursuant to 18 U.S.C. Section 1350, that, to my knowledge, the Annual Report of Tesla, Inc. on Form 10-K for the annual period
ended December 31, 2024, (i) fully complies with the requirements of Section 13(a) or 15(d) of the Securities Exchange Act of 1934 and (ii) that the
information contained in such Form 10-K fairly presents, in all material respects, the financial condition and results of operations of Tesla, Inc.


Date: January 29, 2025 /s/ Vaibhav Taneja


Vaibhav Taneja


Chief Financial Officer


(Principal Financial Officer and

Principal Accounting Officer)

---
*Conversion confidence: 100% (144 pages)*